# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/featurestore/api/v1/FeatureSetProtoApi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ai/h2o/featurestore/api/v1/FeatureSetProtoApi.proto',
  package='ai.h2o.featurestore.api.v1',
  syntax='proto3',
  serialized_options=b'B\027FeatureSetProtoApiProto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3ai/h2o/featurestore/api/v1/FeatureSetProtoApi.proto\x12\x1a\x61i.h2o.featurestore.api.v1\"[\n\x10\x46\x65\x61tureSetHeader\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x03 \x01(\t*)\n\x0e\x46\x65\x61tureSetType\x12\x07\n\x03RAW\x10\x00\x12\x0e\n\nENGINEERED\x10\x01*m\n\x0b\x46\x65\x61tureType\x12\x17\n\x13\x41UTOMATIC_DISCOVERY\x10\x00\x12\r\n\tCOMPOSITE\x10\x01\x12\r\n\tNUMERICAL\x10\x02\x12\x0f\n\x0b\x43\x41TEGORICAL\x10\x03\x12\x0c\n\x08TEMPORAL\x10\x04\x12\x08\n\x04TEXT\x10\x05\x42\x19\x42\x17\x46\x65\x61tureSetProtoApiProtob\x06proto3'
)

_FEATURESETTYPE = _descriptor.EnumDescriptor(
  name='FeatureSetType',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENGINEERED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=176,
  serialized_end=217,
)
_sym_db.RegisterEnumDescriptor(_FEATURESETTYPE)

FeatureSetType = enum_type_wrapper.EnumTypeWrapper(_FEATURESETTYPE)
_FEATURETYPE = _descriptor.EnumDescriptor(
  name='FeatureType',
  full_name='ai.h2o.featurestore.api.v1.FeatureType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTOMATIC_DISCOVERY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPOSITE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMERICAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CATEGORICAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEMPORAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=219,
  serialized_end=328,
)
_sym_db.RegisterEnumDescriptor(_FEATURETYPE)

FeatureType = enum_type_wrapper.EnumTypeWrapper(_FEATURETYPE)
RAW = 0
ENGINEERED = 1
AUTOMATIC_DISCOVERY = 0
COMPOSITE = 1
NUMERICAL = 2
CATEGORICAL = 3
TEMPORAL = 4
TEXT = 5



_FEATURESETHEADER = _descriptor.Descriptor(
  name='FeatureSetHeader',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.FeatureSetHeader.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.FeatureSetHeader.feature_set_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.FeatureSetHeader.feature_set_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=174,
)

DESCRIPTOR.message_types_by_name['FeatureSetHeader'] = _FEATURESETHEADER
DESCRIPTOR.enum_types_by_name['FeatureSetType'] = _FEATURESETTYPE
DESCRIPTOR.enum_types_by_name['FeatureType'] = _FEATURETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureSetHeader = _reflection.GeneratedProtocolMessageType('FeatureSetHeader', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETHEADER,
  '__module__' : 'ai.h2o.featurestore.api.v1.FeatureSetProtoApi_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetHeader)
  })
_sym_db.RegisterMessage(FeatureSetHeader)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
