# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/featurestore/api/v1/CoreService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ai.h2o.featurestore.api.v1 import FeatureSetSearch_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetSearch__pb2
from ai.h2o.featurestore.api.v1 import OnlineApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2
from ai.h2o.featurestore.api.v1 import TimeToLiveApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2
from ai.h2o.featurestore.api.v1 import FeatureSetProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2
from ai.h2o.featurestore.api.v1 import RecommendationProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2
from ai.h2o.featurestore.api.v1 import DashboardApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ai/h2o/featurestore/api/v1/CoreService.proto',
  package='ai.h2o.featurestore.api.v1',
  syntax='proto3',
  serialized_options=b'B\020CoreServiceProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,ai/h2o/featurestore/api/v1/CoreService.proto\x12\x1a\x61i.h2o.featurestore.api.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x31\x61i/h2o/featurestore/api/v1/FeatureSetSearch.proto\x1a*ai/h2o/featurestore/api/v1/OnlineApi.proto\x1a.ai/h2o/featurestore/api/v1/TimeToLiveApi.proto\x1a\x33\x61i/h2o/featurestore/api/v1/FeatureSetProtoApi.proto\x1a\x37\x61i/h2o/featurestore/api/v1/RecommendationProtoApi.proto\x1a-ai/h2o/featurestore/api/v1/DashboardApi.proto\"\xa9\x01\n\x1e\x46\x65\x61tureCustomDataUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12*\n\tnew_value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"R\n\x17IdentityProviderDetails\x12\x14\n\x0cidp_meta_url\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x0e\n\x06scopes\x18\x03 \x03(\t\"w\n\x14GetWebConfigResponse\x12H\n\x0bipd_details\x18\x01 \x01(\x0b\x32\x33.ai.h2o.featurestore.api.v1.IdentityProviderDetails\x12\x15\n\rapp_store_url\x18\x02 \x01(\t\"\x8d\x01\n!FeatureSetCustomDataUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12*\n\tnew_value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"`\n\x1eProjectCustomDataUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12*\n\tnew_value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x9a\x01\n\x1b\x46\x65\x61tureSetTypeUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12=\n\tnew_value\x18\x02 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\"m\n-GetFeatureSetsLastMinorForCurrentMajorRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\"\xb3\x01\n\x18\x46\x65\x61tureTypeUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12:\n\tnew_value\x18\x03 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\"\x91\x01\n\x1f\x46\x65\x61tureDoubleFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x01(\x01\"\x91\x01\n\x1f\x46\x65\x61tureStringFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x01(\t\"\x96\x01\n$FeatureStringArrayFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x03(\t\"\x92\x01\n FeatureBooleanFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x1d\n\x15\x61\x62solute_feature_name\x18\x02 \x01(\t\x12\x11\n\tnew_value\x18\x03 \x01(\x08\"\xbd\x01\n3FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12H\n\tnew_value\x18\x02 \x01(\x0e\x32\x35.ai.h2o.featurestore.api.v1.Online.TimeToLiveInterval\"\xbf\x01\n4FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12I\n\tnew_value\x18\x02 \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.Offline.TimeToLiveInterval\"r\n\x1f\x46\x65\x61tureSetIntFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x01(\x05\"\xae\x01\n*FeatureSetProcessIntervalUnitUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x42\n\tnew_value\x18\x02 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\"z\n\'FeatureSetStringArrayFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x03(\t\"v\n#FeatureSetBooleanFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x01(\x08\"u\n\"FeatureSetStringFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12\x11\n\tnew_value\x18\x02 \x01(\t\"\x9e\x01\n FeatureSetUserFieldUpdateRequest\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetHeader\x12<\n\tnew_value\x18\x02 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"I\n ProjectBooleanFieldUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tnew_value\x18\x02 \x01(\x08\"H\n\x1fProjectStringFieldUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tnew_value\x18\x02 \x01(\t\"q\n\x1dProjectUserFieldUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12<\n\tnew_value\x18\x02 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"E\n\x17\x46\x65\x61tureSetExistsRequest\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\"V\n\x17GetIngestHistoryRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"*\n\x14ProjectExistsRequest\x12\x12\n\nproject_id\x18\x02 \x01(\t\" \n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\")\n\x17ProjectsDefaultResponse\x12\x0e\n\x06locked\x18\x01 \x01(\x08\"P\n\x1eHasPermissionToRetrieveRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\"B\n\x1fHasPermissionToRetrieveResponse\x12\x1f\n\x17has_retrieve_permission\x18\x01 \x01(\x08\"m\n\x1bStartRevertIngestJobRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x11\n\tingest_id\x18\x02 \x01(\t\"e\n\x12OnlineRetrieveMeta\x12\x17\n\x0f\x62\x61se_online_url\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"%\n\x14GetUserByMailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"P\n\x15GetUserByMailResponse\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\" \n\x0cTokenRequest\x12\x10\n\x08token_id\x18\x01 \x01(\t\"j\n\x14GenerateTokenRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\x0b\x65xpiry_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\rTokenResponse\x12>\n\x05token\x18\x01 \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.PersonalAccessToken\"U\n\x12ListTokensResponse\x12?\n\x06tokens\x18\x01 \x03(\x0b\x32/.ai.h2o.featurestore.api.v1.PersonalAccessToken\"!\n\x10RawTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"\x95\x01\n\x0fListJobsRequest\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12;\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x35\n\x08job_type\x18\x03 \x01(\x0e\x32#.ai.h2o.featurestore.api.v1.JobType\"A\n\x10ListJobsResponse\x12-\n\x04jobs\x18\x01 \x03(\x0b\x32\x1f.ai.h2o.featurestore.api.v1.Job\"\xc5\x01\n$FeatureSetSchemaCompatibilityRequest\x12\x42\n\x0foriginal_schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12=\n\nnew_schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x1a\n\x12\x63ompare_data_types\x18\x03 \x01(\x08\">\n%FeatureSetSchemaCompatibilityResponse\x12\x15\n\ris_compatible\x18\x01 \x01(\x08\"\xbd\x01\n\x1c\x46\x65\x61tureSetSchemaPatchRequest\x12\x42\n\x0foriginal_schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12=\n\nnew_schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x1a\n\x12\x63ompare_data_types\x18\x03 \x01(\x08\"Z\n\x1d\x46\x65\x61tureSetSchemaPatchResponse\x12\x39\n\x06schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\"\x17\n\x05JobId\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"W\n\x18GetRecommendationRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"\xaf\x02\n\x19GetRecommendationResponse\x12L\n\x07matches\x18\x01 \x03(\x0b\x32;.ai.h2o.featurestore.api.v1.GetRecommendationResponse.Match\x1a+\n\x04Join\x12\x12\n\nclassifier\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x1a\x96\x01\n\x05Match\x12\x42\n\x12target_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12I\n\x05joins\x18\x02 \x03(\x0b\x32:.ai.h2o.featurestore.api.v1.GetRecommendationResponse.Join\"o\n\x03Job\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x35\n\x08job_type\x18\x02 \x01(\x0e\x32#.ai.h2o.featurestore.api.v1.JobType\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x12\x13\n\x0b\x63hildJobIds\x18\x04 \x03(\t\"6\n\x10JobProgressInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x12\n\nnext_index\x18\x02 \x01(\x05\"\xc6\x01\n\x11JobProgressOutput\x12H\n\x08progress\x18\x01 \x03(\x0b\x32\x36.ai.h2o.featurestore.api.v1.JobProgressOutput.Progress\x1ag\n\x08Progress\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1b\n\x13\x64uration_in_seconds\x18\x02 \x01(\r\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaf\x01\n\x1b\x46\x65\x61tureSetPermissionRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12>\n\npermission\x18\x03 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\"\xa5\x01\n\x18ProjectPermissionRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12>\n\npermission\x18\x03 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\"\xe8\x01\n\x1cStartExtractSchemaJobRequest\x12?\n\x08raw_data\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocationH\x00\x12\x46\n\x0c\x64\x65rived_from\x18\x03 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformationH\x00\x12\x35\n\x04\x63red\x18\x02 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.CredentialsB\x08\n\x06source\"\x98\x01\n\x15\x45xtractSchemaResponse\x12\x39\n\x06schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x44\n\x0c\x64\x65rived_from\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\"\\\n\x1dListFeatureSetsVersionRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"\x81\x01\n\x12\x46\x65\x61tureSetResponse\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12.\n\x03job\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"_\n\x18UpdateFeatureSetResponse\x12\x43\n\x13updated_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"U\n\x15UpdateProjectResponse\x12<\n\x0fupdated_project\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"\x9a\x01\n\x15UpdateFeatureResponse\x12\x43\n\x13updated_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12<\n\x0fupdated_feature\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\"G\n\x0fProjectResponse\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"I\n\rLoginResponse\x12\x13\n\tlogin_url\x18\x01 \x01(\tH\x00\x12\x17\n\rrefresh_token\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"P\n\x15GetActiveUserResponse\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\")\n\x11GetProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\"V\n\x17\x44\x65leteFeatureSetRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"&\n\rLogoutRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"8\n\rUserBasicInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"Y\n\x04User\x12\x42\n\x0fuser_basic_info\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\r\n\x05\x61\x64min\x18\x02 \x01(\x08\"y\n\x13\x41\x63\x63\x65ssTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x03\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x12\n\ntoken_type\x18\x05 \x01(\t\"L\n\x14\x44\x65leteProjectRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"T\n\x1cUpdateProjectMetadataRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"\x8f\x01\n\x14\x43reateProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\x08\x12\x0e\n\x06locked\x18\x04 \x01(\x08\x12,\n\x0b\x63ustom_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"e\n\x15\x43reateProjectResponse\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x16\n\x0e\x61lready_exists\x18\x02 \x01(\x08\"M\n\x14ListProjectsResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"`\n\x18GetIngestHistoryResponse\x12\x44\n\x0eingest_history\x18\x01 \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetIngest\"o\n$ListFeatureSetsAcrossProjectsRequest\x12\x15\n\rproject_names\x18\x01 \x03(\t\x12\x30\n\x05query\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Query\"\x8c\x01\n\x1aListFeatureSetsPageRequest\x12\x15\n\rproject_names\x18\x01 \x03(\t\x12\x30\n\x05query\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Query\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\"t\n\x1bListFeatureSetsPageResponse\x12<\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x01\n\x0e\x41WSCredentials\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x14\n\x0csecret_token\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x12\x10\n\x08role_arn\x18\x06 \x01(\t\"\xa6\x01\n\x10\x41zureCredentials\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x02 \x01(\t\x12\x11\n\tsas_token\x18\x03 \x01(\t\x12\x15\n\rsas_container\x18\x04 \x01(\t\x12\x14\n\x0csp_client_id\x18\x05 \x01(\t\x12\x14\n\x0csp_tenant_id\x18\x06 \x01(\t\x12\x11\n\tsp_secret\x18\x07 \x01(\t\"6\n\x14SnowflakeCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"1\n\x0fJDBCCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x92\x02\n\x0b\x43redentials\x12\x37\n\x03\x61ws\x18\x01 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.AWSCredentials\x12;\n\x05\x61zure\x18\x02 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.AzureCredentials\x12\x43\n\tsnowflake\x18\x03 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.SnowflakeCredentials\x12\x42\n\rjdbc_database\x18\x04 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.JDBCCredentialsJ\x04\x08\x05\x10\x06\"W\n\x17ListFeatureSetsResponse\x12<\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"l\n\x1eListFeatureSetVersionsResponse\x12J\n\x08versions\x18\x01 \x03(\x0b\x32\x38.ai.h2o.featurestore.api.v1.FeatureSetVersionDescription\"~\n\x1c\x46\x65\x61tureSetVersionDescription\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x16\n\x0eversion_change\x18\x02 \x01(\t\x12\x35\n\x11\x63reated_date_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"w\n\x14GetFeatureSetRequest\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xd9\x01\n\x15StartIngestJobRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x35\n\x04\x63red\x18\x02 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.Credentials\x12@\n\x0b\x64\x61ta_source\x18\x05 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocationJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xd8\x02\n\x0eIngestResponse\x12\x43\n\x04meta\x18\x01 \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta\x12;\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x1a\xc3\x01\n\nIngestMeta\x12\x16\n\x0e\x63\x61\x63he_location\x18\x01 \x01(\t\x12\x1a\n\x12raw_cache_location\x18\x02 \x01(\t\x12\x37\n\x13ingestion_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0cingest_scope\x18\x04 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa5\x01\n\x0fRetrieveRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x17\n\x0fstart_date_time\x18\x02 \x01(\t\x12\x15\n\rend_date_time\x18\x03 \x01(\t\x12\x11\n\tingest_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\"\x8b\x01\n\x17RetrieveAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\x12\x39\n\x0eretrieve_scope\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x1d\n\x15retrieve_job_executed\x18\x03 \x01(\x08\"\x96\x02\n\x17RetrieveAsSparkResponse\x12\x12\n\ncache_path\x18\x01 \x01(\t\x12Q\n\x07options\x18\x02 \x03(\x0b\x32@.ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.OptionsEntry\x12\x39\n\x0eretrieve_scope\x18\x03 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x12\n\nsession_id\x18\x04 \x01(\t\x12\x15\n\rdelta_version\x18\x05 \x01(\x04\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\x0ePreviewRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"`\n!StartMaterializationOnlineRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"v\n\x1dMaterializationOnlineResponse\x12@\n\x15materialization_scope\x18\x01 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x13\n\x0bnum_records\x18\x02 \x01(\x04\"2\n\x1cIngestWriteCredentialRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xca\x01\n\x1dIngestWriteCredentialResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12W\n\x07options\x18\x02 \x03(\x0b\x32\x46.ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x03 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xed\x05\n\x0fRawDataLocation\x12\x36\n\x03\x63sv\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.CSVFileSpecH\x00\x12>\n\x07parquet\x18\x02 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.ParquetFileSpecH\x00\x12\x43\n\tsnowflake\x18\x03 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.SnowflakeTableSpecH\x00\x12\x39\n\x04jdbc\x18\x04 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.JDBCTableSpecH\x00\x12\x38\n\x04json\x18\x07 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.JSONFileSpecH\x00\x12\x41\n\x0b\x64\x65lta_table\x18\x08 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.DeltaTableSpecH\x00\x12?\n\ncsv_folder\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.CSVFolderSpecH\x00\x12G\n\x0eparquet_folder\x18\x0b \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.ParquetFolderSpecH\x00\x12\x41\n\x0bjson_folder\x18\x0c \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.JSONFolderSpecH\x00\x12G\n\x0ctemp_parquet\x18\r \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.TempParquetFileSpecH\x00\x12\x45\n\ronline_source\x18\x0e \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.OnlineSourceSpecH\x00\x42\x08\n\x06source\"5\n\x10OnlineSourceSpec\x12!\n\x19\x61\x62solute_json_folder_path\x18\x01 \x01(\t\".\n\x0b\x43SVFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tdelimiter\x18\x02 \x01(\t\"/\n\x0cJSONFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tmultiline\x18\x02 \x01(\x08\"\x1f\n\x0fParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"#\n\x13TempParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"C\n\x05Proxy\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\"\xd7\x01\n\x12SnowflakeTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x11\n\twarehouse\x18\x05 \x01(\t\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08insecure\x18\x07 \x01(\x08\x12\x30\n\x05proxy\x18\x08 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Proxy\x12\x0c\n\x04role\x18\t \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\n \x01(\t\"\xb5\x01\n\rJDBCTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x16\n\x0e\x63onnection_url\x18\x03 \x01(\t\x12\x16\n\x0enum_partitions\x18\x04 \x01(\x05\x12\x18\n\x10partition_column\x18\x05 \x01(\t\x12\x13\n\x0blower_bound\x18\x06 \x01(\x04\x12\x13\n\x0bupper_bound\x18\x07 \x01(\x04\x12\x12\n\nfetch_size\x18\x08 \x01(\x05\"v\n\x0e\x44\x65ltaTableSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x32\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\".ai.h2o.featurestore.api.v1.Filter\"O\n\rCSVFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x11\n\tdelimiter\x18\x03 \x01(\t\"@\n\x11ParquetFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\"P\n\x0eJSONFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x11\n\tmultiline\x18\x03 \x01(\x08\"&\n\x12MojoTransformation\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"/\n\x1bSparkPipelineTransformation\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"9\n\x12JoinTransformation\x12\x10\n\x08left_key\x18\x01 \x01(\t\x12\x11\n\tright_key\x18\x02 \x01(\t\"0\n\x0bVersionedId\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rmajor_version\x18\x02 \x01(\r\"\xec\x01\n\x0eTransformation\x12>\n\x04mojo\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.MojoTransformationH\x00\x12Q\n\x0espark_pipeline\x18\x03 \x01(\x0b\x32\x37.ai.h2o.featurestore.api.v1.SparkPipelineTransformationH\x00\x12>\n\x04join\x18\x04 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.JoinTransformationH\x00\x42\x07\n\x05value\"\x9a\x01\n\x12\x44\x65rivedInformation\x12@\n\x0f\x66\x65\x61ture_set_ids\x18\x01 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\x42\n\x0etransformation\x18\x02 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.Transformation\"J\n\x0fSelectedFeature\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x61ture\x18\x02 \x01(\t\x12\x16\n\x0etransformation\x18\x03 \x01(\t\"\xa1\x01\n\x14\x46ilterConditionUnion\x12;\n\x06\x66ilter\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureFilterH\x00\x12?\n\x05logic\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.FeatureFilterLogicH\x00\x42\x0b\n\tcondition\"\xa1\x01\n\rFeatureFilter\x12<\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12\x43\n\x08operator\x18\x02 \x01(\x0e\x32\x31.ai.h2o.featurestore.api.v1.FeatureFilterOperator\x12\r\n\x05value\x18\x03 \x01(\t\"\xe5\x01\n\x12\x46\x65\x61tureFilterLogic\x12>\n\x04left\x18\x01 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x12?\n\x05right\x18\x02 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x12N\n\x0elogic_operator\x18\x03 \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.FeatureFilterLogicOperator\"\x83\x05\n\x0c\x46\x65\x61tureQuery\x12\x46\n\x11selected_features\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12G\n\x10\x66rom_feature_set\x18\x02 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureQuery.From\x12;\n\x04join\x18\x03 \x03(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureQuery.Join\x12?\n\x05where\x18\x04 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x1aS\n\x04\x46rom\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x1a\x8e\x02\n\x04Join\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12<\n\x02on\x18\x03 \x03(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FeatureQuery.Join.On\x1a{\n\x02On\x12\x39\n\x04left\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12:\n\x05right\x18\x02 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\"\x9a\x01\n\x0b\x46\x65\x61tureView\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x37\n\x05query\x18\x06 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"\x8a\x01\n\x18\x43reateFeatureViewRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x37\n\x05query\x18\x04 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"f\n\x18UpdateFeatureViewRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x94\x01\n\"CreateFeatureViewNewVersionRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x37\n\x05query\x18\x03 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"J\n\x15GetFeatureViewRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\"T\n\x13\x46\x65\x61tureViewResponse\x12=\n\x0c\x66\x65\x61ture_view\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.FeatureView\"-\n\x17ListFeatureViewsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"Z\n\x18ListFeatureViewsResponse\x12>\n\rfeature_views\x18\x01 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.FeatureView\"\xc8\x01\n!RetrieveFeatureViewAsSparkRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12,\n\x08start_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsession_id\x18\x05 \x01(\t\"\xd4\x01\n\"RetrieveFeatureViewAsSparkResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\\\n\x07options\x18\x02 \x03(\x0b\x32K.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n#RetrieveFeatureViewAsAsLinksRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12,\n\x08start_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\">\n$RetrieveFeatureViewAsAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\"3\n\x18\x44\x65leteFeatureViewRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\"\x8f\x03\n\x10MLDatasetFeature\x12\x12\n\nfeature_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x03 \x01(\x05\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x04 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x05 \x01(\x05\x12\x11\n\tdata_type\x18\x06 \x01(\t\x12=\n\x0c\x66\x65\x61ture_type\x18\x07 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x15\n\rml_dataset_id\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x15\n\roriginal_name\x18\n \x01(\t\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x1a\n\x12original_data_type\x18\x0c \x01(\t\x12\x1f\n\x17transformation_function\x18\r \x01(\t\x12\x16\n\x0eis_primary_key\x18\x0e \x01(\x08\"\xf6\x03\n\tMLDataset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x06 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x07 \x01(\x05\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12>\n\x08\x66\x65\x61tures\x18\t \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.MLDatasetFeature\x12\x43\n\x05state\x18\n \x01(\x0e\x32\x34.ai.h2o.featurestore.api.v1.MLDataset.MLDatasetState\x12\x14\n\x0cprimary_keys\x18\x0b \x03(\t\"l\n\x0eMLDatasetState\x12\x1c\n\x18ML_DATASET_STATE_UNKNOWN\x10\x00\x12\x1c\n\x18ML_DATASET_STATE_PENDING\x10\x01\x12\x1e\n\x1aML_DATASET_STATE_AVAILABLE\x10\x02\"\xda\x01\n\x16\x43reateMLDatasetRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x33\n\x0fstart_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"D\n\x16UpdateMLDatasetRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"/\n\x16\x44\x65leteMLDatasetRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\"\x84\x01\n\x17\x43reateMLDatasetResponse\x12\x39\n\nml_dataset\x18\x01 \x01(\x0b\x32%.ai.h2o.featurestore.api.v1.MLDataset\x12.\n\x03job\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"e\n\x13GetMLDatasetRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x17\n\x0fml_dataset_name\x18\x03 \x01(\t\"N\n\x15ListMLDatasetsRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\"T\n\x16ListMLDatasetsResponse\x12:\n\x0bml_datasets\x18\x01 \x03(\x0b\x32%.ai.h2o.featurestore.api.v1.MLDataset\"L\n\x1fRetrieveMLDatasetAsSparkRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\"\xd0\x01\n RetrieveMLDatasetAsSparkResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12Z\n\x07options\x18\x02 \x03(\x0b\x32I.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n!RetrieveMLDatasetAsAsLinksRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\"<\n\"RetrieveMLDatasetAsAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\"E\n\x1eRetrieveMLDatasetOnlineRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\"\xc7\x0e\n\nFeatureSet\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x16\n\x0eversion_change\x18\x05 \x01(\t\x12\x1a\n\x12time_travel_column\x18\x06 \x01(\t\x12!\n\x19time_travel_column_format\x18\x07 \x01(\t\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x08 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x38\n\x05owner\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x39\n\x06\x61uthor\x18\x0b \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x61pplication_name\x18\x0e \x01(\t\x12\x12\n\ndeprecated\x18\x0f \x01(\x08\x12\x33\n\x0f\x64\x65precated_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x11 \x03(\t\x12\x0c\n\x04tags\x18\x12 \x03(\t\x12\x18\n\x10process_interval\x18\x13 \x01(\r\x12N\n\x15process_interval_unit\x18\x14 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x15 \x01(\t\x12<\n\x0ctime_to_live\x18\x16 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12\x35\n\x08\x66\x65\x61tures\x18\x17 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x45\n\nstatistics\x18\x18 \x01(\x0b\x32\x31.ai.h2o.featurestore.api.v1.FeatureSet.Statistics\x12H\n\x0cspecial_data\x18\x19 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12\x13\n\x0bprimary_key\x18\x1a \x03(\t\x12\n\n\x02id\x18\x1c \x01(\t\x12<\n\x11time_travel_scope\x18\x1d \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x16\n\x0e\x61pplication_id\x18\x1e \x01(\t\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\x1f \x01(\t\x12=\n\x06online\x18  \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureSet.Online\x12\x0e\n\x06secret\x18! \x01(\x08\x12\x12\n\nproject_id\x18\" \x01(\t\x12\x14\n\x0cpartition_by\x18# \x03(\t\x12,\n\x0b\x63ustom_data\x18$ \x01(\x0b\x32\x17.google.protobuf.Struct\x12G\n\x1conline_materialization_scope\x18% \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x44\n\x0c\x64\x65rived_from\x18& \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x1b\n\x13\x66\x65\x61ture_classifiers\x18\' \x03(\t\x1a\"\n\nStatistics\x12\x14\n\x0c\x64\x61ta_latency\x18\x01 \x01(\x05\x1a\x82\x02\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\x12G\n\x05legal\x18\x06 \x01(\x0b\x32\x38.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal\x1a[\n\x05Legal\x12\x10\n\x08\x61pproved\x18\x01 \x01(\x08\x12\x31\n\rapproved_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05notes\x18\x03 \x01(\t\x1aJ\n\x06Online\x12\x18\n\x10online_namespace\x18\x01 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\"R\n\x1bGetFeatureSetPreviewRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"I\n\x1cGetFeatureSetPreviewResponse\x12\x13\n\x0bpreview_url\x18\x01 \x01(\t\x12\x14\n\x0cmax_cols_num\x18\x02 \x01(\r\"o\n\x05Scope\x12\x33\n\x0fstart_date_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xcf\x07\n\x19RegisterFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x34\n\x07project\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x1a\n\x12time_travel_column\x18\x03 \x01(\t\x12!\n\x19time_travel_column_format\x18\x04 \x01(\t\x12\x13\n\x0bprimary_key\x18\x05 \x03(\t\x12\x39\n\x06schema\x18\x07 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x0e\n\x06secret\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x14\n\x0cpartition_by\x18\n \x03(\t\x12\'\n\x1ftime_travel_column_as_partition\x18\x0b \x01(\x08\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x0c \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\r \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x0e \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x0f \x01(\t\x12=\n\x06online\x18\x10 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureSet.Online\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x11 \x03(\t\x12\x0c\n\x04tags\x18\x12 \x03(\t\x12\x18\n\x10process_interval\x18\x13 \x01(\r\x12N\n\x15process_interval_unit\x18\x14 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x15 \x01(\t\x12H\n\x0cspecial_data\x18\x16 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12,\n\x0b\x63ustom_data\x18\x17 \x01(\x0b\x32\x17.google.protobuf.Struct\x12<\n\x0ctime_to_live\x18\x18 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12\x44\n\x0c\x64\x65rived_from\x18\x19 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\"\x97\x03\n!CreateNewFeatureSetVersionRequest\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x39\n\x06schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x19\n\x11\x61\x66\x66\x65\x63ted_features\x18\x03 \x03(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x44\n\x0c\x64\x65rived_from\x18\x05 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x13\n\x0bprimary_key\x18\x06 \x03(\t\x12-\n%use_primary_key_from_previous_version\x18\x07 \x01(\x08\x12\x45\n\x10\x62\x61\x63kfill_options\x18\x08 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.BackfillOptions\"\xff\x01\n\x0e\x46\x65\x61tureProfile\x12=\n\x0c\x66\x65\x61ture_type\x18\x01 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12M\n\x0b\x63\x61tegorical\x18\x02 \x01(\x0b\x32\x38.ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics\x12\x41\n\nstatistics\x18\x03 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureStatistics\x12\x1c\n\x14statistics_available\x18\x04 \x01(\x08\"\xff\x02\n\rFeatureSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x39\n\x06nested\x18\x03 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12K\n\x0cspecial_data\x18\x04 \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData\x12=\n\x0c\x66\x65\x61ture_type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x13\n\x0b\x63lassifiers\x18\x07 \x03(\t\x1a\\\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\"\xb8\x05\n\x07\x46\x65\x61ture\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0eversion_change\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tdata_type\x18\x05 \x01(\t\x12;\n\x07profile\x18\x06 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.FeatureProfile\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x12\n\nimportance\x18\x08 \x01(\x01\x12\x0f\n\x07special\x18\t \x01(\t\x12\x42\n\nmonitoring\x18\n \x01(\x0b\x32..ai.h2o.featurestore.api.v1.Feature.Monitoring\x12<\n\x0fnested_features\x18\x0b \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12%\n\x1d\x66ully_qualified_feature_names\x18\x0c \x03(\t\x12\x45\n\x0cspecial_data\x18\r \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.Feature.SpecialData\x12\x13\n\x0b\x63lassifiers\x18\x0e \x03(\t\x12,\n\x0b\x63ustom_data\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12\n\n\x02id\x18\x10 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x11 \x01(\t\x1a\'\n\nMonitoring\x12\x19\n\x11\x61nomaly_detection\x18\x01 \x01(\x08\x1a\\\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\"\xac\x01\n\x11\x46\x65\x61tureStatistics\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x0e\n\x06median\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0e\n\x06stddev\x18\x05 \x01(\x01\x12\x18\n\x10stddev_rec_count\x18\x06 \x01(\x03\x12\x12\n\nnull_count\x18\x07 \x01(\x03\x12\x11\n\tnan_count\x18\x08 \x01(\x03\x12\x0e\n\x06unique\x18\t \x01(\x03\"\xab\x01\n\x1c\x43\x61tegoricalFeatureStatistics\x12\x0e\n\x06unique\x18\x01 \x01(\x03\x12P\n\x03top\x18\x02 \x03(\x0b\x32\x43.ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.FeatureTop\x1a)\n\nFeatureTop\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"%\n\x12GetVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x89\x03\n\x07Project\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x38\n\x05owner\x18\x03 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x39\n\x06\x61uthor\x18\x04 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12\x0e\n\x06locked\x18\x08 \x01(\x08\x12\n\n\x02id\x18\t \x01(\t\x12,\n\x0b\x63ustom_data\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1a\n\x12\x66\x65\x61ture_sets_count\x18\x0b \x01(\x04\"\xa4\x02\n\x0fListableProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x39\n\x15last_update_date_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06locked\x18\x05 \x01(\x08\x12@\n\npermission\x18\x06 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\x12\x39\n\x06\x61uthor\x18\x07 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x1a\n\x12\x66\x65\x61ture_sets_count\x18\x08 \x01(\x04\"\x97\x02\n\x10\x46\x65\x61tureSetIngest\x12\x11\n\tingest_id\x18\x01 \x01(\t\x12\x34\n\x10ingest_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x06source\x18\x03 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x05 \x01(\t\x12\x30\n\x05scope\x18\x07 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x16\n\x0eparent_ingests\x18\x08 \x03(\t\"\xd7\x01\n\x13PersonalAccessToken\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12-\n\tlast_used\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65xpiry_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x88\x01\n#GenerateTransformationUploadRequest\x12K\n\x13transformation_type\x18\x01 \x01(\x0e\x32..ai.h2o.featurestore.api.v1.TransformationType\x12\x14\n\x0cmd5_checksum\x18\x02 \x01(\t\"\xd5\x01\n$GenerateTransformationUploadResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12^\n\x07headers\x18\x03 \x03(\x0b\x32M.ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x17ListProjectsPageRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\"j\n\x18ListProjectsPageResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"n\n\rSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x12\n\nowned_only\x18\x04 \x01(\x08\x12\x13\n\x0bproject_ids\x18\x05 \x03(\t\"v\n\x14ProjectSearchResults\x12\x45\n\x10listable_project\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableProject\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x08\n\x12ListableFeatureSet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\x12\x39\n\x15last_update_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x06 \x01(\t\x12@\n\npermission\x18\x07 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x16\n\x0eversion_change\x18\t \x01(\t\x12\x1a\n\x12time_travel_column\x18\n \x01(\t\x12!\n\x19time_travel_column_format\x18\x0b \x01(\t\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x0c \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x39\n\x06\x61uthor\x18\r \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ndeprecated\x18\x0f \x01(\x08\x12\x33\n\x0f\x64\x65precated_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04tags\x18\x11 \x03(\t\x12<\n\x0ctime_to_live\x18\x12 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12H\n\x0cspecial_data\x18\x13 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12\x13\n\x0bprimary_key\x18\x14 \x03(\t\x12<\n\x11time_travel_scope\x18\x15 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x0e\n\x06secret\x18\x16 \x01(\x08\x12\x14\n\x0cpartition_by\x18\x17 \x03(\t\x12G\n\x1conline_materialization_scope\x18\x18 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x44\n\x0c\x64\x65rived_from\x18\x19 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x1b\n\x13\x66\x65\x61ture_classifiers\x18\x1a \x03(\t\"\x80\x01\n\x17\x46\x65\x61tureSetSearchResults\x12L\n\x14listable_feature_set\x18\x01 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xde\x01\n\x0fListableFeature\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11\x61nomaly_detection\x18\x04 \x01(\x08\x12=\n\x0c\x66\x65\x61ture_type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x11\n\tdata_type\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\x12\x12\n\nfeature_id\x18\x08 \x01(\t\"v\n\x14\x46\x65\x61tureSearchResults\x12\x45\n\x10listable_feature\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableFeature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"-\n\x13\x46\x65\x61tureSetRequestId\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"\\\n\x11GetFeatureRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x12\n\nfeature_id\x18\x03 \x01(\t\"j\n\x18ListFeaturesPageResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"G\n\x0f\x46\x65\x61tureResponse\x12\x34\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\"c\n\x13ListFeaturesRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\"f\n\x14ListFeaturesResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x19ListableFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"j\n\x1aListableFeatureSetResponse\x12L\n\x14listable_feature_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\"\x85\x01\n\x1eSubmitPendingPermissionRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12>\n\npermission\x18\x02 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x0e\n\x06reason\x18\x03 \x01(\t\"8\n\x1fSubmitPendingPermissionResponse\x12\x15\n\rpermission_id\x18\x01 \x01(\t\"\x81\x01\n\x1aListPermissionsPageRequest\x12<\n\x07\x66ilters\x18\x01 \x03(\x0e\x32+.ai.h2o.featurestore.api.v1.PermissionState\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n#ListProjectsPermissionsPageResponse\x12H\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x37.ai.h2o.featurestore.api.v1.ListableProjectToPermission\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x01\n&ListFeatureSetsPermissionsPageResponse\x12K\n\x07\x65ntries\x18\x01 \x03(\x0b\x32:.ai.h2o.featurestore.api.v1.ListableFeatureSetToPermission\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x97\x01\n\x1bListableProjectToPermission\x12<\n\x07project\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableProject\x12:\n\npermission\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.Permission\"\xa1\x01\n\x1eListableFeatureSetToPermission\x12\x43\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\x12:\n\npermission\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.Permission\"\xec\x08\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12?\n\rresource_type\x18\x03 \x01(\x0e\x32(.ai.h2o.featurestore.api.v1.ResourceType\x12>\n\npermission\x18\x04 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x37\n\x04user\x18\x05 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x17\n\x0f\x63reation_reason\x18\x06 \x01(\t\x12:\n\x05state\x18\x07 \x01(\x0e\x32+.ai.h2o.featurestore.api.v1.PermissionState\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_update_on\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x12[\n\x13granted_or_rejected\x18\x0b \x01(\x0b\x32>.ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate\x12\x45\n\x07revoked\x18\x0c \x01(\x0b\x32\x34.ai.h2o.featurestore.api.v1.Permission.RevokedUpdate\x12G\n\x08promoted\x18\r \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.Permission.PromotedUpdate\x1a\xac\x01\n\x0ePromotedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12!\n\x19replaced_by_permission_id\x18\x04 \x01(\t\x1a\x88\x01\n\rRevokedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\x1a\x92\x01\n\x17GrantedOrRejectedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\"@\n\x17RevokePermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"H\n\x1f\x41pprovePendingPermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"G\n\x1eRejectPendingPermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"1\n\x1aGetActivePermissionRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"_\n\x1bGetActivePermissionResponse\x12@\n\npermission\x18\x01 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\"\xb6\x04\n\rScheduledTask\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12;\n\x06source\x18\x06 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x31\n\rnext_run_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_exec\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x05owner\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\ttask_type\x18\r \x01(\x0e\x32$.ai.h2o.featurestore.api.v1.TaskType\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x0e \x01(\t\x12\x17\n\x0f\x63rone_time_zone\x18\x0f \x01(\t\"\xa0\x02\n\x13ScheduleTaskRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x35\n\x04\x63red\x18\x05 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.Credentials\x12;\n\x06source\x18\x06 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x08 \x01(\t\x12\x17\n\x0f\x63rone_time_zone\x18\t \x01(\t\"Z\n\x19ListScheduledTasksRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"o\n\x1aListScheduledTasksResponse\x12\x38\n\x05tasks\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.ScheduledTask\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\",\n\x0fScheduledTaskId\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\"P\n\x15ScheduledTaskResponse\x12\x37\n\x04task\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.ScheduledTask\"v\n\x1aScheduledTaskUpdateRequest\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08schedule\x18\x03 \x01(\t\x12\x16\n\x0eupdated_fields\x18\x04 \x03(\t\"H\n\x11LazyIngestRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"G\n\x12LazyIngestResponse\x12\x31\n\x06job_id\x18\x01 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"O\n\x18GetLazyIngestTaskRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"c\n\x16TransformationFunction\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x1d\n\x15supported_input_types\x18\x02 \x03(\t\x12\x13\n\x0boutput_type\x18\x03 \x01(\t\"$\n\"ListTransformationFunctionsRequest\"{\n#ListTransformationFunctionsResponse\x12T\n\x18transformation_functions\x18\x01 \x03(\x0b\x32\x32.ai.h2o.featurestore.api.v1.TransformationFunction\"H\n GetTransformationFunctionRequest\x12$\n\x1ctransformation_function_name\x18\x01 \x01(\t\"x\n!GetTransformationFunctionResponse\x12S\n\x17transformation_function\x18\x01 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.TransformationFunction\"\xda\x01\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06locked\x18\x02 \x01(\x08\x12\x0e\n\x06secret\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12,\n\x0b\x63ustom_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12K\n\x10\x66ields_to_update\x18\x06 \x03(\x0e\x32\x31.ai.h2o.featurestore.api.v1.UpdatableProjectField\"\xbc\x07\n\x17UpdateFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x04type\x18\x06 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x12\n\ndeprecated\x18\x07 \x01(\x08\x12\x18\n\x10process_interval\x18\x08 \x01(\x05\x12N\n\x15process_interval_unit\x18\t \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0e\n\x06secret\x18\n \x01(\x08\x12%\n\x1dtime_to_live_offline_interval\x18\x0b \x01(\r\x12\x62\n\"time_to_live_offline_interval_unit\x18\x0c \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.Offline.TimeToLiveInterval\x12$\n\x1ctime_to_live_online_interval\x18\r \x01(\r\x12`\n!time_to_live_online_interval_unit\x18\x0e \x01(\x0e\x32\x35.ai.h2o.featurestore.api.v1.Online.TimeToLiveInterval\x12\x16\n\x0elegal_approved\x18\x0f \x01(\x08\x12\x1c\n\x14legal_approved_notes\x18\x10 \x01(\t\x12\r\n\x05state\x18\x11 \x01(\t\x12\x0c\n\x04\x66low\x18\x12 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x13 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x14 \x01(\t\x12,\n\x0b\x63ustom_data\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x18\n\x10online_namespace\x18\x16 \x01(\t\x12\x14\n\x0conline_topic\x18\x17 \x01(\t\x12\x1e\n\x16online_connection_type\x18\x18 \x01(\t\x12N\n\x10\x66ields_to_update\x18\x19 \x03(\x0e\x32\x34.ai.h2o.featurestore.api.v1.UpdatableFeatureSetField\"\x8b\x03\n\x14UpdateFeatureRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x12\n\nfeature_id\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x12\n\nimportance\x18\x06 \x01(\x01\x12,\n\x0b\x63ustom_data\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x0f\n\x07special\x18\t \x01(\t\x12\x19\n\x11\x61nomaly_detection\x18\n \x01(\x08\x12\x13\n\x0b\x63lassifiers\x18\x0b \x03(\t\x12K\n\x10\x66ields_to_update\x18\x0c \x03(\x0e\x32\x31.ai.h2o.featurestore.api.v1.UpdatableFeatureField\"\'\n\x10GetOwnersRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"N\n\x11GetOwnersResponse\x12\x39\n\x06owners\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"\xe5\x02\n\x0f\x42\x61\x63kfillOptions\x12-\n\tfrom_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rom_version\x18\x03 \x01(\t\x12O\n\x0espark_pipeline\x18\x04 \x01(\x0b\x32\x37.ai.h2o.featurestore.api.v1.SparkPipelineTransformation\x12X\n\x0f\x66\x65\x61ture_mapping\x18\x05 \x03(\x0b\x32?.ai.h2o.featurestore.api.v1.BackfillOptions.FeatureMappingEntry\x1a\x35\n\x13\x46\x65\x61tureMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x10\x42\x61\x63kfillResponse\x12\x43\n\x0fingest_response\x18\x01 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.IngestResponse*\x97\x02\n\x07JobType\x12\x0b\n\x07Unknown\x10\x00\x12\n\n\x06Ingest\x10\x01\x12\x0c\n\x08Retrieve\x10\x02\x12\x11\n\rExtractSchema\x10\x03\x12\x0b\n\x07Preview\x10\x04\x12\x15\n\x11\x43omputeStatistics\x10\x05\x12\n\n\x06Revert\x10\x06\x12\x19\n\x15MaterializationOnline\x10\x07\x12$\n ComputeRecommendationClassifiers\x10\x08\x12\x13\n\x0f\x43reateMLDataset\x10\t\x12\x1e\n\x1a\x46\x65\x61tureViewRetrieveAsLinks\x10\n\x12\x1e\n\x1a\x46\x65\x61tureViewRetrieveAsSpark\x10\x0b\x12\x0c\n\x08\x42\x61\x63kfill\x10\x0c*L\n\x0ePermissionType\x12\t\n\x05Owner\x10\x00\x12\n\n\x06\x45\x64itor\x10\x01\x12\x0c\n\x08\x43onsumer\x10\x02\x12\x15\n\x11SensitiveConsumer\x10\x03*\xb3\x01\n\x10\x41\x63tivePermission\x12\x1a\n\x16\x41\x43TIVE_PERMISSION_NONE\x10\x00\x12\x1b\n\x17\x41\x43TIVE_PERMISSION_OWNER\x10\x01\x12\x1c\n\x18\x41\x43TIVE_PERMISSION_EDITOR\x10\x02\x12\x1e\n\x1a\x41\x43TIVE_PERMISSION_CONSUMER\x10\x03\x12(\n$ACTIVE_PERMISSION_SENSITIVE_CONSUMER\x10\x04*\xfc\x01\n\x15\x46\x65\x61tureFilterOperator\x12#\n\x1f\x46\x45\x41TURE_FILTER_OPERATOR_UNKNOWN\x10\x00\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_EQ\x10\x01\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_LT\x10\x02\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_LE\x10\x03\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_GT\x10\x04\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_GE\x10\x05\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_NE\x10\x06*\x94\x01\n\x1a\x46\x65\x61tureFilterLogicOperator\x12)\n%FEATURE_FILTER_LOGIC_OPERATOR_UNKNOWN\x10\x00\x12%\n!FEATURE_FILTER_LOGIC_OPERATOR_AND\x10\x01\x12$\n FEATURE_FILTER_LOGIC_OPERATOR_OR\x10\x02*\x96\x01\n\x0f\x46\x65\x61tureDataType\x12\x0b\n\x07TinyInt\x10\x00\x12\x0c\n\x08SmallInt\x10\x01\x12\n\n\x06\x42igInt\x10\x02\x12\x07\n\x03Int\x10\x03\x12\t\n\x05\x46loat\x10\x04\x12\n\n\x06\x44ouble\x10\x05\x12\n\n\x06String\x10\x06\x12\n\n\x06\x42inary\x10\x07\x12\x0b\n\x07\x42oolean\x10\x08\x12\x08\n\x04\x44\x61te\x10\t\x12\r\n\tTimestamp\x10\n*q\n\x13ProcessIntervalUnit\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05HOURS\x10\x01\x12\n\n\x06MONTHS\x10\x02\x12\x08\n\x04\x44\x41YS\x10\x03\x12\x0b\n\x07MINUTES\x10\x04\x12\x0b\n\x07SECONDS\x10\x05\x12\x10\n\x0cMILLISECONDS\x10\x06*h\n\x12TransformationType\x12\x19\n\x15TransformationUnknown\x10\x00\x12\x16\n\x12TransformationMojo\x10\x01\x12\x1f\n\x1bTransformationSparkPipeline\x10\x02*,\n\x0cResourceType\x12\x0b\n\x07PROJECT\x10\x00\x12\x0f\n\x0b\x46\x45\x41TURE_SET\x10\x01*T\n\x0fPermissionState\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07GRANTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\x0b\n\x07REVOKED\x10\x03\x12\x0c\n\x08PROMOTED\x10\x04*\'\n\x08TaskType\x12\n\n\x06INGEST\x10\x00\x12\x0f\n\x0bLAZY_INGEST\x10\x01*\x8a\x01\n\x15UpdatableProjectField\x12\x17\n\x13PROJECT_UNSPECIFIED\x10\x00\x12\x12\n\x0ePROJECT_LOCKED\x10\x01\x12\x12\n\x0ePROJECT_SECRET\x10\x02\x12\x17\n\x13PROJECT_DESCRIPTION\x10\x03\x12\x17\n\x13PROJECT_CUSTOM_DATA\x10\x04*\xf1\x05\n\x18UpdatableFeatureSetField\x12\x1b\n\x17\x46\x45\x41TURE_SET_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46\x45\x41TURE_SET_TAGS\x10\x01\x12#\n\x1f\x46\x45\x41TURE_SET_DATA_SOURCE_DOMAINS\x10\x02\x12\x1b\n\x17\x46\x45\x41TURE_SET_DESCRIPTION\x10\x03\x12\x14\n\x10\x46\x45\x41TURE_SET_TYPE\x10\x04\x12 \n\x1c\x46\x45\x41TURE_SET_APPLICATION_NAME\x10\x05\x12\x1e\n\x1a\x46\x45\x41TURE_SET_APPLICATION_ID\x10\x06\x12\x1a\n\x16\x46\x45\x41TURE_SET_DEPRECATED\x10\x07\x12 \n\x1c\x46\x45\x41TURE_SET_PROCESS_INTERVAL\x10\x08\x12%\n!FEATURE_SET_PROCESS_INTERVAL_UNIT\x10\t\x12\x14\n\x10\x46\x45\x41TURE_SET_FLOW\x10\n\x12\x15\n\x11\x46\x45\x41TURE_SET_STATE\x10\x0b\x12\x16\n\x12\x46\x45\x41TURE_SET_SECRET\x10\x0c\x12\x1b\n\x17\x46\x45\x41TURE_SET_TTL_OFFLINE\x10\r\x12$\n FEATURE_SET_TTL_OFFLINE_INTERVAL\x10\x0e\x12\x1a\n\x16\x46\x45\x41TURE_SET_TTL_ONLINE\x10\x0f\x12#\n\x1f\x46\x45\x41TURE_SET_TTL_ONLINE_INTERVAL\x10\x10\x12\x1b\n\x17\x46\x45\x41TURE_SET_CUSTOM_DATA\x10\x11\x12+\n\'FEATURE_SET_SPECIAL_DATA_LEGAL_APPROVED\x10\x12\x12(\n$FEATURE_SET_SPECIAL_DATA_LEGAL_NOTES\x10\x13\x12 \n\x1c\x46\x45\x41TURE_SET_ONLINE_NAMESPACE\x10\x14\x12\x1c\n\x18\x46\x45\x41TURE_SET_ONLINE_TOPIC\x10\x15\x12&\n\"FEATURE_SET_ONLINE_CONNECTION_TYPE\x10\x16*\xed\x01\n\x15UpdatableFeatureField\x12\x17\n\x13\x46\x45\x41TURE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46\x45\x41TURE_STATUS\x10\x01\x12\x10\n\x0c\x46\x45\x41TURE_TYPE\x10\x02\x12\x16\n\x12\x46\x45\x41TURE_IMPORTANCE\x10\x03\x12\x17\n\x13\x46\x45\x41TURE_CUSTOM_DATA\x10\x04\x12\x17\n\x13\x46\x45\x41TURE_DESCRIPTION\x10\x05\x12\x13\n\x0f\x46\x45\x41TURE_SPECIAL\x10\x06\x12\x1d\n\x19\x46\x45\x41TURE_ANOMALY_DETECTION\x10\x07\x12\x17\n\x13\x46\x45\x41TURE_CLASSIFIERS\x10\x08\x32\xad\xc5\x01\n\x0b\x43oreService\x12{\n\x08ListJobs\x12+.ai.h2o.featurestore.api.v1.ListJobsRequest\x1a,.ai.h2o.featurestore.api.v1.ListJobsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v1/jobs\x12k\n\x06GetJob\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x1f.ai.h2o.featurestore.api.v1.Job\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/jobs/{job_id}\x12\x95\x01\n\x0eGetJobProgress\x12,.ai.h2o.featurestore.api.v1.JobProgressInput\x1a-.ai.h2o.featurestore.api.v1.JobProgressOutput\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/jobs/{job_id}/progress\x12\x9c\x01\n\x15StartExtractSchemaJob\x12\x38.ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/jobs/extract-schema:\x01*\x12\x9f\x01\n\x19GetExtractSchemaJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x31.ai.h2o.featurestore.api.v1.ExtractSchemaResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/jobs/extract-schema/{job_id}\x12\x87\x01\n\x0eStartIngestJob\x12\x31.ai.h2o.featurestore.api.v1.StartIngestJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/ingest/start:\x01*\x12\x85\x01\n\x12GetIngestJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a*.ai.h2o.featurestore.api.v1.IngestResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/api/v1/ingests/{job_id}\x12\x8d\x01\n\x17StartRetrieveAsLinksJob\x12+.ai.h2o.featurestore.api.v1.RetrieveRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/ingest/retrieve:\x01*\x12\x9f\x01\n\x1bGetRetrieveAsLinksJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x33.ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/ingest/retrieve/{job_id}\x12\x9d\x01\n\x0fRetrieveAsSpark\x12+.ai.h2o.featurestore.api.v1.RetrieveRequest\x1a\x33.ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/ingest/retrieve/spark:\x01*\x12\x82\x01\n\x0fStartPreviewJob\x12*.ai.h2o.featurestore.api.v1.PreviewRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/preview/start:\x01*\x12\xc0\x01\n\x19GetIngestWriteCredentials\x12\x38.ai.h2o.featurestore.api.v1.IngestWriteCredentialRequest\x1a\x39.ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/ingest/credential/{session_id}\x12\x94\x01\n\x14StartRevertIngestJob\x12\x37.ai.h2o.featurestore.api.v1.StartRevertIngestJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/ingest/revert:\x01*\x12}\n\x18GetRevertIngestJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/ingest/revert/{job_id}\x12\xb5\x01\n\x17HasPermissionToRetrieve\x12:.ai.h2o.featurestore.api.v1.HasPermissionToRetrieveRequest\x1a;.ai.h2o.featurestore.api.v1.HasPermissionToRetrieveResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/ingest/permission\x12\xa5\x01\n\x12RegisterFeatureSet\x12\x35.ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/feature-sets/register:\x01*\x12\xb4\x01\n\x1a\x43reateNewFeatureSetVersion\x12=.ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1/feature-sets/version:\x01*\x12\x80\x01\n\x15GetOnlineRetrieveMeta\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.OnlineRetrieveMeta\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/online-retrieve\x12m\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.GetVersionResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/version\x12\x91\x01\n\rGetFeatureSet\x12\x30.ai.h2o.featurestore.api.v1.GetFeatureSetRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/feature-set:\x01*\x12\xa2\x01\n\x11GetFeatureSetById\x12/.ai.h2o.featurestore.api.v1.FeatureSetRequestId\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-set/{feature_set_id}\x12\xc6\x01\n&GetFeatureSetsLastMinorForCurrentMajor\x12I.ai.h2o.featurestore.api.v1.GetFeatureSetsLastMinorForCurrentMajorRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/feature-sets-last\x12\xb5\x01\n\x16ListFeatureSetVersions\x12\x39.ai.h2o.featurestore.api.v1.ListFeatureSetsVersionRequest\x1a:.ai.h2o.featurestore.api.v1.ListFeatureSetVersionsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/feature-sets/version\x12\x80\x01\n\x10\x44\x65leteFeatureSet\x12\x33.ai.h2o.featurestore.api.v1.DeleteFeatureSetRequest\x1a\x16.google.protobuf.Empty\"\x1f\x82\xd3\xe4\x93\x02\x19*\x14/api/v1/feature-sets:\x01*\x12\xa4\x01\n\x13ListFeatureSetsPage\x12\x36.ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest\x1a\x37.ai.h2o.featurestore.api.v1.ListFeatureSetsPageResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/feature-sets\x12\x98\x01\n\x10\x46\x65\x61tureSetExists\x12\x33.ai.h2o.featurestore.api.v1.FeatureSetExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/feature-sets/exists\x12\x9d\x01\n\x10GetIngestHistory\x12\x33.ai.h2o.featurestore.api.v1.GetIngestHistoryRequest\x1a\x34.ai.h2o.featurestore.api.v1.GetIngestHistoryResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/ingest/history\x12\xa9\x01\n\x1aUpdateFeatureSetPrimaryKey\x12\x43.ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\".\x88\x02\x01\x82\xd3\xe4\x93\x02%\x1a /api/v1/feature-sets/primary-key:\x01*\x12\x9c\x01\n\x14UpdateFeatureSetTags\x12\x43.ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"\'\x88\x02\x01\x82\xd3\xe4\x93\x02\x1e\x1a\x19/api/v1/feature-sets/tags:\x01*\x12\xb8\x01\n!UpdateFeatureSetDataSourceDomains\x12\x43.ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-\x1a(/api/v1/feature-sets/data-source-domains:\x01*\x12\xa5\x01\n\x1bUpdateFeatureSetDescription\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\".\x88\x02\x01\x82\xd3\xe4\x93\x02%\x1a /api/v1/feature-sets/description:\x01*\x12\x90\x01\n\x14UpdateFeatureSetType\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetTypeUpdateRequest\x1a\x16.google.protobuf.Empty\"\'\x88\x02\x01\x82\xd3\xe4\x93\x02\x1e\x1a\x19/api/v1/feature-sets/type:\x01*\x12\x97\x01\n\x15UpdateFeatureSetOwner\x12<.ai.h2o.featurestore.api.v1.FeatureSetUserFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"(\x88\x02\x01\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/feature-sets/owner:\x01*\x12\xae\x01\n\x1fUpdateFeatureSetApplicationName\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x88\x02\x01\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/application-name:\x01*\x12\xaa\x01\n\x1dUpdateFeatureSetApplicationId\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"1\x88\x02\x01\x82\xd3\xe4\x93\x02(\x1a#/api/v1/feature-sets/application-id:\x01*\x12\xa4\x01\n\x1aUpdateFeatureSetDeprecated\x12?.ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"-\x88\x02\x01\x82\xd3\xe4\x93\x02$\x1a\x1f/api/v1/feature-sets/deprecated:\x01*\x12\xab\x01\n\x1fUpdateFeatureSetProcessInterval\x12;.ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x88\x02\x01\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/process-interval:\x01*\x12\xbf\x01\n#UpdateFeatureSetProcessIntervalUnit\x12\x46.ai.h2o.featurestore.api.v1.FeatureSetProcessIntervalUnitUpdateRequest\x1a\x16.google.protobuf.Empty\"8\x88\x02\x01\x82\xd3\xe4\x93\x02/\x1a*/api/v1/feature-sets/process-interval-unit:\x01*\x12\x97\x01\n\x14UpdateFeatureSetFlow\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"\'\x88\x02\x01\x82\xd3\xe4\x93\x02\x1e\x1a\x19/api/v1/feature-sets/flow:\x01*\x12\x99\x01\n\x15UpdateFeatureSetState\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"(\x88\x02\x01\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/feature-sets/state:\x01*\x12\x9c\x01\n\x16UpdateFeatureSetSecret\x12?.ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\")\x88\x02\x01\x82\xd3\xe4\x93\x02 \x1a\x1b/api/v1/feature-sets/secret:\x01*\x12\xa3\x01\n\x1aUpdateFeatureSetCustomData\x12=.ai.h2o.featurestore.api.v1.FeatureSetCustomDataUpdateRequest\x1a\x16.google.protobuf.Empty\".\x88\x02\x01\x82\xd3\xe4\x93\x02%\x1a /api/v1/feature-sets/custom-data:\x01*\x12\xaf\x01\n\x1fUpdateTimeToLiveOfflineInterval\x12;.ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/time-to-live-offline:\x01*\x12\xcd\x01\n#UpdateTimeToLiveOfflineIntervalUnit\x12P.ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest\x1a\x16.google.protobuf.Empty\"<\x88\x02\x01\x82\xd3\xe4\x93\x02\x33\x1a./api/v1/feature-sets/time-to-live-offline-unit:\x01*\x12\xad\x01\n\x1eUpdateTimeToLiveOnlineInterval\x12;.ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"6\x88\x02\x01\x82\xd3\xe4\x93\x02-\x1a(/api/v1/feature-sets/time-to-live-online:\x01*\x12\xca\x01\n\"UpdateTimeToLiveOnlineIntervalUnit\x12O.ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest\x1a\x16.google.protobuf.Empty\";\x88\x02\x01\x82\xd3\xe4\x93\x02\x32\x1a-/api/v1/feature-sets/time-to-live-online-unit:\x01*\x12\xae\x01\n\x1fUpdateFeatureSetOnlineNamespace\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x88\x02\x01\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/online-namespace:\x01*\x12\xa6\x01\n\x1bUpdateFeatureSetOnlineTopic\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"/\x88\x02\x01\x82\xd3\xe4\x93\x02&\x1a!/api/v1/feature-sets/online-topic:\x01*\x12\xb9\x01\n$UpdateFeatureSetOnlineConnectionType\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"9\x88\x02\x01\x82\xd3\xe4\x93\x02\x30\x1a+/api/v1/feature-sets/online-connection-type:\x01*\x12\xab\x01\n\x1dUpdateFeatureSetLegalApproved\x12?.ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"1\x88\x02\x01\x82\xd3\xe4\x93\x02(\x1a#/api/v1/feature-sets/legal-approved:\x01*\x12\xb5\x01\n\"UpdateFeatureSetLegalApprovedNotes\x12>.ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/legal-approved-notes:\x01*\x12\x9b\x01\n\x13UpdateFeatureStatus\x12;.ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)\x1a$/api/v1/feature-sets/features/status:\x01*\x12\x90\x01\n\x11UpdateFeatureType\x12\x34.ai.h2o.featurestore.api.v1.FeatureTypeUpdateRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'\x1a\"/api/v1/feature-sets/features/type:\x01*\x12\xa3\x01\n\x17UpdateFeatureCustomData\x12:.ai.h2o.featurestore.api.v1.FeatureCustomDataUpdateRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/features/custom-data:\x01*\x12\xa3\x01\n\x17UpdateFeatureImportance\x12;.ai.h2o.featurestore.api.v1.FeatureDoubleFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\x1a(/api/v1/feature-sets/features/importance:\x01*\x12\xa5\x01\n\x18UpdateFeatureDescription\x12;.ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/features/description:\x01*\x12\x9d\x01\n\x14UpdateFeatureSpecial\x12;.ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/features/special:\x01*\x12\xb1\x01\n\x1dUpdateFeatureAnomalyDetection\x12<.ai.h2o.featurestore.api.v1.FeatureBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34\x1a//api/v1/feature-sets/features/anomaly-detection:\x01*\x12\xaa\x01\n\x18UpdateFeatureClassifiers\x12@.ai.h2o.featurestore.api.v1.FeatureStringArrayFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x1a)/api/v1/feature-sets/features/classifiers:\x01*\x12\xdf\x01\n\x1cIsFeatureSetSchemaCompatible\x12@.ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest\x1a\x41.ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityResponse\":\x82\xd3\xe4\x93\x02\x34\"//api/v1/feature-sets/features/schema-compatible:\x01*\x12\xba\x01\n\x15\x46\x65\x61tureSetSchemaPatch\x12\x38.ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest\x1a\x39.ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchResponse\",\x82\xd3\xe4\x93\x02&\"!/api/v1/feature-sets/schema-patch:\x01*\x12\xc0\x01\n\x14GetFeatureSetPreview\x12\x37.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewRequest\x1a\x38.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewResponse\"5\x82\xd3\xe4\x93\x02/\x12-/api/v1/feature-set-previews/{feature_set_id}\x12\xaf\x01\n\x10UpdateFeatureSet\x12\x33.ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest\x1a\x34.ai.h2o.featurestore.api.v1.UpdateFeatureSetResponse\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/{feature_set_id}:\x01*\x12\x9c\x01\n\x11\x43reateFeatureView\x12\x34.ai.h2o.featurestore.api.v1.CreateFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/feature-views:\x01*\x12\xc5\x01\n\x11UpdateFeatureView\x12\x34.ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/api/v1/feature-views/{feature_view_id}/{feature_view_version}:\x01*\x12\xb0\x01\n\x0eGetFeatureView\x12\x31.ai.h2o.featurestore.api.v1.GetFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/projects/{project_id}/feature-views/{name}\x12\x9c\x01\n\x10ListFeatureViews\x12\x33.ai.h2o.featurestore.api.v1.ListFeatureViewsRequest\x1a\x34.ai.h2o.featurestore.api.v1.ListFeatureViewsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/feature-views\x12\xb0\x01\n\x1b\x43reateFeatureViewNewVersion\x12>.ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/feature-views:\x01*\x12\xd7\x01\n\"StartRetrieveFeatureViewAsSparkJob\x12=.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"O\x82\xd3\xe4\x93\x02I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/spark:\x01*\x12\xb9\x01\n&GetRetrieveFeatureViewAsSparkJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a>.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-views/spark/{job_id}\x12\xd9\x01\n\"StartRetrieveFeatureViewAsLinksJob\x12?.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"O\x82\xd3\xe4\x93\x02I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/links:\x01*\x12\xbb\x01\n&GetRetrieveFeatureViewAsLinksJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a@.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-views/links/{job_id}\x12\x92\x01\n\x11\x44\x65leteFeatureView\x12\x34.ai.h2o.featurestore.api.v1.DeleteFeatureViewRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)*\'/api/v1/feature-views/{feature_view_id}\x12\x9a\x01\n\x0f\x43reateMLDataset\x12\x32.ai.h2o.featurestore.api.v1.CreateMLDatasetRequest\x1a\x33.ai.h2o.featurestore.api.v1.CreateMLDatasetResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/ml-datasets:\x01*\x12\x8f\x01\n\x1dGetMLDatasetCreationJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a%.ai.h2o.featurestore.api.v1.MLDataset\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/ml-datasets/{job_id}\x12\x9c\x01\n\x0fUpdateMLDataset\x12\x32.ai.h2o.featurestore.api.v1.UpdateMLDatasetRequest\x1a%.ai.h2o.featurestore.api.v1.MLDataset\".\x82\xd3\xe4\x93\x02(\x1a#/api/v1/ml-datasets/{ml_dataset_id}:\x01*\x12\x8a\x01\n\x0f\x44\x65leteMLDataset\x12\x32.ai.h2o.featurestore.api.v1.DeleteMLDatasetRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/api/v1/ml-datasets/{ml_dataset_id}\x12\x93\x01\n\x0cGetMLDataset\x12/.ai.h2o.featurestore.api.v1.GetMLDatasetRequest\x1a%.ai.h2o.featurestore.api.v1.MLDataset\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/ml-datasets/{ml_dataset_id}\x12\x94\x01\n\x0eListMLDatasets\x12\x31.ai.h2o.featurestore.api.v1.ListMLDatasetsRequest\x1a\x32.ai.h2o.featurestore.api.v1.ListMLDatasetsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/ml-datasets\x12\xc5\x01\n\x18RetrieveMLDatasetAsSpark\x12;.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkRequest\x1a<.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse\".\x82\xd3\xe4\x93\x02(\"#/api/v1/ml-datasets/{ml_dataset_id}:\x01*\x12\xc6\x01\n\x18RetrieveMLDatasetAsLinks\x12=.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksRequest\x1a>.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksResponse\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/ml-datasets/{ml_dataset_id}\x12\xbd\x01\n\x17RetrieveMLDatasetOnline\x12:.ai.h2o.featurestore.api.v1.RetrieveMLDatasetOnlineRequest\x1a\x32.ai.h2o.featurestore.api.v1.OnlineRetrieveResponse\"2\x82\xd3\xe4\x93\x02,\x12*/api/v1/ml-datasets/{ml_dataset_id}/online\x12\x97\x01\n\x10ListProjectsPage\x12\x33.ai.h2o.featurestore.api.v1.ListProjectsPageRequest\x1a\x34.ai.h2o.featurestore.api.v1.ListProjectsPageResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/projects\x12\x91\x01\n\rCreateProject\x12\x30.ai.h2o.featurestore.api.v1.CreateProjectRequest\x1a\x31.ai.h2o.featurestore.api.v1.CreateProjectResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/api/v1/projects:\x01*\x12\x91\x01\n\nGetProject\x12-.ai.h2o.featurestore.api.v1.GetProjectRequest\x1a+.ai.h2o.featurestore.api.v1.ProjectResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/projects/{project_name}\x12v\n\rDeleteProject\x12\x30.ai.h2o.featurestore.api.v1.DeleteProjectRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15*\x10/api/v1/projects:\x01*\x12\x83\x01\n\x12GetProjectsDefault\x12\x16.google.protobuf.Empty\x1a\x33.ai.h2o.featurestore.api.v1.ProjectsDefaultResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/api/v1/projects/default\x12\x9b\x01\n\rProjectExists\x12\x30.ai.h2o.featurestore.api.v1.ProjectExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/projects/{project_id}/exists\x12\x9f\x01\n\x13UpdateProjectSecret\x12<.ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"2\x88\x02\x01\x82\xd3\xe4\x93\x02)\x1a$/api/v1/projects/{project_id}/secret:\x01*\x12\x9f\x01\n\x13UpdateProjectLocked\x12<.ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"2\x88\x02\x01\x82\xd3\xe4\x93\x02)\x1a$/api/v1/projects/{project_id}/locked:\x01*\x12\x9a\x01\n\x12UpdateProjectOwner\x12\x39.ai.h2o.featurestore.api.v1.ProjectUserFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"1\x88\x02\x01\x82\xd3\xe4\x93\x02(\x1a#/api/v1/projects/{project_id}/owner:\x01*\x12\xa8\x01\n\x18UpdateProjectDescription\x12;.ai.h2o.featurestore.api.v1.ProjectStringFieldUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/projects/{project_id}/description:\x01*\x12\xa6\x01\n\x17UpdateProjectCustomData\x12:.ai.h2o.featurestore.api.v1.ProjectCustomDataUpdateRequest\x1a\x16.google.protobuf.Empty\"7\x88\x02\x01\x82\xd3\xe4\x93\x02.\x1a)/api/v1/projects/{project_id}/custom-data:\x01*\x12\x9e\x01\n\rUpdateProject\x12\x30.ai.h2o.featurestore.api.v1.UpdateProjectRequest\x1a\x31.ai.h2o.featurestore.api.v1.UpdateProjectResponse\"(\x82\xd3\xe4\x93\x02\"\x1a\x1d/api/v1/projects/{project_id}:\x01*\x12\x91\x01\n\x0eGetAccessToken\x12/.ai.h2o.featurestore.api.v1.RefreshTokenRequest\x1a/.ai.h2o.featurestore.api.v1.AccessTokenResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/token:\x01*\x12\x98\x01\n\rGetUserByMail\x12\x30.ai.h2o.featurestore.api.v1.GetUserByMailRequest\x1a\x31.ai.h2o.featurestore.api.v1.GetUserByMailResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/auth/users/{email}\x12k\n\x06Logout\x12).ai.h2o.featurestore.api.v1.LogoutRequest\x1a\x16.google.protobuf.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/auth/logout:\x01*\x12v\n\rGetActiveUser\x12\x16.google.protobuf.Empty\x1a\x31.ai.h2o.featurestore.api.v1.GetActiveUserResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/auth/users\x12k\n\x05Login\x12\x16.google.protobuf.Empty\x1a).ai.h2o.featurestore.api.v1.LoginResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/login:\x01*0\x01\x12p\n\x0cGetWebConfig\x12\x16.google.protobuf.Empty\x1a\x30.ai.h2o.featurestore.api.v1.GetWebConfigResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/api/v1/config\x12\xb4\x01\n\x17\x41\x64\x64\x46\x65\x61tureSetPermission\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"0\x82\xd3\xe4\x93\x02*\"%/api/v1/auth/feature-sets/permissions:\x01*\x12\xa7\x01\n\x14\x41\x64\x64ProjectPermission\x12\x34.ai.h2o.featurestore.api.v1.ProjectPermissionRequest\x1a+.ai.h2o.featurestore.api.v1.ProjectResponse\",\x82\xd3\xe4\x93\x02&\"!/api/v1/auth/projects/permissions:\x01*\x12\xb7\x01\n\x1aRemoveFeatureSetPermission\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"0\x82\xd3\xe4\x93\x02**%/api/v1/auth/feature-sets/permissions:\x01*\x12\xaa\x01\n\x17RemoveProjectPermission\x12\x34.ai.h2o.featurestore.api.v1.ProjectPermissionRequest\x1a+.ai.h2o.featurestore.api.v1.ProjectResponse\",\x82\xd3\xe4\x93\x02&*!/api/v1/auth/projects/permissions:\x01*\x12\xd0\x01\n\x1eSubmitPendingProjectPermission\x12:.ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest\x1a;.ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse\"5\x82\xd3\xe4\x93\x02/\"*/api/v1/permissions/projects/{resource_id}:\x01*\x12\xd7\x01\n!SubmitPendingFeatureSetPermission\x12:.ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest\x1a;.ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse\"9\x82\xd3\xe4\x93\x02\x33\"./api/v1/permissions/feature-sets/{resource_id}:\x01*\x12\xbb\x01\n\x1aListProjectPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a?.ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/permissions/projects\x12\xc6\x01\n\x1eListFeatureSetsPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a\x42.ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/permissions/feature-sets\x12\xd0\x01\n$ListManageableProjectPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a?.ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/api/v1/permissions/manageable-projects\x12\xdb\x01\n(ListManageableFeatureSetsPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a\x42.ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/permissions/manageable-feature-sets\x12\x98\x01\n\x18\x41pprovePendingPermission\x12;.ai.h2o.featurestore.api.v1.ApprovePendingPermissionRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1/permissions/approval:\x01*\x12\x97\x01\n\x17RejectPendingPermission\x12:.ai.h2o.featurestore.api.v1.RejectPendingPermissionRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/permissions/rejection:\x01*\x12\x86\x01\n\x10RevokePermission\x12\x33.ai.h2o.featurestore.api.v1.RevokePermissionRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1/permissions/revoke:\x01*\x12\xc8\x01\n\x1aGetActiveProjectPermission\x12\x36.ai.h2o.featurestore.api.v1.GetActivePermissionRequest\x1a\x37.ai.h2o.featurestore.api.v1.GetActivePermissionResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/api/v1/permissions/projects/{resource_id}/active\x12\xcf\x01\n\x1dGetActiveFeatureSetPermission\x12\x36.ai.h2o.featurestore.api.v1.GetActivePermissionRequest\x1a\x37.ai.h2o.featurestore.api.v1.GetActivePermissionResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/permissions/feature-sets/{resource_id}/active\x12\xa9\x01\n\x10GetProjectOwners\x12,.ai.h2o.featurestore.api.v1.GetOwnersRequest\x1a-.ai.h2o.featurestore.api.v1.GetOwnersResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/api/v1/permissions/project/{resource_id}/owners\x12\xb1\x01\n\x13GetFeatureSetOwners\x12,.ai.h2o.featurestore.api.v1.GetOwnersRequest\x1a-.ai.h2o.featurestore.api.v1.GetOwnersResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/permissions/feature-sets/{resource_id}/owners\x12u\n\x0bRevokeToken\x12(.ai.h2o.featurestore.api.v1.TokenRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/api/v1/auth/token/revoke:\x01*\x12\x8e\x01\n\rGenerateToken\x12\x30.ai.h2o.featurestore.api.v1.GenerateTokenRequest\x1a,.ai.h2o.featurestore.api.v1.RawTokenResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/token:\x01*\x12q\n\nListTokens\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.ListTokensResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/auth/tokens\x12\x87\x01\n\x08GetToken\x12(.ai.h2o.featurestore.api.v1.TokenRequest\x1a).ai.h2o.featurestore.api.v1.TokenResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/auth/tokens/{token_id}\x12\x98\x01\n\x0eOnlineRetrieve\x12\x31.ai.h2o.featurestore.api.v1.OnlineRetrieveRequest\x1a\x32.ai.h2o.featurestore.api.v1.OnlineRetrieveResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/online-retrieve\x12v\n\x0cOnlineIngest\x12/.ai.h2o.featurestore.api.v1.OnlineIngestRequest\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/online-ingest\x12\x9c\x01\n\x1dStartMaterializationOnlineJob\x12=.ai.h2o.featurestore.api.v1.StartMaterializationOnlineRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/api/v1/online:\x01*\x12\xa2\x01\n!GetMaterializationOnlineJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x39.ai.h2o.featurestore.api.v1.MaterializationOnlineResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/online/{job_id}\x12\x87\x01\n\x1dGetComputeStatisticsJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/compute-statistics/{job_id}\x12\x9b\x01\n,GetComputeRecommendationClassifiersJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\x12(/api/v1/compute-recommendations/{job_id}\x12\xc5\x01\n\x1cGenerateTransformationUpload\x12?.ai.h2o.featurestore.api.v1.GenerateTransformationUploadRequest\x1a@.ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/transformations:\x01*\x12\xb3\x01\n\x1dListRecommendationClassifiers\x12\x16.google.protobuf.Empty\x1a@.ai.h2o.featurestore.api.v1.ListRecommendationClassifierResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/api/v1/feature-sets/recommendations-classifiers\x12\xb8\x01\n\x1e\x43reateRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.CreateRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"0/api/v1/feature-sets/recommendations-classifiers:\x01*\x12\xbf\x01\n\x1eUpdateRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.UpdateRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\"B\x82\xd3\xe4\x93\x02<\x1a\x37/api/v1/feature-sets/recommendations-classifiers/{name}:\x01*\x12\xc7\x01\n\x1e\x44\x65leteRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.DeleteRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\"J\x82\xd3\xe4\x93\x02\x44*B/api/v1/feature-sets/recommendations-classifiers/{classifier_name}\x12\xaf\x01\n\x12GetRecommendations\x12\x34.ai.h2o.featurestore.api.v1.GetRecommendationRequest\x1a\x35.ai.h2o.featurestore.api.v1.GetRecommendationResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-sets/recommendations\x12p\n\x0cGetDashboard\x12\x16.google.protobuf.Empty\x1a-.ai.h2o.featurestore.api.v1.DashboardResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/dashboard\x12\x8e\x01\n\x0eSearchProjects\x12).ai.h2o.featurestore.api.v1.SearchRequest\x1a\x30.ai.h2o.featurestore.api.v1.ProjectSearchResults\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/search/projects\x12\x98\x01\n\x11SearchFeatureSets\x12).ai.h2o.featurestore.api.v1.SearchRequest\x1a\x33.ai.h2o.featurestore.api.v1.FeatureSetSearchResults\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/search/feature-sets\x12\x8d\x01\n\x0eSearchFeatures\x12).ai.h2o.featurestore.api.v1.SearchRequest\x1a\x30.ai.h2o.featurestore.api.v1.FeatureSearchResults\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/search/feature\x12\xad\x01\n\nGetFeature\x12-.ai.h2o.featurestore.api.v1.GetFeatureRequest\x1a+.ai.h2o.featurestore.api.v1.FeatureResponse\"C\x82\xd3\xe4\x93\x02=\x12;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}\x12\xa8\x01\n\x0bListFeature\x12/.ai.h2o.featurestore.api.v1.ListFeaturesRequest\x1a\x30.ai.h2o.featurestore.api.v1.ListFeaturesResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/feature-sets/{feature_set_id}/features\x12\xbc\x01\n\rUpdateFeature\x12\x30.ai.h2o.featurestore.api.v1.UpdateFeatureRequest\x1a\x31.ai.h2o.featurestore.api.v1.UpdateFeatureResponse\"F\x82\xd3\xe4\x93\x02@\x1a;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}:\x01*\x12\xbe\x01\n\x15GetListableFeatureSet\x12\x35.ai.h2o.featurestore.api.v1.ListableFeatureSetRequest\x1a\x36.ai.h2o.featurestore.api.v1.ListableFeatureSetResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/listable-feature-sets/{feature_set_id}\x12\x9f\x01\n\x11ScheduleIngestJob\x12/.ai.h2o.featurestore.api.v1.ScheduleTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/schedules/ingestion:\x01*\x12\x9e\x01\n\x12ListScheduledTasks\x12\x35.ai.h2o.featurestore.api.v1.ListScheduledTasksRequest\x1a\x36.ai.h2o.featurestore.api.v1.ListScheduledTasksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/schedules\x12\xa1\x01\n\x10GetScheduledTask\x12+.ai.h2o.featurestore.api.v1.ScheduledTaskId\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/schedules/{scheduled_task_id}\x12\x89\x01\n\x13\x44\x65leteScheduledTask\x12+.ai.h2o.featurestore.api.v1.ScheduledTaskId\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/api/v1/schedules/{scheduled_task_id}\x12\x97\x01\n\x13UpdateScheduledTask\x12\x36.ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/schedules/{scheduled_task_id}:\x01*\x12\xa9\x01\n\x16ScheduleLazyIngestTask\x12/.ai.h2o.featurestore.api.v1.ScheduleTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"+\x82\xd3\xe4\x93\x02%\" /api/v1/schedules/lazy/ingestion:\x01*\x12\xa4\x01\n\x13StartLazyIngestTask\x12-.ai.h2o.featurestore.api.v1.LazyIngestRequest\x1a..ai.h2o.featurestore.api.v1.LazyIngestResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/schedules/lazy/ingestion/start\x12\xb7\x01\n\x11GetLazyIngestTask\x12\x34.ai.h2o.featurestore.api.v1.GetLazyIngestTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/api/v1/schedules/lazy/ingestion/{feature_set_id}\x12\xc8\x01\n\x1bListTransformationFunctions\x12>.ai.h2o.featurestore.api.v1.ListTransformationFunctionsRequest\x1a?.ai.h2o.featurestore.api.v1.ListTransformationFunctionsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/transformation_functions\x12\xe1\x01\n\x19GetTransformationFunction\x12<.ai.h2o.featurestore.api.v1.GetTransformationFunctionRequest\x1a=.ai.h2o.featurestore.api.v1.GetTransformationFunctionResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/api/v1/transformation_functions/{transformation_function_name}\x12\x8a\x01\n\x14GetBackfillJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a,.ai.h2o.featurestore.api.v1.BackfillResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/api/v1/backfill/{job_id}B\x14\x42\x10\x43oreServiceProtoP\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetSearch__pb2.DESCRIPTOR,ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.DESCRIPTOR,ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2.DESCRIPTOR,ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2.DESCRIPTOR,ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.DESCRIPTOR,ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2.DESCRIPTOR,])

_JOBTYPE = _descriptor.EnumDescriptor(
  name='JobType',
  full_name='ai.h2o.featurestore.api.v1.JobType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Ingest', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Retrieve', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ExtractSchema', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Preview', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ComputeStatistics', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Revert', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MaterializationOnline', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ComputeRecommendationClassifiers', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CreateMLDataset', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FeatureViewRetrieveAsLinks', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FeatureViewRetrieveAsSpark', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Backfill', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=35528,
  serialized_end=35807,
)
_sym_db.RegisterEnumDescriptor(_JOBTYPE)

JobType = enum_type_wrapper.EnumTypeWrapper(_JOBTYPE)
_PERMISSIONTYPE = _descriptor.EnumDescriptor(
  name='PermissionType',
  full_name='ai.h2o.featurestore.api.v1.PermissionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Owner', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Editor', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Consumer', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SensitiveConsumer', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=35809,
  serialized_end=35885,
)
_sym_db.RegisterEnumDescriptor(_PERMISSIONTYPE)

PermissionType = enum_type_wrapper.EnumTypeWrapper(_PERMISSIONTYPE)
_ACTIVEPERMISSION = _descriptor.EnumDescriptor(
  name='ActivePermission',
  full_name='ai.h2o.featurestore.api.v1.ActivePermission',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_PERMISSION_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_PERMISSION_OWNER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_PERMISSION_EDITOR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_PERMISSION_CONSUMER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_PERMISSION_SENSITIVE_CONSUMER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=35888,
  serialized_end=36067,
)
_sym_db.RegisterEnumDescriptor(_ACTIVEPERMISSION)

ActivePermission = enum_type_wrapper.EnumTypeWrapper(_ACTIVEPERMISSION)
_FEATUREFILTEROPERATOR = _descriptor.EnumDescriptor(
  name='FeatureFilterOperator',
  full_name='ai.h2o.featurestore.api.v1.FeatureFilterOperator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_OPERATOR_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_OPERATOR_EQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_OPERATOR_LT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_OPERATOR_LE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_OPERATOR_GT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_OPERATOR_GE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_OPERATOR_NE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36070,
  serialized_end=36322,
)
_sym_db.RegisterEnumDescriptor(_FEATUREFILTEROPERATOR)

FeatureFilterOperator = enum_type_wrapper.EnumTypeWrapper(_FEATUREFILTEROPERATOR)
_FEATUREFILTERLOGICOPERATOR = _descriptor.EnumDescriptor(
  name='FeatureFilterLogicOperator',
  full_name='ai.h2o.featurestore.api.v1.FeatureFilterLogicOperator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_LOGIC_OPERATOR_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_LOGIC_OPERATOR_AND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_FILTER_LOGIC_OPERATOR_OR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36325,
  serialized_end=36473,
)
_sym_db.RegisterEnumDescriptor(_FEATUREFILTERLOGICOPERATOR)

FeatureFilterLogicOperator = enum_type_wrapper.EnumTypeWrapper(_FEATUREFILTERLOGICOPERATOR)
_FEATUREDATATYPE = _descriptor.EnumDescriptor(
  name='FeatureDataType',
  full_name='ai.h2o.featurestore.api.v1.FeatureDataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TinyInt', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SmallInt', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BigInt', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Int', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Float', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Double', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='String', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Binary', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Boolean', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Date', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Timestamp', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36476,
  serialized_end=36626,
)
_sym_db.RegisterEnumDescriptor(_FEATUREDATATYPE)

FeatureDataType = enum_type_wrapper.EnumTypeWrapper(_FEATUREDATATYPE)
_PROCESSINTERVALUNIT = _descriptor.EnumDescriptor(
  name='ProcessIntervalUnit',
  full_name='ai.h2o.featurestore.api.v1.ProcessIntervalUnit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOURS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAYS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINUTES', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECONDS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILLISECONDS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36628,
  serialized_end=36741,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINTERVALUNIT)

ProcessIntervalUnit = enum_type_wrapper.EnumTypeWrapper(_PROCESSINTERVALUNIT)
_TRANSFORMATIONTYPE = _descriptor.EnumDescriptor(
  name='TransformationType',
  full_name='ai.h2o.featurestore.api.v1.TransformationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TransformationUnknown', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TransformationMojo', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TransformationSparkPipeline', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36743,
  serialized_end=36847,
)
_sym_db.RegisterEnumDescriptor(_TRANSFORMATIONTYPE)

TransformationType = enum_type_wrapper.EnumTypeWrapper(_TRANSFORMATIONTYPE)
_RESOURCETYPE = _descriptor.EnumDescriptor(
  name='ResourceType',
  full_name='ai.h2o.featurestore.api.v1.ResourceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROJECT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36849,
  serialized_end=36893,
)
_sym_db.RegisterEnumDescriptor(_RESOURCETYPE)

ResourceType = enum_type_wrapper.EnumTypeWrapper(_RESOURCETYPE)
_PERMISSIONSTATE = _descriptor.EnumDescriptor(
  name='PermissionState',
  full_name='ai.h2o.featurestore.api.v1.PermissionState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REVOKED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROMOTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36895,
  serialized_end=36979,
)
_sym_db.RegisterEnumDescriptor(_PERMISSIONSTATE)

PermissionState = enum_type_wrapper.EnumTypeWrapper(_PERMISSIONSTATE)
_TASKTYPE = _descriptor.EnumDescriptor(
  name='TaskType',
  full_name='ai.h2o.featurestore.api.v1.TaskType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INGEST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAZY_INGEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36981,
  serialized_end=37020,
)
_sym_db.RegisterEnumDescriptor(_TASKTYPE)

TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
_UPDATABLEPROJECTFIELD = _descriptor.EnumDescriptor(
  name='UpdatableProjectField',
  full_name='ai.h2o.featurestore.api.v1.UpdatableProjectField',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROJECT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_LOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_SECRET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_DESCRIPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_CUSTOM_DATA', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=37023,
  serialized_end=37161,
)
_sym_db.RegisterEnumDescriptor(_UPDATABLEPROJECTFIELD)

UpdatableProjectField = enum_type_wrapper.EnumTypeWrapper(_UPDATABLEPROJECTFIELD)
_UPDATABLEFEATURESETFIELD = _descriptor.EnumDescriptor(
  name='UpdatableFeatureSetField',
  full_name='ai.h2o.featurestore.api.v1.UpdatableFeatureSetField',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_TAGS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_DATA_SOURCE_DOMAINS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_DESCRIPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_TYPE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_APPLICATION_NAME', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_APPLICATION_ID', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_DEPRECATED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_PROCESS_INTERVAL', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_PROCESS_INTERVAL_UNIT', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_FLOW', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_STATE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_SECRET', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_TTL_OFFLINE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_TTL_OFFLINE_INTERVAL', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_TTL_ONLINE', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_TTL_ONLINE_INTERVAL', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_CUSTOM_DATA', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_SPECIAL_DATA_LEGAL_APPROVED', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_SPECIAL_DATA_LEGAL_NOTES', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_ONLINE_NAMESPACE', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_ONLINE_TOPIC', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SET_ONLINE_CONNECTION_TYPE', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=37164,
  serialized_end=37917,
)
_sym_db.RegisterEnumDescriptor(_UPDATABLEFEATURESETFIELD)

UpdatableFeatureSetField = enum_type_wrapper.EnumTypeWrapper(_UPDATABLEFEATURESETFIELD)
_UPDATABLEFEATUREFIELD = _descriptor.EnumDescriptor(
  name='UpdatableFeatureField',
  full_name='ai.h2o.featurestore.api.v1.UpdatableFeatureField',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FEATURE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_STATUS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_TYPE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_IMPORTANCE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_CUSTOM_DATA', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_DESCRIPTION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SPECIAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_ANOMALY_DETECTION', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_CLASSIFIERS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=37920,
  serialized_end=38157,
)
_sym_db.RegisterEnumDescriptor(_UPDATABLEFEATUREFIELD)

UpdatableFeatureField = enum_type_wrapper.EnumTypeWrapper(_UPDATABLEFEATUREFIELD)
Unknown = 0
Ingest = 1
Retrieve = 2
ExtractSchema = 3
Preview = 4
ComputeStatistics = 5
Revert = 6
MaterializationOnline = 7
ComputeRecommendationClassifiers = 8
CreateMLDataset = 9
FeatureViewRetrieveAsLinks = 10
FeatureViewRetrieveAsSpark = 11
Backfill = 12
Owner = 0
Editor = 1
Consumer = 2
SensitiveConsumer = 3
ACTIVE_PERMISSION_NONE = 0
ACTIVE_PERMISSION_OWNER = 1
ACTIVE_PERMISSION_EDITOR = 2
ACTIVE_PERMISSION_CONSUMER = 3
ACTIVE_PERMISSION_SENSITIVE_CONSUMER = 4
FEATURE_FILTER_OPERATOR_UNKNOWN = 0
FEATURE_FILTER_OPERATOR_EQ = 1
FEATURE_FILTER_OPERATOR_LT = 2
FEATURE_FILTER_OPERATOR_LE = 3
FEATURE_FILTER_OPERATOR_GT = 4
FEATURE_FILTER_OPERATOR_GE = 5
FEATURE_FILTER_OPERATOR_NE = 6
FEATURE_FILTER_LOGIC_OPERATOR_UNKNOWN = 0
FEATURE_FILTER_LOGIC_OPERATOR_AND = 1
FEATURE_FILTER_LOGIC_OPERATOR_OR = 2
TinyInt = 0
SmallInt = 1
BigInt = 2
Int = 3
Float = 4
Double = 5
String = 6
Binary = 7
Boolean = 8
Date = 9
Timestamp = 10
UNDEFINED = 0
HOURS = 1
MONTHS = 2
DAYS = 3
MINUTES = 4
SECONDS = 5
MILLISECONDS = 6
TransformationUnknown = 0
TransformationMojo = 1
TransformationSparkPipeline = 2
PROJECT = 0
FEATURE_SET = 1
PENDING = 0
GRANTED = 1
REJECTED = 2
REVOKED = 3
PROMOTED = 4
INGEST = 0
LAZY_INGEST = 1
PROJECT_UNSPECIFIED = 0
PROJECT_LOCKED = 1
PROJECT_SECRET = 2
PROJECT_DESCRIPTION = 3
PROJECT_CUSTOM_DATA = 4
FEATURE_SET_UNSPECIFIED = 0
FEATURE_SET_TAGS = 1
FEATURE_SET_DATA_SOURCE_DOMAINS = 2
FEATURE_SET_DESCRIPTION = 3
FEATURE_SET_TYPE = 4
FEATURE_SET_APPLICATION_NAME = 5
FEATURE_SET_APPLICATION_ID = 6
FEATURE_SET_DEPRECATED = 7
FEATURE_SET_PROCESS_INTERVAL = 8
FEATURE_SET_PROCESS_INTERVAL_UNIT = 9
FEATURE_SET_FLOW = 10
FEATURE_SET_STATE = 11
FEATURE_SET_SECRET = 12
FEATURE_SET_TTL_OFFLINE = 13
FEATURE_SET_TTL_OFFLINE_INTERVAL = 14
FEATURE_SET_TTL_ONLINE = 15
FEATURE_SET_TTL_ONLINE_INTERVAL = 16
FEATURE_SET_CUSTOM_DATA = 17
FEATURE_SET_SPECIAL_DATA_LEGAL_APPROVED = 18
FEATURE_SET_SPECIAL_DATA_LEGAL_NOTES = 19
FEATURE_SET_ONLINE_NAMESPACE = 20
FEATURE_SET_ONLINE_TOPIC = 21
FEATURE_SET_ONLINE_CONNECTION_TYPE = 22
FEATURE_UNSPECIFIED = 0
FEATURE_STATUS = 1
FEATURE_TYPE = 2
FEATURE_IMPORTANCE = 3
FEATURE_CUSTOM_DATA = 4
FEATURE_DESCRIPTION = 5
FEATURE_SPECIAL = 6
FEATURE_ANOMALY_DETECTION = 7
FEATURE_CLASSIFIERS = 8


_MLDATASET_MLDATASETSTATE = _descriptor.EnumDescriptor(
  name='MLDatasetState',
  full_name='ai.h2o.featurestore.api.v1.MLDataset.MLDatasetState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ML_DATASET_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ML_DATASET_STATE_PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ML_DATASET_STATE_AVAILABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18175,
  serialized_end=18283,
)
_sym_db.RegisterEnumDescriptor(_MLDATASET_MLDATASETSTATE)


_FEATURECUSTOMDATAUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureCustomDataUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureCustomDataUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureCustomDataUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_feature_name', full_name='ai.h2o.featurestore.api.v1.FeatureCustomDataUpdateRequest.absolute_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureCustomDataUpdateRequest.new_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=668,
)


_IDENTITYPROVIDERDETAILS = _descriptor.Descriptor(
  name='IdentityProviderDetails',
  full_name='ai.h2o.featurestore.api.v1.IdentityProviderDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idp_meta_url', full_name='ai.h2o.featurestore.api.v1.IdentityProviderDetails.idp_meta_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ai.h2o.featurestore.api.v1.IdentityProviderDetails.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scopes', full_name='ai.h2o.featurestore.api.v1.IdentityProviderDetails.scopes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=670,
  serialized_end=752,
)


_GETWEBCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetWebConfigResponse',
  full_name='ai.h2o.featurestore.api.v1.GetWebConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipd_details', full_name='ai.h2o.featurestore.api.v1.GetWebConfigResponse.ipd_details', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_store_url', full_name='ai.h2o.featurestore.api.v1.GetWebConfigResponse.app_store_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=873,
)


_FEATURESETCUSTOMDATAUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetCustomDataUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetCustomDataUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetCustomDataUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetCustomDataUpdateRequest.new_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=876,
  serialized_end=1017,
)


_PROJECTCUSTOMDATAUPDATEREQUEST = _descriptor.Descriptor(
  name='ProjectCustomDataUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.ProjectCustomDataUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ProjectCustomDataUpdateRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.ProjectCustomDataUpdateRequest.new_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1019,
  serialized_end=1115,
)


_FEATURESETTYPEUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetTypeUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetTypeUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetTypeUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetTypeUpdateRequest.new_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1272,
)


_GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST = _descriptor.Descriptor(
  name='GetFeatureSetsLastMinorForCurrentMajorRequest',
  full_name='ai.h2o.featurestore.api.v1.GetFeatureSetsLastMinorForCurrentMajorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetsLastMinorForCurrentMajorRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1274,
  serialized_end=1383,
)


_FEATURETYPEUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureTypeUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureTypeUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureTypeUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_feature_name', full_name='ai.h2o.featurestore.api.v1.FeatureTypeUpdateRequest.absolute_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureTypeUpdateRequest.new_value', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1565,
)


_FEATUREDOUBLEFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureDoubleFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureDoubleFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureDoubleFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_feature_name', full_name='ai.h2o.featurestore.api.v1.FeatureDoubleFieldUpdateRequest.absolute_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureDoubleFieldUpdateRequest.new_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1713,
)


_FEATURESTRINGFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureStringFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_feature_name', full_name='ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest.absolute_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest.new_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1716,
  serialized_end=1861,
)


_FEATURESTRINGARRAYFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureStringArrayFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureStringArrayFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureStringArrayFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_feature_name', full_name='ai.h2o.featurestore.api.v1.FeatureStringArrayFieldUpdateRequest.absolute_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureStringArrayFieldUpdateRequest.new_value', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1864,
  serialized_end=2014,
)


_FEATUREBOOLEANFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureBooleanFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureBooleanFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureBooleanFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_feature_name', full_name='ai.h2o.featurestore.api.v1.FeatureBooleanFieldUpdateRequest.absolute_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureBooleanFieldUpdateRequest.new_value', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2017,
  serialized_end=2163,
)


_FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest.new_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2166,
  serialized_end=2355,
)


_FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest.new_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2358,
  serialized_end=2549,
)


_FEATURESETINTFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetIntFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest.new_value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2551,
  serialized_end=2665,
)


_FEATURESETPROCESSINTERVALUNITUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetProcessIntervalUnitUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetProcessIntervalUnitUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetProcessIntervalUnitUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetProcessIntervalUnitUpdateRequest.new_value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2668,
  serialized_end=2842,
)


_FEATURESETSTRINGARRAYFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetStringArrayFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest.new_value', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2844,
  serialized_end=2966,
)


_FEATURESETBOOLEANFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetBooleanFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest.new_value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2968,
  serialized_end=3086,
)


_FEATURESETSTRINGFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetStringFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest.new_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3088,
  serialized_end=3205,
)


_FEATURESETUSERFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='FeatureSetUserFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetUserFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ai.h2o.featurestore.api.v1.FeatureSetUserFieldUpdateRequest.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.FeatureSetUserFieldUpdateRequest.new_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3208,
  serialized_end=3366,
)


_PROJECTBOOLEANFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='ProjectBooleanFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest.new_value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3368,
  serialized_end=3441,
)


_PROJECTSTRINGFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='ProjectStringFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.ProjectStringFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ProjectStringFieldUpdateRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.ProjectStringFieldUpdateRequest.new_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3443,
  serialized_end=3515,
)


_PROJECTUSERFIELDUPDATEREQUEST = _descriptor.Descriptor(
  name='ProjectUserFieldUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.ProjectUserFieldUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ProjectUserFieldUpdateRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='ai.h2o.featurestore.api.v1.ProjectUserFieldUpdateRequest.new_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3517,
  serialized_end=3630,
)


_FEATURESETEXISTSREQUEST = _descriptor.Descriptor(
  name='FeatureSetExistsRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.FeatureSetExistsRequest.project_id', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.FeatureSetExistsRequest.feature_set_id', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3632,
  serialized_end=3701,
)


_GETINGESTHISTORYREQUEST = _descriptor.Descriptor(
  name='GetIngestHistoryRequest',
  full_name='ai.h2o.featurestore.api.v1.GetIngestHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.GetIngestHistoryRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3703,
  serialized_end=3789,
)


_PROJECTEXISTSREQUEST = _descriptor.Descriptor(
  name='ProjectExistsRequest',
  full_name='ai.h2o.featurestore.api.v1.ProjectExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ProjectExistsRequest.project_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3791,
  serialized_end=3833,
)


_EXISTSRESPONSE = _descriptor.Descriptor(
  name='ExistsResponse',
  full_name='ai.h2o.featurestore.api.v1.ExistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exists', full_name='ai.h2o.featurestore.api.v1.ExistsResponse.exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3835,
  serialized_end=3867,
)


_PROJECTSDEFAULTRESPONSE = _descriptor.Descriptor(
  name='ProjectsDefaultResponse',
  full_name='ai.h2o.featurestore.api.v1.ProjectsDefaultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locked', full_name='ai.h2o.featurestore.api.v1.ProjectsDefaultResponse.locked', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3869,
  serialized_end=3910,
)


_HASPERMISSIONTORETRIEVEREQUEST = _descriptor.Descriptor(
  name='HasPermissionToRetrieveRequest',
  full_name='ai.h2o.featurestore.api.v1.HasPermissionToRetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_name', full_name='ai.h2o.featurestore.api.v1.HasPermissionToRetrieveRequest.project_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='ai.h2o.featurestore.api.v1.HasPermissionToRetrieveRequest.feature_set_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3912,
  serialized_end=3992,
)


_HASPERMISSIONTORETRIEVERESPONSE = _descriptor.Descriptor(
  name='HasPermissionToRetrieveResponse',
  full_name='ai.h2o.featurestore.api.v1.HasPermissionToRetrieveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_retrieve_permission', full_name='ai.h2o.featurestore.api.v1.HasPermissionToRetrieveResponse.has_retrieve_permission', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3994,
  serialized_end=4060,
)


_STARTREVERTINGESTJOBREQUEST = _descriptor.Descriptor(
  name='StartRevertIngestJobRequest',
  full_name='ai.h2o.featurestore.api.v1.StartRevertIngestJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.StartRevertIngestJobRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_id', full_name='ai.h2o.featurestore.api.v1.StartRevertIngestJobRequest.ingest_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4062,
  serialized_end=4171,
)


_ONLINERETRIEVEMETA = _descriptor.Descriptor(
  name='OnlineRetrieveMeta',
  full_name='ai.h2o.featurestore.api.v1.OnlineRetrieveMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_online_url', full_name='ai.h2o.featurestore.api.v1.OnlineRetrieveMeta.base_online_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='ai.h2o.featurestore.api.v1.OnlineRetrieveMeta.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='ai.h2o.featurestore.api.v1.OnlineRetrieveMeta.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='ai.h2o.featurestore.api.v1.OnlineRetrieveMeta.is_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4173,
  serialized_end=4274,
)


_REFRESHTOKENREQUEST = _descriptor.Descriptor(
  name='RefreshTokenRequest',
  full_name='ai.h2o.featurestore.api.v1.RefreshTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='ai.h2o.featurestore.api.v1.RefreshTokenRequest.refresh_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4276,
  serialized_end=4320,
)


_GETUSERBYMAILREQUEST = _descriptor.Descriptor(
  name='GetUserByMailRequest',
  full_name='ai.h2o.featurestore.api.v1.GetUserByMailRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='ai.h2o.featurestore.api.v1.GetUserByMailRequest.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4322,
  serialized_end=4359,
)


_GETUSERBYMAILRESPONSE = _descriptor.Descriptor(
  name='GetUserByMailResponse',
  full_name='ai.h2o.featurestore.api.v1.GetUserByMailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.GetUserByMailResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4361,
  serialized_end=4441,
)


_TOKENREQUEST = _descriptor.Descriptor(
  name='TokenRequest',
  full_name='ai.h2o.featurestore.api.v1.TokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token_id', full_name='ai.h2o.featurestore.api.v1.TokenRequest.token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4443,
  serialized_end=4475,
)


_GENERATETOKENREQUEST = _descriptor.Descriptor(
  name='GenerateTokenRequest',
  full_name='ai.h2o.featurestore.api.v1.GenerateTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.GenerateTokenRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.GenerateTokenRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_date', full_name='ai.h2o.featurestore.api.v1.GenerateTokenRequest.expiry_date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4477,
  serialized_end=4583,
)


_TOKENRESPONSE = _descriptor.Descriptor(
  name='TokenResponse',
  full_name='ai.h2o.featurestore.api.v1.TokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.h2o.featurestore.api.v1.TokenResponse.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4585,
  serialized_end=4664,
)


_LISTTOKENSRESPONSE = _descriptor.Descriptor(
  name='ListTokensResponse',
  full_name='ai.h2o.featurestore.api.v1.ListTokensResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='ai.h2o.featurestore.api.v1.ListTokensResponse.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4666,
  serialized_end=4751,
)


_RAWTOKENRESPONSE = _descriptor.Descriptor(
  name='RawTokenResponse',
  full_name='ai.h2o.featurestore.api.v1.RawTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ai.h2o.featurestore.api.v1.RawTokenResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4753,
  serialized_end=4786,
)


_LISTJOBSREQUEST = _descriptor.Descriptor(
  name='ListJobsRequest',
  full_name='ai.h2o.featurestore.api.v1.ListJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='ai.h2o.featurestore.api.v1.ListJobsRequest.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.ListJobsRequest.feature_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_type', full_name='ai.h2o.featurestore.api.v1.ListJobsRequest.job_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4789,
  serialized_end=4938,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
  name='ListJobsResponse',
  full_name='ai.h2o.featurestore.api.v1.ListJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobs', full_name='ai.h2o.featurestore.api.v1.ListJobsResponse.jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4940,
  serialized_end=5005,
)


_FEATURESETSCHEMACOMPATIBILITYREQUEST = _descriptor.Descriptor(
  name='FeatureSetSchemaCompatibilityRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_schema', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest.original_schema', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_schema', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest.new_schema', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compare_data_types', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest.compare_data_types', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5008,
  serialized_end=5205,
)


_FEATURESETSCHEMACOMPATIBILITYRESPONSE = _descriptor.Descriptor(
  name='FeatureSetSchemaCompatibilityResponse',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_compatible', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityResponse.is_compatible', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5207,
  serialized_end=5269,
)


_FEATURESETSCHEMAPATCHREQUEST = _descriptor.Descriptor(
  name='FeatureSetSchemaPatchRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_schema', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest.original_schema', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_schema', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest.new_schema', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compare_data_types', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest.compare_data_types', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5272,
  serialized_end=5461,
)


_FEATURESETSCHEMAPATCHRESPONSE = _descriptor.Descriptor(
  name='FeatureSetSchemaPatchResponse',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schema', full_name='ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchResponse.schema', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5463,
  serialized_end=5553,
)


_JOBID = _descriptor.Descriptor(
  name='JobId',
  full_name='ai.h2o.featurestore.api.v1.JobId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ai.h2o.featurestore.api.v1.JobId.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5555,
  serialized_end=5578,
)


_GETRECOMMENDATIONREQUEST = _descriptor.Descriptor(
  name='GetRecommendationRequest',
  full_name='ai.h2o.featurestore.api.v1.GetRecommendationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.GetRecommendationRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5580,
  serialized_end=5667,
)


_GETRECOMMENDATIONRESPONSE_JOIN = _descriptor.Descriptor(
  name='Join',
  full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse.Join',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='classifier', full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse.Join.classifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse.Join.columns', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5777,
  serialized_end=5820,
)

_GETRECOMMENDATIONRESPONSE_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse.Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_feature_set', full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse.Match.target_feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joins', full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse.Match.joins', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5823,
  serialized_end=5973,
)

_GETRECOMMENDATIONRESPONSE = _descriptor.Descriptor(
  name='GetRecommendationResponse',
  full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matches', full_name='ai.h2o.featurestore.api.v1.GetRecommendationResponse.matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETRECOMMENDATIONRESPONSE_JOIN, _GETRECOMMENDATIONRESPONSE_MATCH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5670,
  serialized_end=5973,
)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='ai.h2o.featurestore.api.v1.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ai.h2o.featurestore.api.v1.Job.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_type', full_name='ai.h2o.featurestore.api.v1.Job.job_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done', full_name='ai.h2o.featurestore.api.v1.Job.done', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='childJobIds', full_name='ai.h2o.featurestore.api.v1.Job.childJobIds', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5975,
  serialized_end=6086,
)


_JOBPROGRESSINPUT = _descriptor.Descriptor(
  name='JobProgressInput',
  full_name='ai.h2o.featurestore.api.v1.JobProgressInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ai.h2o.featurestore.api.v1.JobProgressInput.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_index', full_name='ai.h2o.featurestore.api.v1.JobProgressInput.next_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6088,
  serialized_end=6142,
)


_JOBPROGRESSOUTPUT_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='ai.h2o.featurestore.api.v1.JobProgressOutput.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ai.h2o.featurestore.api.v1.JobProgressOutput.Progress.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_in_seconds', full_name='ai.h2o.featurestore.api.v1.JobProgressOutput.Progress.duration_in_seconds', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ai.h2o.featurestore.api.v1.JobProgressOutput.Progress.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6240,
  serialized_end=6343,
)

_JOBPROGRESSOUTPUT = _descriptor.Descriptor(
  name='JobProgressOutput',
  full_name='ai.h2o.featurestore.api.v1.JobProgressOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='progress', full_name='ai.h2o.featurestore.api.v1.JobProgressOutput.progress', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JOBPROGRESSOUTPUT_PROGRESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6145,
  serialized_end=6343,
)


_FEATURESETPERMISSIONREQUEST = _descriptor.Descriptor(
  name='FeatureSetPermissionRequest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_emails', full_name='ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest.user_emails', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest.permission', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6346,
  serialized_end=6521,
)


_PROJECTPERMISSIONREQUEST = _descriptor.Descriptor(
  name='ProjectPermissionRequest',
  full_name='ai.h2o.featurestore.api.v1.ProjectPermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.ProjectPermissionRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_emails', full_name='ai.h2o.featurestore.api.v1.ProjectPermissionRequest.user_emails', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.ProjectPermissionRequest.permission', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6524,
  serialized_end=6689,
)


_STARTEXTRACTSCHEMAJOBREQUEST = _descriptor.Descriptor(
  name='StartExtractSchemaJobRequest',
  full_name='ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_data', full_name='ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest.raw_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_from', full_name='ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest.derived_from', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cred', full_name='ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest.cred', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6692,
  serialized_end=6924,
)


_EXTRACTSCHEMARESPONSE = _descriptor.Descriptor(
  name='ExtractSchemaResponse',
  full_name='ai.h2o.featurestore.api.v1.ExtractSchemaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schema', full_name='ai.h2o.featurestore.api.v1.ExtractSchemaResponse.schema', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_from', full_name='ai.h2o.featurestore.api.v1.ExtractSchemaResponse.derived_from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6927,
  serialized_end=7079,
)


_LISTFEATURESETSVERSIONREQUEST = _descriptor.Descriptor(
  name='ListFeatureSetsVersionRequest',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsVersionRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7081,
  serialized_end=7173,
)


_FEATURESETRESPONSE = _descriptor.Descriptor(
  name='FeatureSetResponse',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.FeatureSetResponse.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='ai.h2o.featurestore.api.v1.FeatureSetResponse.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7176,
  serialized_end=7305,
)


_UPDATEFEATURESETRESPONSE = _descriptor.Descriptor(
  name='UpdateFeatureSetResponse',
  full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='updated_feature_set', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetResponse.updated_feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7307,
  serialized_end=7402,
)


_UPDATEPROJECTRESPONSE = _descriptor.Descriptor(
  name='UpdateProjectResponse',
  full_name='ai.h2o.featurestore.api.v1.UpdateProjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='updated_project', full_name='ai.h2o.featurestore.api.v1.UpdateProjectResponse.updated_project', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7404,
  serialized_end=7489,
)


_UPDATEFEATURERESPONSE = _descriptor.Descriptor(
  name='UpdateFeatureResponse',
  full_name='ai.h2o.featurestore.api.v1.UpdateFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='updated_feature_set', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureResponse.updated_feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_feature', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureResponse.updated_feature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7492,
  serialized_end=7646,
)


_PROJECTRESPONSE = _descriptor.Descriptor(
  name='ProjectResponse',
  full_name='ai.h2o.featurestore.api.v1.ProjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.ProjectResponse.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7648,
  serialized_end=7719,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='ai.h2o.featurestore.api.v1.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_url', full_name='ai.h2o.featurestore.api.v1.LoginResponse.login_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='ai.h2o.featurestore.api.v1.LoginResponse.refresh_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='ai.h2o.featurestore.api.v1.LoginResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7721,
  serialized_end=7794,
)


_GETACTIVEUSERRESPONSE = _descriptor.Descriptor(
  name='GetActiveUserResponse',
  full_name='ai.h2o.featurestore.api.v1.GetActiveUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.GetActiveUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7796,
  serialized_end=7876,
)


_GETPROJECTREQUEST = _descriptor.Descriptor(
  name='GetProjectRequest',
  full_name='ai.h2o.featurestore.api.v1.GetProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_name', full_name='ai.h2o.featurestore.api.v1.GetProjectRequest.project_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7878,
  serialized_end=7919,
)


_DELETEFEATURESETREQUEST = _descriptor.Descriptor(
  name='DeleteFeatureSetRequest',
  full_name='ai.h2o.featurestore.api.v1.DeleteFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.DeleteFeatureSetRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7921,
  serialized_end=8007,
)


_LOGOUTREQUEST = _descriptor.Descriptor(
  name='LogoutRequest',
  full_name='ai.h2o.featurestore.api.v1.LogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='ai.h2o.featurestore.api.v1.LogoutRequest.refresh_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8009,
  serialized_end=8047,
)


_USERBASICINFO = _descriptor.Descriptor(
  name='UserBasicInfo',
  full_name='ai.h2o.featurestore.api.v1.UserBasicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.UserBasicInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.UserBasicInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='ai.h2o.featurestore.api.v1.UserBasicInfo.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8049,
  serialized_end=8105,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='ai.h2o.featurestore.api.v1.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_basic_info', full_name='ai.h2o.featurestore.api.v1.User.user_basic_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='ai.h2o.featurestore.api.v1.User.admin', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8107,
  serialized_end=8196,
)


_ACCESSTOKENRESPONSE = _descriptor.Descriptor(
  name='AccessTokenResponse',
  full_name='ai.h2o.featurestore.api.v1.AccessTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='ai.h2o.featurestore.api.v1.AccessTokenResponse.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='ai.h2o.featurestore.api.v1.AccessTokenResponse.refresh_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='ai.h2o.featurestore.api.v1.AccessTokenResponse.expires_in', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='ai.h2o.featurestore.api.v1.AccessTokenResponse.scope', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_type', full_name='ai.h2o.featurestore.api.v1.AccessTokenResponse.token_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8198,
  serialized_end=8319,
)


_DELETEPROJECTREQUEST = _descriptor.Descriptor(
  name='DeleteProjectRequest',
  full_name='ai.h2o.featurestore.api.v1.DeleteProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.DeleteProjectRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8321,
  serialized_end=8397,
)


_UPDATEPROJECTMETADATAREQUEST = _descriptor.Descriptor(
  name='UpdateProjectMetadataRequest',
  full_name='ai.h2o.featurestore.api.v1.UpdateProjectMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.UpdateProjectMetadataRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8399,
  serialized_end=8483,
)


_CREATEPROJECTREQUEST = _descriptor.Descriptor(
  name='CreateProjectRequest',
  full_name='ai.h2o.featurestore.api.v1.CreateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_name', full_name='ai.h2o.featurestore.api.v1.CreateProjectRequest.project_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.CreateProjectRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='ai.h2o.featurestore.api.v1.CreateProjectRequest.secret', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='ai.h2o.featurestore.api.v1.CreateProjectRequest.locked', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.CreateProjectRequest.custom_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8486,
  serialized_end=8629,
)


_CREATEPROJECTRESPONSE = _descriptor.Descriptor(
  name='CreateProjectResponse',
  full_name='ai.h2o.featurestore.api.v1.CreateProjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.CreateProjectResponse.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='already_exists', full_name='ai.h2o.featurestore.api.v1.CreateProjectResponse.already_exists', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8631,
  serialized_end=8732,
)


_LISTPROJECTSRESPONSE = _descriptor.Descriptor(
  name='ListProjectsResponse',
  full_name='ai.h2o.featurestore.api.v1.ListProjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='ai.h2o.featurestore.api.v1.ListProjectsResponse.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8734,
  serialized_end=8811,
)


_GETINGESTHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetIngestHistoryResponse',
  full_name='ai.h2o.featurestore.api.v1.GetIngestHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingest_history', full_name='ai.h2o.featurestore.api.v1.GetIngestHistoryResponse.ingest_history', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8813,
  serialized_end=8909,
)


_LISTFEATURESETSACROSSPROJECTSREQUEST = _descriptor.Descriptor(
  name='ListFeatureSetsAcrossProjectsRequest',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsAcrossProjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_names', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsAcrossProjectsRequest.project_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsAcrossProjectsRequest.query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8911,
  serialized_end=9022,
)


_LISTFEATURESETSPAGEREQUEST = _descriptor.Descriptor(
  name='ListFeatureSetsPageRequest',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_names', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest.project_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest.query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9025,
  serialized_end=9165,
)


_LISTFEATURESETSPAGERESPONSE = _descriptor.Descriptor(
  name='ListFeatureSetsPageResponse',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_sets', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageResponse.feature_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPageResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9167,
  serialized_end=9283,
)


_AWSCREDENTIALS = _descriptor.Descriptor(
  name='AWSCredentials',
  full_name='ai.h2o.featurestore.api.v1.AWSCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='ai.h2o.featurestore.api.v1.AWSCredentials.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret_token', full_name='ai.h2o.featurestore.api.v1.AWSCredentials.secret_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='ai.h2o.featurestore.api.v1.AWSCredentials.region', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_name', full_name='ai.h2o.featurestore.api.v1.AWSCredentials.bucket_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='ai.h2o.featurestore.api.v1.AWSCredentials.endpoint', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role_arn', full_name='ai.h2o.featurestore.api.v1.AWSCredentials.role_arn', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9286,
  serialized_end=9419,
)


_AZURECREDENTIALS = _descriptor.Descriptor(
  name='AzureCredentials',
  full_name='ai.h2o.featurestore.api.v1.AzureCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_name', full_name='ai.h2o.featurestore.api.v1.AzureCredentials.account_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_key', full_name='ai.h2o.featurestore.api.v1.AzureCredentials.account_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sas_token', full_name='ai.h2o.featurestore.api.v1.AzureCredentials.sas_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sas_container', full_name='ai.h2o.featurestore.api.v1.AzureCredentials.sas_container', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_client_id', full_name='ai.h2o.featurestore.api.v1.AzureCredentials.sp_client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_tenant_id', full_name='ai.h2o.featurestore.api.v1.AzureCredentials.sp_tenant_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_secret', full_name='ai.h2o.featurestore.api.v1.AzureCredentials.sp_secret', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9422,
  serialized_end=9588,
)


_SNOWFLAKECREDENTIALS = _descriptor.Descriptor(
  name='SnowflakeCredentials',
  full_name='ai.h2o.featurestore.api.v1.SnowflakeCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.SnowflakeCredentials.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='ai.h2o.featurestore.api.v1.SnowflakeCredentials.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9590,
  serialized_end=9644,
)


_JDBCCREDENTIALS = _descriptor.Descriptor(
  name='JDBCCredentials',
  full_name='ai.h2o.featurestore.api.v1.JDBCCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.JDBCCredentials.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='ai.h2o.featurestore.api.v1.JDBCCredentials.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9646,
  serialized_end=9695,
)


_CREDENTIALS = _descriptor.Descriptor(
  name='Credentials',
  full_name='ai.h2o.featurestore.api.v1.Credentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='ai.h2o.featurestore.api.v1.Credentials.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azure', full_name='ai.h2o.featurestore.api.v1.Credentials.azure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snowflake', full_name='ai.h2o.featurestore.api.v1.Credentials.snowflake', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jdbc_database', full_name='ai.h2o.featurestore.api.v1.Credentials.jdbc_database', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9698,
  serialized_end=9972,
)


_LISTFEATURESETSRESPONSE = _descriptor.Descriptor(
  name='ListFeatureSetsResponse',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_sets', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsResponse.feature_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9974,
  serialized_end=10061,
)


_LISTFEATURESETVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListFeatureSetVersionsResponse',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureSetVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetVersionsResponse.versions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10063,
  serialized_end=10171,
)


_FEATURESETVERSIONDESCRIPTION = _descriptor.Descriptor(
  name='FeatureSetVersionDescription',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetVersionDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.FeatureSetVersionDescription.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_change', full_name='ai.h2o.featurestore.api.v1.FeatureSetVersionDescription.version_change', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='ai.h2o.featurestore.api.v1.FeatureSetVersionDescription.created_date_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10173,
  serialized_end=10299,
)


_GETFEATURESETREQUEST = _descriptor.Descriptor(
  name='GetFeatureSetRequest',
  full_name='ai.h2o.featurestore.api.v1.GetFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetRequest.feature_set_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetRequest.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10301,
  serialized_end=10420,
)


_STARTINGESTJOBREQUEST = _descriptor.Descriptor(
  name='StartIngestJobRequest',
  full_name='ai.h2o.featurestore.api.v1.StartIngestJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.StartIngestJobRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cred', full_name='ai.h2o.featurestore.api.v1.StartIngestJobRequest.cred', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source', full_name='ai.h2o.featurestore.api.v1.StartIngestJobRequest.data_source', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10423,
  serialized_end=10640,
)


_INGESTRESPONSE_INGESTMETA = _descriptor.Descriptor(
  name='IngestMeta',
  full_name='ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_location', full_name='ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta.cache_location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_cache_location', full_name='ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta.raw_cache_location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingestion_timestamp', full_name='ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta.ingestion_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_scope', full_name='ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta.ingest_scope', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10792,
  serialized_end=10987,
)

_INGESTRESPONSE = _descriptor.Descriptor(
  name='IngestResponse',
  full_name='ai.h2o.featurestore.api.v1.IngestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='ai.h2o.featurestore.api.v1.IngestResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.IngestResponse.feature_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INGESTRESPONSE_INGESTMETA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10643,
  serialized_end=10987,
)


_RETRIEVEREQUEST = _descriptor.Descriptor(
  name='RetrieveRequest',
  full_name='ai.h2o.featurestore.api.v1.RetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.RetrieveRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='ai.h2o.featurestore.api.v1.RetrieveRequest.start_date_time', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='ai.h2o.featurestore.api.v1.RetrieveRequest.end_date_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_id', full_name='ai.h2o.featurestore.api.v1.RetrieveRequest.ingest_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.RetrieveRequest.session_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10990,
  serialized_end=11155,
)


_RETRIEVEASLINKSRESPONSE = _descriptor.Descriptor(
  name='RetrieveAsLinksResponse',
  full_name='ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_links', full_name='ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse.download_links', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieve_scope', full_name='ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse.retrieve_scope', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieve_job_executed', full_name='ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse.retrieve_job_executed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11158,
  serialized_end=11297,
)


_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11532,
  serialized_end=11578,
)

_RETRIEVEASSPARKRESPONSE = _descriptor.Descriptor(
  name='RetrieveAsSparkResponse',
  full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_path', full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.cache_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.options', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieve_scope', full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.retrieve_scope', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.session_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_version', full_name='ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.delta_version', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11300,
  serialized_end=11578,
)


_PREVIEWREQUEST = _descriptor.Descriptor(
  name='PreviewRequest',
  full_name='ai.h2o.featurestore.api.v1.PreviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.PreviewRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11580,
  serialized_end=11657,
)


_STARTMATERIALIZATIONONLINEREQUEST = _descriptor.Descriptor(
  name='StartMaterializationOnlineRequest',
  full_name='ai.h2o.featurestore.api.v1.StartMaterializationOnlineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.StartMaterializationOnlineRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11659,
  serialized_end=11755,
)


_MATERIALIZATIONONLINERESPONSE = _descriptor.Descriptor(
  name='MaterializationOnlineResponse',
  full_name='ai.h2o.featurestore.api.v1.MaterializationOnlineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_scope', full_name='ai.h2o.featurestore.api.v1.MaterializationOnlineResponse.materialization_scope', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_records', full_name='ai.h2o.featurestore.api.v1.MaterializationOnlineResponse.num_records', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11757,
  serialized_end=11875,
)


_INGESTWRITECREDENTIALREQUEST = _descriptor.Descriptor(
  name='IngestWriteCredentialRequest',
  full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11877,
  serialized_end=11927,
)


_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11532,
  serialized_end=11578,
)

_INGESTWRITECREDENTIALRESPONSE = _descriptor.Descriptor(
  name='IngestWriteCredentialResponse',
  full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.options', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11930,
  serialized_end=12132,
)


_RAWDATALOCATION = _descriptor.Descriptor(
  name='RawDataLocation',
  full_name='ai.h2o.featurestore.api.v1.RawDataLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='csv', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.csv', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.parquet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snowflake', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.snowflake', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jdbc', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.jdbc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.json', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_table', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.delta_table', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='csv_folder', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.csv_folder', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet_folder', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.parquet_folder', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_folder', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.json_folder', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_parquet', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.temp_parquet', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_source', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.online_source', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='ai.h2o.featurestore.api.v1.RawDataLocation.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12135,
  serialized_end=12884,
)


_ONLINESOURCESPEC = _descriptor.Descriptor(
  name='OnlineSourceSpec',
  full_name='ai.h2o.featurestore.api.v1.OnlineSourceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='absolute_json_folder_path', full_name='ai.h2o.featurestore.api.v1.OnlineSourceSpec.absolute_json_folder_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12886,
  serialized_end=12939,
)


_CSVFILESPEC = _descriptor.Descriptor(
  name='CSVFileSpec',
  full_name='ai.h2o.featurestore.api.v1.CSVFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.CSVFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delimiter', full_name='ai.h2o.featurestore.api.v1.CSVFileSpec.delimiter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12941,
  serialized_end=12987,
)


_JSONFILESPEC = _descriptor.Descriptor(
  name='JSONFileSpec',
  full_name='ai.h2o.featurestore.api.v1.JSONFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.JSONFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiline', full_name='ai.h2o.featurestore.api.v1.JSONFileSpec.multiline', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12989,
  serialized_end=13036,
)


_PARQUETFILESPEC = _descriptor.Descriptor(
  name='ParquetFileSpec',
  full_name='ai.h2o.featurestore.api.v1.ParquetFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.ParquetFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13038,
  serialized_end=13069,
)


_TEMPPARQUETFILESPEC = _descriptor.Descriptor(
  name='TempParquetFileSpec',
  full_name='ai.h2o.featurestore.api.v1.TempParquetFileSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.TempParquetFileSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13071,
  serialized_end=13106,
)


_PROXY = _descriptor.Descriptor(
  name='Proxy',
  full_name='ai.h2o.featurestore.api.v1.Proxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='ai.h2o.featurestore.api.v1.Proxy.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='ai.h2o.featurestore.api.v1.Proxy.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.Proxy.user', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='ai.h2o.featurestore.api.v1.Proxy.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13108,
  serialized_end=13175,
)


_SNOWFLAKETABLESPEC = _descriptor.Descriptor(
  name='SnowflakeTableSpec',
  full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.database', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.query', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warehouse', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.warehouse', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.schema', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insecure', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.insecure', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.proxy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.role', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='ai.h2o.featurestore.api.v1.SnowflakeTableSpec.account', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13178,
  serialized_end=13393,
)


_JDBCTABLESPEC = _descriptor.Descriptor(
  name='JDBCTableSpec',
  full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.query', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_url', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.connection_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_partitions', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.num_partitions', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_column', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.partition_column', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower_bound', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.lower_bound', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper_bound', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.upper_bound', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fetch_size', full_name='ai.h2o.featurestore.api.v1.JDBCTableSpec.fetch_size', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13396,
  serialized_end=13577,
)


_DELTATABLESPEC = _descriptor.Descriptor(
  name='DeltaTableSpec',
  full_name='ai.h2o.featurestore.api.v1.DeltaTableSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.DeltaTableSpec.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.DeltaTableSpec.version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ai.h2o.featurestore.api.v1.DeltaTableSpec.timestamp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='ai.h2o.featurestore.api.v1.DeltaTableSpec.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13579,
  serialized_end=13697,
)


_CSVFOLDERSPEC = _descriptor.Descriptor(
  name='CSVFolderSpec',
  full_name='ai.h2o.featurestore.api.v1.CSVFolderSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_folder', full_name='ai.h2o.featurestore.api.v1.CSVFolderSpec.root_folder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_pattern', full_name='ai.h2o.featurestore.api.v1.CSVFolderSpec.filter_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delimiter', full_name='ai.h2o.featurestore.api.v1.CSVFolderSpec.delimiter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13699,
  serialized_end=13778,
)


_PARQUETFOLDERSPEC = _descriptor.Descriptor(
  name='ParquetFolderSpec',
  full_name='ai.h2o.featurestore.api.v1.ParquetFolderSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_folder', full_name='ai.h2o.featurestore.api.v1.ParquetFolderSpec.root_folder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_pattern', full_name='ai.h2o.featurestore.api.v1.ParquetFolderSpec.filter_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13780,
  serialized_end=13844,
)


_JSONFOLDERSPEC = _descriptor.Descriptor(
  name='JSONFolderSpec',
  full_name='ai.h2o.featurestore.api.v1.JSONFolderSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_folder', full_name='ai.h2o.featurestore.api.v1.JSONFolderSpec.root_folder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_pattern', full_name='ai.h2o.featurestore.api.v1.JSONFolderSpec.filter_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiline', full_name='ai.h2o.featurestore.api.v1.JSONFolderSpec.multiline', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13846,
  serialized_end=13926,
)


_MOJOTRANSFORMATION = _descriptor.Descriptor(
  name='MojoTransformation',
  full_name='ai.h2o.featurestore.api.v1.MojoTransformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ai.h2o.featurestore.api.v1.MojoTransformation.filename', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13928,
  serialized_end=13966,
)


_SPARKPIPELINETRANSFORMATION = _descriptor.Descriptor(
  name='SparkPipelineTransformation',
  full_name='ai.h2o.featurestore.api.v1.SparkPipelineTransformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ai.h2o.featurestore.api.v1.SparkPipelineTransformation.filename', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13968,
  serialized_end=14015,
)


_JOINTRANSFORMATION = _descriptor.Descriptor(
  name='JoinTransformation',
  full_name='ai.h2o.featurestore.api.v1.JoinTransformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_key', full_name='ai.h2o.featurestore.api.v1.JoinTransformation.left_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_key', full_name='ai.h2o.featurestore.api.v1.JoinTransformation.right_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14017,
  serialized_end=14074,
)


_VERSIONEDID = _descriptor.Descriptor(
  name='VersionedId',
  full_name='ai.h2o.featurestore.api.v1.VersionedId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.VersionedId.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major_version', full_name='ai.h2o.featurestore.api.v1.VersionedId.major_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14076,
  serialized_end=14124,
)


_TRANSFORMATION = _descriptor.Descriptor(
  name='Transformation',
  full_name='ai.h2o.featurestore.api.v1.Transformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mojo', full_name='ai.h2o.featurestore.api.v1.Transformation.mojo', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_pipeline', full_name='ai.h2o.featurestore.api.v1.Transformation.spark_pipeline', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join', full_name='ai.h2o.featurestore.api.v1.Transformation.join', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.Transformation.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=14127,
  serialized_end=14363,
)


_DERIVEDINFORMATION = _descriptor.Descriptor(
  name='DerivedInformation',
  full_name='ai.h2o.featurestore.api.v1.DerivedInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_ids', full_name='ai.h2o.featurestore.api.v1.DerivedInformation.feature_set_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformation', full_name='ai.h2o.featurestore.api.v1.DerivedInformation.transformation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14366,
  serialized_end=14520,
)


_SELECTEDFEATURE = _descriptor.Descriptor(
  name='SelectedFeature',
  full_name='ai.h2o.featurestore.api.v1.SelectedFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='ai.h2o.featurestore.api.v1.SelectedFeature.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature', full_name='ai.h2o.featurestore.api.v1.SelectedFeature.feature', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformation', full_name='ai.h2o.featurestore.api.v1.SelectedFeature.transformation', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14522,
  serialized_end=14596,
)


_FILTERCONDITIONUNION = _descriptor.Descriptor(
  name='FilterConditionUnion',
  full_name='ai.h2o.featurestore.api.v1.FilterConditionUnion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='ai.h2o.featurestore.api.v1.FilterConditionUnion.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logic', full_name='ai.h2o.featurestore.api.v1.FilterConditionUnion.logic', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='condition', full_name='ai.h2o.featurestore.api.v1.FilterConditionUnion.condition',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=14599,
  serialized_end=14760,
)


_FEATUREFILTER = _descriptor.Descriptor(
  name='FeatureFilter',
  full_name='ai.h2o.featurestore.api.v1.FeatureFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='ai.h2o.featurestore.api.v1.FeatureFilter.feature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='ai.h2o.featurestore.api.v1.FeatureFilter.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.FeatureFilter.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14763,
  serialized_end=14924,
)


_FEATUREFILTERLOGIC = _descriptor.Descriptor(
  name='FeatureFilterLogic',
  full_name='ai.h2o.featurestore.api.v1.FeatureFilterLogic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left', full_name='ai.h2o.featurestore.api.v1.FeatureFilterLogic.left', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right', full_name='ai.h2o.featurestore.api.v1.FeatureFilterLogic.right', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logic_operator', full_name='ai.h2o.featurestore.api.v1.FeatureFilterLogic.logic_operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14927,
  serialized_end=15156,
)


_FEATUREQUERY_FROM = _descriptor.Descriptor(
  name='From',
  full_name='ai.h2o.featurestore.api.v1.FeatureQuery.From',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.From.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alias', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.From.alias', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15446,
  serialized_end=15529,
)

_FEATUREQUERY_JOIN_ON = _descriptor.Descriptor(
  name='On',
  full_name='ai.h2o.featurestore.api.v1.FeatureQuery.Join.On',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.Join.On.left', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.Join.On.right', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15679,
  serialized_end=15802,
)

_FEATUREQUERY_JOIN = _descriptor.Descriptor(
  name='Join',
  full_name='ai.h2o.featurestore.api.v1.FeatureQuery.Join',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.Join.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alias', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.Join.alias', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.Join.on', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATUREQUERY_JOIN_ON, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15532,
  serialized_end=15802,
)

_FEATUREQUERY = _descriptor.Descriptor(
  name='FeatureQuery',
  full_name='ai.h2o.featurestore.api.v1.FeatureQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selected_features', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.selected_features', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_feature_set', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.from_feature_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.join', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='where', full_name='ai.h2o.featurestore.api.v1.FeatureQuery.where', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATUREQUERY_FROM, _FEATUREQUERY_JOIN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15159,
  serialized_end=15802,
)


_FEATUREVIEW = _descriptor.Descriptor(
  name='FeatureView',
  full_name='ai.h2o.featurestore.api.v1.FeatureView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.FeatureView.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.FeatureView.version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.FeatureView.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.FeatureView.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.FeatureView.project_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.FeatureView.query', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15805,
  serialized_end=15959,
)


_CREATEFEATUREVIEWREQUEST = _descriptor.Descriptor(
  name='CreateFeatureViewRequest',
  full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewRequest.project_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewRequest.query', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15962,
  serialized_end=16100,
)


_UPDATEFEATUREVIEWREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureViewRequest',
  full_name='ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest.feature_view_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16102,
  serialized_end=16204,
)


_CREATEFEATUREVIEWNEWVERSIONREQUEST = _descriptor.Descriptor(
  name='CreateFeatureViewNewVersionRequest',
  full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest.feature_view_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest.query', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16207,
  serialized_end=16355,
)


_GETFEATUREVIEWREQUEST = _descriptor.Descriptor(
  name='GetFeatureViewRequest',
  full_name='ai.h2o.featurestore.api.v1.GetFeatureViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.GetFeatureViewRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.GetFeatureViewRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.GetFeatureViewRequest.version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16357,
  serialized_end=16431,
)


_FEATUREVIEWRESPONSE = _descriptor.Descriptor(
  name='FeatureViewResponse',
  full_name='ai.h2o.featurestore.api.v1.FeatureViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='ai.h2o.featurestore.api.v1.FeatureViewResponse.feature_view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16433,
  serialized_end=16517,
)


_LISTFEATUREVIEWSREQUEST = _descriptor.Descriptor(
  name='ListFeatureViewsRequest',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureViewsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ListFeatureViewsRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16519,
  serialized_end=16564,
)


_LISTFEATUREVIEWSRESPONSE = _descriptor.Descriptor(
  name='ListFeatureViewsResponse',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureViewsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_views', full_name='ai.h2o.featurestore.api.v1.ListFeatureViewsResponse.feature_views', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16566,
  serialized_end=16656,
)


_RETRIEVEFEATUREVIEWASSPARKREQUEST = _descriptor.Descriptor(
  name='RetrieveFeatureViewAsSparkRequest',
  full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest.feature_view_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_at', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest.start_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_at', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest.end_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest.session_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16659,
  serialized_end=16859,
)


_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11532,
  serialized_end=11578,
)

_RETRIEVEFEATUREVIEWASSPARKRESPONSE = _descriptor.Descriptor(
  name='RetrieveFeatureViewAsSparkResponse',
  full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.options', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.session_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16862,
  serialized_end=17074,
)


_RETRIEVEFEATUREVIEWASASLINKSREQUEST = _descriptor.Descriptor(
  name='RetrieveFeatureViewAsAsLinksRequest',
  full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest.feature_view_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_at', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest.start_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_at', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest.end_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17077,
  serialized_end=17259,
)


_RETRIEVEFEATUREVIEWASASLINKSRESPONSE = _descriptor.Descriptor(
  name='RetrieveFeatureViewAsAsLinksResponse',
  full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_links', full_name='ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksResponse.download_links', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17261,
  serialized_end=17323,
)


_DELETEFEATUREVIEWREQUEST = _descriptor.Descriptor(
  name='DeleteFeatureViewRequest',
  full_name='ai.h2o.featurestore.api.v1.DeleteFeatureViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.DeleteFeatureViewRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17325,
  serialized_end=17376,
)


_MLDATASETFEATURE = _descriptor.Descriptor(
  name='MLDatasetFeature',
  full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_id', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.feature_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.feature_set_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_major_version', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.feature_set_major_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.feature_view_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.feature_view_version', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.data_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_type', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.feature_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ml_dataset_id', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.ml_dataset_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_name', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.original_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.project_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_data_type', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.original_data_type', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformation_function', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.transformation_function', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_primary_key', full_name='ai.h2o.featurestore.api.v1.MLDatasetFeature.is_primary_key', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17379,
  serialized_end=17778,
)


_MLDATASET = _descriptor.Descriptor(
  name='MLDataset',
  full_name='ai.h2o.featurestore.api.v1.MLDataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.MLDataset.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.MLDataset.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.MLDataset.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='ai.h2o.featurestore.api.v1.MLDataset.start_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='ai.h2o.featurestore.api.v1.MLDataset.end_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.MLDataset.feature_view_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.MLDataset.feature_view_version', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.MLDataset.project_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='ai.h2o.featurestore.api.v1.MLDataset.features', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ai.h2o.featurestore.api.v1.MLDataset.state', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_keys', full_name='ai.h2o.featurestore.api.v1.MLDataset.primary_keys', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MLDATASET_MLDATASETSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17781,
  serialized_end=18283,
)


_CREATEMLDATASETREQUEST = _descriptor.Descriptor(
  name='CreateMLDatasetRequest',
  full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetRequest.feature_view_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetRequest.start_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetRequest.end_date_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18286,
  serialized_end=18504,
)


_UPDATEMLDATASETREQUEST = _descriptor.Descriptor(
  name='UpdateMLDatasetRequest',
  full_name='ai.h2o.featurestore.api.v1.UpdateMLDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ml_dataset_id', full_name='ai.h2o.featurestore.api.v1.UpdateMLDatasetRequest.ml_dataset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.UpdateMLDatasetRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18506,
  serialized_end=18574,
)


_DELETEMLDATASETREQUEST = _descriptor.Descriptor(
  name='DeleteMLDatasetRequest',
  full_name='ai.h2o.featurestore.api.v1.DeleteMLDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ml_dataset_id', full_name='ai.h2o.featurestore.api.v1.DeleteMLDatasetRequest.ml_dataset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18576,
  serialized_end=18623,
)


_CREATEMLDATASETRESPONSE = _descriptor.Descriptor(
  name='CreateMLDatasetResponse',
  full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ml_dataset', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetResponse.ml_dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='ai.h2o.featurestore.api.v1.CreateMLDatasetResponse.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18626,
  serialized_end=18758,
)


_GETMLDATASETREQUEST = _descriptor.Descriptor(
  name='GetMLDatasetRequest',
  full_name='ai.h2o.featurestore.api.v1.GetMLDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.GetMLDatasetRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.GetMLDatasetRequest.feature_view_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ml_dataset_name', full_name='ai.h2o.featurestore.api.v1.GetMLDatasetRequest.ml_dataset_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18760,
  serialized_end=18861,
)


_LISTMLDATASETSREQUEST = _descriptor.Descriptor(
  name='ListMLDatasetsRequest',
  full_name='ai.h2o.featurestore.api.v1.ListMLDatasetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='ai.h2o.featurestore.api.v1.ListMLDatasetsRequest.feature_view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_version', full_name='ai.h2o.featurestore.api.v1.ListMLDatasetsRequest.feature_view_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18863,
  serialized_end=18941,
)


_LISTMLDATASETSRESPONSE = _descriptor.Descriptor(
  name='ListMLDatasetsResponse',
  full_name='ai.h2o.featurestore.api.v1.ListMLDatasetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ml_datasets', full_name='ai.h2o.featurestore.api.v1.ListMLDatasetsResponse.ml_datasets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18943,
  serialized_end=19027,
)


_RETRIEVEMLDATASETASSPARKREQUEST = _descriptor.Descriptor(
  name='RetrieveMLDatasetAsSparkRequest',
  full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ml_dataset_id', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkRequest.ml_dataset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkRequest.session_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19029,
  serialized_end=19105,
)


_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11532,
  serialized_end=11578,
)

_RETRIEVEMLDATASETASSPARKRESPONSE = _descriptor.Descriptor(
  name='RetrieveMLDatasetAsSparkResponse',
  full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.options', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.session_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19108,
  serialized_end=19316,
)


_RETRIEVEMLDATASETASASLINKSREQUEST = _descriptor.Descriptor(
  name='RetrieveMLDatasetAsAsLinksRequest',
  full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ml_dataset_id', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksRequest.ml_dataset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19318,
  serialized_end=19376,
)


_RETRIEVEMLDATASETASASLINKSRESPONSE = _descriptor.Descriptor(
  name='RetrieveMLDatasetAsAsLinksResponse',
  full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_links', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksResponse.download_links', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19378,
  serialized_end=19438,
)


_RETRIEVEMLDATASETONLINEREQUEST = _descriptor.Descriptor(
  name='RetrieveMLDatasetOnlineRequest',
  full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetOnlineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ml_dataset_id', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetOnlineRequest.ml_dataset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keys', full_name='ai.h2o.featurestore.api.v1.RetrieveMLDatasetOnlineRequest.keys', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19440,
  serialized_end=19509,
)


_FEATURESET_STATISTICS = _descriptor.Descriptor(
  name='Statistics',
  full_name='ai.h2o.featurestore.api.v1.FeatureSet.Statistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_latency', full_name='ai.h2o.featurestore.api.v1.FeatureSet.Statistics.data_latency', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21004,
  serialized_end=21038,
)

_FEATURESET_SPECIALDATA_LEGAL = _descriptor.Descriptor(
  name='Legal',
  full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='approved', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal.approved', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='approved_date', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal.approved_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notes', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal.notes', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21208,
  serialized_end=21299,
)

_FEATURESET_SPECIALDATA = _descriptor.Descriptor(
  name='SpecialData',
  full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spi', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.spi', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pci', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.pci', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rpi', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.rpi', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='demographic', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.demographic', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensitive', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.sensitive', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legal', full_name='ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.legal', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURESET_SPECIALDATA_LEGAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21041,
  serialized_end=21299,
)

_FEATURESET_ONLINE = _descriptor.Descriptor(
  name='Online',
  full_name='ai.h2o.featurestore.api.v1.FeatureSet.Online',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='online_namespace', full_name='ai.h2o.featurestore.api.v1.FeatureSet.Online.online_namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_type', full_name='ai.h2o.featurestore.api.v1.FeatureSet.Online.connection_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='ai.h2o.featurestore.api.v1.FeatureSet.Online.topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21301,
  serialized_end=21375,
)

_FEATURESET = _descriptor.Descriptor(
  name='FeatureSet',
  full_name='ai.h2o.featurestore.api.v1.FeatureSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.FeatureSet.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='ai.h2o.featurestore.api.v1.FeatureSet.feature_set_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.FeatureSet.version', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_change', full_name='ai.h2o.featurestore.api.v1.FeatureSet.version_change', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column', full_name='ai.h2o.featurestore.api.v1.FeatureSet.time_travel_column', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column_format', full_name='ai.h2o.featurestore.api.v1.FeatureSet.time_travel_column_format', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_type', full_name='ai.h2o.featurestore.api.v1.FeatureSet.feature_set_type', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.FeatureSet.description', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='ai.h2o.featurestore.api.v1.FeatureSet.owner', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='ai.h2o.featurestore.api.v1.FeatureSet.author', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='ai.h2o.featurestore.api.v1.FeatureSet.created_date_time', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_date_time', full_name='ai.h2o.featurestore.api.v1.FeatureSet.last_update_date_time', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_name', full_name='ai.h2o.featurestore.api.v1.FeatureSet.application_name', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='ai.h2o.featurestore.api.v1.FeatureSet.deprecated', index=13,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_date', full_name='ai.h2o.featurestore.api.v1.FeatureSet.deprecated_date', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_domains', full_name='ai.h2o.featurestore.api.v1.FeatureSet.data_source_domains', index=15,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ai.h2o.featurestore.api.v1.FeatureSet.tags', index=16,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval', full_name='ai.h2o.featurestore.api.v1.FeatureSet.process_interval', index=17,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval_unit', full_name='ai.h2o.featurestore.api.v1.FeatureSet.process_interval_unit', index=18,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow', full_name='ai.h2o.featurestore.api.v1.FeatureSet.flow', index=19,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='ai.h2o.featurestore.api.v1.FeatureSet.time_to_live', index=20,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='ai.h2o.featurestore.api.v1.FeatureSet.features', index=21,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='ai.h2o.featurestore.api.v1.FeatureSet.statistics', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_data', full_name='ai.h2o.featurestore.api.v1.FeatureSet.special_data', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='ai.h2o.featurestore.api.v1.FeatureSet.primary_key', index=24,
      number=26, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.FeatureSet.id', index=25,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_scope', full_name='ai.h2o.featurestore.api.v1.FeatureSet.time_travel_scope', index=26,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='ai.h2o.featurestore.api.v1.FeatureSet.application_id', index=27,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_state', full_name='ai.h2o.featurestore.api.v1.FeatureSet.feature_set_state', index=28,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online', full_name='ai.h2o.featurestore.api.v1.FeatureSet.online', index=29,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='ai.h2o.featurestore.api.v1.FeatureSet.secret', index=30,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.FeatureSet.project_id', index=31,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_by', full_name='ai.h2o.featurestore.api.v1.FeatureSet.partition_by', index=32,
      number=35, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.FeatureSet.custom_data', index=33,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_materialization_scope', full_name='ai.h2o.featurestore.api.v1.FeatureSet.online_materialization_scope', index=34,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_from', full_name='ai.h2o.featurestore.api.v1.FeatureSet.derived_from', index=35,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_classifiers', full_name='ai.h2o.featurestore.api.v1.FeatureSet.feature_classifiers', index=36,
      number=39, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURESET_STATISTICS, _FEATURESET_SPECIALDATA, _FEATURESET_ONLINE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19512,
  serialized_end=21375,
)


_GETFEATURESETPREVIEWREQUEST = _descriptor.Descriptor(
  name='GetFeatureSetPreviewRequest',
  full_name='ai.h2o.featurestore.api.v1.GetFeatureSetPreviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetPreviewRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetPreviewRequest.feature_set_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21377,
  serialized_end=21459,
)


_GETFEATURESETPREVIEWRESPONSE = _descriptor.Descriptor(
  name='GetFeatureSetPreviewResponse',
  full_name='ai.h2o.featurestore.api.v1.GetFeatureSetPreviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preview_url', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetPreviewResponse.preview_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_cols_num', full_name='ai.h2o.featurestore.api.v1.GetFeatureSetPreviewResponse.max_cols_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21461,
  serialized_end=21534,
)


_SCOPE = _descriptor.Descriptor(
  name='Scope',
  full_name='ai.h2o.featurestore.api.v1.Scope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='ai.h2o.featurestore.api.v1.Scope.start_date_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='ai.h2o.featurestore.api.v1.Scope.end_date_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21536,
  serialized_end=21647,
)


_REGISTERFEATURESETREQUEST = _descriptor.Descriptor(
  name='RegisterFeatureSetRequest',
  full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_name', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.feature_set_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.project', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.time_travel_column', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column_format', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.time_travel_column_format', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.primary_key', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.schema', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.secret', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.description', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_by', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.partition_by', index=8,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column_as_partition', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.time_travel_column_as_partition', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_type', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.feature_set_type', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_state', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.feature_set_state', index=11,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_name', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.application_name', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.application_id', index=13,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.online', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_domains', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.data_source_domains', index=15,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.tags', index=16,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.process_interval', index=17,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval_unit', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.process_interval_unit', index=18,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.flow', index=19,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_data', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.special_data', index=20,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.custom_data', index=21,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.time_to_live', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_from', full_name='ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest.derived_from', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21650,
  serialized_end=22625,
)


_CREATENEWFEATURESETVERSIONREQUEST = _descriptor.Descriptor(
  name='CreateNewFeatureSetVersionRequest',
  full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.schema', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_features', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.affected_features', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_from', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.derived_from', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.primary_key', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_primary_key_from_previous_version', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.use_primary_key_from_previous_version', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backfill_options', full_name='ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest.backfill_options', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22628,
  serialized_end=23035,
)


_FEATUREPROFILE = _descriptor.Descriptor(
  name='FeatureProfile',
  full_name='ai.h2o.featurestore.api.v1.FeatureProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_type', full_name='ai.h2o.featurestore.api.v1.FeatureProfile.feature_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categorical', full_name='ai.h2o.featurestore.api.v1.FeatureProfile.categorical', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='ai.h2o.featurestore.api.v1.FeatureProfile.statistics', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics_available', full_name='ai.h2o.featurestore.api.v1.FeatureProfile.statistics_available', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23038,
  serialized_end=23293,
)


_FEATURESCHEMA_SPECIALDATA = _descriptor.Descriptor(
  name='SpecialData',
  full_name='ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spi', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData.spi', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pci', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData.pci', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rpi', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData.rpi', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='demographic', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData.demographic', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensitive', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData.sensitive', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21041,
  serialized_end=21133,
)

_FEATURESCHEMA = _descriptor.Descriptor(
  name='FeatureSchema',
  full_name='ai.h2o.featurestore.api.v1.FeatureSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.data_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nested', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.nested', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_data', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.special_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_type', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.feature_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifiers', full_name='ai.h2o.featurestore.api.v1.FeatureSchema.classifiers', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURESCHEMA_SPECIALDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23296,
  serialized_end=23679,
)


_FEATURE_MONITORING = _descriptor.Descriptor(
  name='Monitoring',
  full_name='ai.h2o.featurestore.api.v1.Feature.Monitoring',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='anomaly_detection', full_name='ai.h2o.featurestore.api.v1.Feature.Monitoring.anomaly_detection', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24245,
  serialized_end=24284,
)

_FEATURE_SPECIALDATA = _descriptor.Descriptor(
  name='SpecialData',
  full_name='ai.h2o.featurestore.api.v1.Feature.SpecialData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spi', full_name='ai.h2o.featurestore.api.v1.Feature.SpecialData.spi', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pci', full_name='ai.h2o.featurestore.api.v1.Feature.SpecialData.pci', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rpi', full_name='ai.h2o.featurestore.api.v1.Feature.SpecialData.rpi', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='demographic', full_name='ai.h2o.featurestore.api.v1.Feature.SpecialData.demographic', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensitive', full_name='ai.h2o.featurestore.api.v1.Feature.SpecialData.sensitive', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21041,
  serialized_end=21133,
)

_FEATURE = _descriptor.Descriptor(
  name='Feature',
  full_name='ai.h2o.featurestore.api.v1.Feature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.Feature.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.Feature.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_change', full_name='ai.h2o.featurestore.api.v1.Feature.version_change', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='ai.h2o.featurestore.api.v1.Feature.status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ai.h2o.featurestore.api.v1.Feature.data_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile', full_name='ai.h2o.featurestore.api.v1.Feature.profile', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.Feature.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importance', full_name='ai.h2o.featurestore.api.v1.Feature.importance', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special', full_name='ai.h2o.featurestore.api.v1.Feature.special', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring', full_name='ai.h2o.featurestore.api.v1.Feature.monitoring', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nested_features', full_name='ai.h2o.featurestore.api.v1.Feature.nested_features', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fully_qualified_feature_names', full_name='ai.h2o.featurestore.api.v1.Feature.fully_qualified_feature_names', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_data', full_name='ai.h2o.featurestore.api.v1.Feature.special_data', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifiers', full_name='ai.h2o.featurestore.api.v1.Feature.classifiers', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.Feature.custom_data', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.Feature.id', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.Feature.feature_set_id', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURE_MONITORING, _FEATURE_SPECIALDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23682,
  serialized_end=24378,
)


_FEATURESTATISTICS = _descriptor.Descriptor(
  name='FeatureStatistics',
  full_name='ai.h2o.featurestore.api.v1.FeatureStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.max', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.mean', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.median', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.min', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.stddev', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stddev_rec_count', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.stddev_rec_count', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_count', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.null_count', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nan_count', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.nan_count', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique', full_name='ai.h2o.featurestore.api.v1.FeatureStatistics.unique', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24381,
  serialized_end=24553,
)


_CATEGORICALFEATURESTATISTICS_FEATURETOP = _descriptor.Descriptor(
  name='FeatureTop',
  full_name='ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.FeatureTop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.FeatureTop.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.FeatureTop.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24686,
  serialized_end=24727,
)

_CATEGORICALFEATURESTATISTICS = _descriptor.Descriptor(
  name='CategoricalFeatureStatistics',
  full_name='ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique', full_name='ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.unique', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top', full_name='ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.top', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORICALFEATURESTATISTICS_FEATURETOP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24556,
  serialized_end=24727,
)


_GETVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetVersionResponse',
  full_name='ai.h2o.featurestore.api.v1.GetVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.GetVersionResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24729,
  serialized_end=24766,
)


_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='ai.h2o.featurestore.api.v1.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.Project.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.Project.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='ai.h2o.featurestore.api.v1.Project.owner', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='ai.h2o.featurestore.api.v1.Project.author', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='ai.h2o.featurestore.api.v1.Project.created_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_date_time', full_name='ai.h2o.featurestore.api.v1.Project.last_update_date_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='ai.h2o.featurestore.api.v1.Project.secret', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='ai.h2o.featurestore.api.v1.Project.locked', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.Project.id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.Project.custom_data', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_sets_count', full_name='ai.h2o.featurestore.api.v1.Project.feature_sets_count', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24769,
  serialized_end=25162,
)


_LISTABLEPROJECT = _descriptor.Descriptor(
  name='ListableProject',
  full_name='ai.h2o.featurestore.api.v1.ListableProject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.ListableProject.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.ListableProject.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.ListableProject.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_date_time', full_name='ai.h2o.featurestore.api.v1.ListableProject.last_update_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='ai.h2o.featurestore.api.v1.ListableProject.locked', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.ListableProject.permission', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='ai.h2o.featurestore.api.v1.ListableProject.author', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_sets_count', full_name='ai.h2o.featurestore.api.v1.ListableProject.feature_sets_count', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25165,
  serialized_end=25457,
)


_FEATURESETINGEST = _descriptor.Descriptor(
  name='FeatureSetIngest',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingest_id', full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest.ingest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingest_timestamp', full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest.ingest_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest.source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest.feature_set_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest.feature_set_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest.scope', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_ingests', full_name='ai.h2o.featurestore.api.v1.FeatureSetIngest.parent_ingests', index=6,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25460,
  serialized_end=25739,
)


_PERSONALACCESSTOKEN = _descriptor.Descriptor(
  name='PersonalAccessToken',
  full_name='ai.h2o.featurestore.api.v1.PersonalAccessToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.PersonalAccessToken.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.PersonalAccessToken.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.PersonalAccessToken.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_used', full_name='ai.h2o.featurestore.api.v1.PersonalAccessToken.last_used', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_time', full_name='ai.h2o.featurestore.api.v1.PersonalAccessToken.creation_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_date', full_name='ai.h2o.featurestore.api.v1.PersonalAccessToken.expiry_date', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25742,
  serialized_end=25957,
)


_GENERATETRANSFORMATIONUPLOADREQUEST = _descriptor.Descriptor(
  name='GenerateTransformationUploadRequest',
  full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_type', full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadRequest.transformation_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5_checksum', full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadRequest.md5_checksum', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25960,
  serialized_end=26096,
)


_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY = _descriptor.Descriptor(
  name='HeadersEntry',
  full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.HeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.HeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.HeadersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26266,
  serialized_end=26312,
)

_GENERATETRANSFORMATIONUPLOADRESPONSE = _descriptor.Descriptor(
  name='GenerateTransformationUploadResponse',
  full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.headers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26099,
  serialized_end=26312,
)


_LISTPROJECTSPAGEREQUEST = _descriptor.Descriptor(
  name='ListProjectsPageRequest',
  full_name='ai.h2o.featurestore.api.v1.ListProjectsPageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='ai.h2o.featurestore.api.v1.ListProjectsPageRequest.page_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='ai.h2o.featurestore.api.v1.ListProjectsPageRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26314,
  serialized_end=26378,
)


_LISTPROJECTSPAGERESPONSE = _descriptor.Descriptor(
  name='ListProjectsPageResponse',
  full_name='ai.h2o.featurestore.api.v1.ListProjectsPageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='ai.h2o.featurestore.api.v1.ListProjectsPageResponse.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ListProjectsPageResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26380,
  serialized_end=26486,
)


_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='ai.h2o.featurestore.api.v1.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.SearchRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='ai.h2o.featurestore.api.v1.SearchRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='ai.h2o.featurestore.api.v1.SearchRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owned_only', full_name='ai.h2o.featurestore.api.v1.SearchRequest.owned_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_ids', full_name='ai.h2o.featurestore.api.v1.SearchRequest.project_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26488,
  serialized_end=26598,
)


_PROJECTSEARCHRESULTS = _descriptor.Descriptor(
  name='ProjectSearchResults',
  full_name='ai.h2o.featurestore.api.v1.ProjectSearchResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listable_project', full_name='ai.h2o.featurestore.api.v1.ProjectSearchResults.listable_project', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ProjectSearchResults.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26600,
  serialized_end=26718,
)


_LISTABLEFEATURESET = _descriptor.Descriptor(
  name='ListableFeatureSet',
  full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_name', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.project_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_date_time', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.last_update_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.permission', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.project_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_change', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.version_change', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.time_travel_column', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_column_format', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.time_travel_column_format', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_type', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.feature_set_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.author', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.created_date_time', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.deprecated', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_date', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.deprecated_date', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.tags', index=16,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.time_to_live', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_data', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.special_data', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_key', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.primary_key', index=19,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_travel_scope', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.time_travel_scope', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.secret', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_by', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.partition_by', index=22,
      number=23, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_materialization_scope', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.online_materialization_scope', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derived_from', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.derived_from', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_classifiers', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSet.feature_classifiers', index=25,
      number=26, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26721,
  serialized_end=27759,
)


_FEATURESETSEARCHRESULTS = _descriptor.Descriptor(
  name='FeatureSetSearchResults',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetSearchResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listable_feature_set', full_name='ai.h2o.featurestore.api.v1.FeatureSetSearchResults.listable_feature_set', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.FeatureSetSearchResults.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27762,
  serialized_end=27890,
)


_LISTABLEFEATURE = _descriptor.Descriptor(
  name='ListableFeature',
  full_name='ai.h2o.featurestore.api.v1.ListableFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.ListableFeature.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.ListableFeature.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.ListableFeature.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anomaly_detection', full_name='ai.h2o.featurestore.api.v1.ListableFeature.anomaly_detection', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_type', full_name='ai.h2o.featurestore.api.v1.ListableFeature.feature_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ai.h2o.featurestore.api.v1.ListableFeature.data_type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ai.h2o.featurestore.api.v1.ListableFeature.version', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_id', full_name='ai.h2o.featurestore.api.v1.ListableFeature.feature_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27893,
  serialized_end=28115,
)


_FEATURESEARCHRESULTS = _descriptor.Descriptor(
  name='FeatureSearchResults',
  full_name='ai.h2o.featurestore.api.v1.FeatureSearchResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listable_feature', full_name='ai.h2o.featurestore.api.v1.FeatureSearchResults.listable_feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.FeatureSearchResults.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28117,
  serialized_end=28235,
)


_FEATURESETREQUESTID = _descriptor.Descriptor(
  name='FeatureSetRequestId',
  full_name='ai.h2o.featurestore.api.v1.FeatureSetRequestId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.FeatureSetRequestId.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28237,
  serialized_end=28282,
)


_GETFEATUREREQUEST = _descriptor.Descriptor(
  name='GetFeatureRequest',
  full_name='ai.h2o.featurestore.api.v1.GetFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.GetFeatureRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.GetFeatureRequest.feature_set_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_id', full_name='ai.h2o.featurestore.api.v1.GetFeatureRequest.feature_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28284,
  serialized_end=28376,
)


_LISTFEATURESPAGERESPONSE = _descriptor.Descriptor(
  name='ListFeaturesPageResponse',
  full_name='ai.h2o.featurestore.api.v1.ListFeaturesPageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='ai.h2o.featurestore.api.v1.ListFeaturesPageResponse.features', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ListFeaturesPageResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28378,
  serialized_end=28484,
)


_FEATURERESPONSE = _descriptor.Descriptor(
  name='FeatureResponse',
  full_name='ai.h2o.featurestore.api.v1.FeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='ai.h2o.featurestore.api.v1.FeatureResponse.feature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28486,
  serialized_end=28557,
)


_LISTFEATURESREQUEST = _descriptor.Descriptor(
  name='ListFeaturesRequest',
  full_name='ai.h2o.featurestore.api.v1.ListFeaturesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.ListFeaturesRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='ai.h2o.featurestore.api.v1.ListFeaturesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='ai.h2o.featurestore.api.v1.ListFeaturesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='ai.h2o.featurestore.api.v1.ListFeaturesRequest.query', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28559,
  serialized_end=28658,
)


_LISTFEATURESRESPONSE = _descriptor.Descriptor(
  name='ListFeaturesResponse',
  full_name='ai.h2o.featurestore.api.v1.ListFeaturesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='ai.h2o.featurestore.api.v1.ListFeaturesResponse.features', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ListFeaturesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28660,
  serialized_end=28762,
)


_LISTABLEFEATURESETREQUEST = _descriptor.Descriptor(
  name='ListableFeatureSetRequest',
  full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetRequest.feature_set_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28764,
  serialized_end=28844,
)


_LISTABLEFEATURESETRESPONSE = _descriptor.Descriptor(
  name='ListableFeatureSetResponse',
  full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listable_feature_set', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetResponse.listable_feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28846,
  serialized_end=28952,
)


_SUBMITPENDINGPERMISSIONREQUEST = _descriptor.Descriptor(
  name='SubmitPendingPermissionRequest',
  full_name='ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest.permission', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28955,
  serialized_end=29088,
)


_SUBMITPENDINGPERMISSIONRESPONSE = _descriptor.Descriptor(
  name='SubmitPendingPermissionResponse',
  full_name='ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission_id', full_name='ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse.permission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29090,
  serialized_end=29146,
)


_LISTPERMISSIONSPAGEREQUEST = _descriptor.Descriptor(
  name='ListPermissionsPageRequest',
  full_name='ai.h2o.featurestore.api.v1.ListPermissionsPageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='ai.h2o.featurestore.api.v1.ListPermissionsPageRequest.filters', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='ai.h2o.featurestore.api.v1.ListPermissionsPageRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='ai.h2o.featurestore.api.v1.ListPermissionsPageRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29149,
  serialized_end=29278,
)


_LISTPROJECTSPERMISSIONSPAGERESPONSE = _descriptor.Descriptor(
  name='ListProjectsPermissionsPageResponse',
  full_name='ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29281,
  serialized_end=29417,
)


_LISTFEATURESETSPERMISSIONSPAGERESPONSE = _descriptor.Descriptor(
  name='ListFeatureSetsPermissionsPageResponse',
  full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29420,
  serialized_end=29562,
)


_LISTABLEPROJECTTOPERMISSION = _descriptor.Descriptor(
  name='ListableProjectToPermission',
  full_name='ai.h2o.featurestore.api.v1.ListableProjectToPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='ai.h2o.featurestore.api.v1.ListableProjectToPermission.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.ListableProjectToPermission.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29565,
  serialized_end=29716,
)


_LISTABLEFEATURESETTOPERMISSION = _descriptor.Descriptor(
  name='ListableFeatureSetToPermission',
  full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetToPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetToPermission.feature_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.ListableFeatureSetToPermission.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29719,
  serialized_end=29880,
)


_PERMISSION_PROMOTEDUPDATE = _descriptor.Descriptor(
  name='PromotedUpdate',
  full_name='ai.h2o.featurestore.api.v1.Permission.PromotedUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.Permission.PromotedUpdate.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_on', full_name='ai.h2o.featurestore.api.v1.Permission.PromotedUpdate.updated_on', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.Permission.PromotedUpdate.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replaced_by_permission_id', full_name='ai.h2o.featurestore.api.v1.Permission.PromotedUpdate.replaced_by_permission_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30555,
  serialized_end=30727,
)

_PERMISSION_REVOKEDUPDATE = _descriptor.Descriptor(
  name='RevokedUpdate',
  full_name='ai.h2o.featurestore.api.v1.Permission.RevokedUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.Permission.RevokedUpdate.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_on', full_name='ai.h2o.featurestore.api.v1.Permission.RevokedUpdate.updated_on', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.Permission.RevokedUpdate.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30730,
  serialized_end=30866,
)

_PERMISSION_GRANTEDORREJECTEDUPDATE = _descriptor.Descriptor(
  name='GrantedOrRejectedUpdate',
  full_name='ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_on', full_name='ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate.updated_on', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30869,
  serialized_end=31015,
)

_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='ai.h2o.featurestore.api.v1.Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.Permission.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='ai.h2o.featurestore.api.v1.Permission.resource_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='ai.h2o.featurestore.api.v1.Permission.resource_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.Permission.permission', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='ai.h2o.featurestore.api.v1.Permission.user', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_reason', full_name='ai.h2o.featurestore.api.v1.Permission.creation_reason', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ai.h2o.featurestore.api.v1.Permission.state', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_on', full_name='ai.h2o.featurestore.api.v1.Permission.created_on', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_on', full_name='ai.h2o.featurestore.api.v1.Permission.last_update_on', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='ai.h2o.featurestore.api.v1.Permission.active', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granted_or_rejected', full_name='ai.h2o.featurestore.api.v1.Permission.granted_or_rejected', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revoked', full_name='ai.h2o.featurestore.api.v1.Permission.revoked', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='promoted', full_name='ai.h2o.featurestore.api.v1.Permission.promoted', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PERMISSION_PROMOTEDUPDATE, _PERMISSION_REVOKEDUPDATE, _PERMISSION_GRANTEDORREJECTEDUPDATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29883,
  serialized_end=31015,
)


_REVOKEPERMISSIONREQUEST = _descriptor.Descriptor(
  name='RevokePermissionRequest',
  full_name='ai.h2o.featurestore.api.v1.RevokePermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission_id', full_name='ai.h2o.featurestore.api.v1.RevokePermissionRequest.permission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.RevokePermissionRequest.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31017,
  serialized_end=31081,
)


_APPROVEPENDINGPERMISSIONREQUEST = _descriptor.Descriptor(
  name='ApprovePendingPermissionRequest',
  full_name='ai.h2o.featurestore.api.v1.ApprovePendingPermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission_id', full_name='ai.h2o.featurestore.api.v1.ApprovePendingPermissionRequest.permission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.ApprovePendingPermissionRequest.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31083,
  serialized_end=31155,
)


_REJECTPENDINGPERMISSIONREQUEST = _descriptor.Descriptor(
  name='RejectPendingPermissionRequest',
  full_name='ai.h2o.featurestore.api.v1.RejectPendingPermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission_id', full_name='ai.h2o.featurestore.api.v1.RejectPendingPermissionRequest.permission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='ai.h2o.featurestore.api.v1.RejectPendingPermissionRequest.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31157,
  serialized_end=31228,
)


_GETACTIVEPERMISSIONREQUEST = _descriptor.Descriptor(
  name='GetActivePermissionRequest',
  full_name='ai.h2o.featurestore.api.v1.GetActivePermissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='ai.h2o.featurestore.api.v1.GetActivePermissionRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31230,
  serialized_end=31279,
)


_GETACTIVEPERMISSIONRESPONSE = _descriptor.Descriptor(
  name='GetActivePermissionResponse',
  full_name='ai.h2o.featurestore.api.v1.GetActivePermissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='ai.h2o.featurestore.api.v1.GetActivePermissionResponse.permission', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31281,
  serialized_end=31376,
)


_SCHEDULEDTASK = _descriptor.Descriptor(
  name='ScheduledTask',
  full_name='ai.h2o.featurestore.api.v1.ScheduledTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.feature_set_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.project_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.source', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.schedule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_run_time', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.next_run_time', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_exec', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.last_exec', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.owner', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_date_time', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.created_date_time', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_update_date_time', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.last_update_date_time', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.task_type', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.feature_set_version', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crone_time_zone', full_name='ai.h2o.featurestore.api.v1.ScheduledTask.crone_time_zone', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31379,
  serialized_end=31945,
)


_SCHEDULETASKREQUEST = _descriptor.Descriptor(
  name='ScheduleTaskRequest',
  full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.project_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cred', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.cred', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.source', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.schedule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.feature_set_version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crone_time_zone', full_name='ai.h2o.featurestore.api.v1.ScheduleTaskRequest.crone_time_zone', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31948,
  serialized_end=32236,
)


_LISTSCHEDULEDTASKSREQUEST = _descriptor.Descriptor(
  name='ListScheduledTasksRequest',
  full_name='ai.h2o.featurestore.api.v1.ListScheduledTasksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.ListScheduledTasksRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='ai.h2o.featurestore.api.v1.ListScheduledTasksRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='ai.h2o.featurestore.api.v1.ListScheduledTasksRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32238,
  serialized_end=32328,
)


_LISTSCHEDULEDTASKSRESPONSE = _descriptor.Descriptor(
  name='ListScheduledTasksResponse',
  full_name='ai.h2o.featurestore.api.v1.ListScheduledTasksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tasks', full_name='ai.h2o.featurestore.api.v1.ListScheduledTasksResponse.tasks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='ai.h2o.featurestore.api.v1.ListScheduledTasksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32330,
  serialized_end=32441,
)


_SCHEDULEDTASKID = _descriptor.Descriptor(
  name='ScheduledTaskId',
  full_name='ai.h2o.featurestore.api.v1.ScheduledTaskId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduled_task_id', full_name='ai.h2o.featurestore.api.v1.ScheduledTaskId.scheduled_task_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32443,
  serialized_end=32487,
)


_SCHEDULEDTASKRESPONSE = _descriptor.Descriptor(
  name='ScheduledTaskResponse',
  full_name='ai.h2o.featurestore.api.v1.ScheduledTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='ai.h2o.featurestore.api.v1.ScheduledTaskResponse.task', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32489,
  serialized_end=32569,
)


_SCHEDULEDTASKUPDATEREQUEST = _descriptor.Descriptor(
  name='ScheduledTaskUpdateRequest',
  full_name='ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduled_task_id', full_name='ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest.scheduled_task_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest.schedule', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_fields', full_name='ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest.updated_fields', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32571,
  serialized_end=32689,
)


_LAZYINGESTREQUEST = _descriptor.Descriptor(
  name='LazyIngestRequest',
  full_name='ai.h2o.featurestore.api.v1.LazyIngestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.LazyIngestRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.LazyIngestRequest.feature_set_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32691,
  serialized_end=32763,
)


_LAZYINGESTRESPONSE = _descriptor.Descriptor(
  name='LazyIngestResponse',
  full_name='ai.h2o.featurestore.api.v1.LazyIngestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ai.h2o.featurestore.api.v1.LazyIngestResponse.job_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32765,
  serialized_end=32836,
)


_GETLAZYINGESTTASKREQUEST = _descriptor.Descriptor(
  name='GetLazyIngestTaskRequest',
  full_name='ai.h2o.featurestore.api.v1.GetLazyIngestTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.GetLazyIngestTaskRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.GetLazyIngestTaskRequest.feature_set_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32838,
  serialized_end=32917,
)


_TRANSFORMATIONFUNCTION = _descriptor.Descriptor(
  name='TransformationFunction',
  full_name='ai.h2o.featurestore.api.v1.TransformationFunction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_name', full_name='ai.h2o.featurestore.api.v1.TransformationFunction.function_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_input_types', full_name='ai.h2o.featurestore.api.v1.TransformationFunction.supported_input_types', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_type', full_name='ai.h2o.featurestore.api.v1.TransformationFunction.output_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32919,
  serialized_end=33018,
)


_LISTTRANSFORMATIONFUNCTIONSREQUEST = _descriptor.Descriptor(
  name='ListTransformationFunctionsRequest',
  full_name='ai.h2o.featurestore.api.v1.ListTransformationFunctionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33020,
  serialized_end=33056,
)


_LISTTRANSFORMATIONFUNCTIONSRESPONSE = _descriptor.Descriptor(
  name='ListTransformationFunctionsResponse',
  full_name='ai.h2o.featurestore.api.v1.ListTransformationFunctionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_functions', full_name='ai.h2o.featurestore.api.v1.ListTransformationFunctionsResponse.transformation_functions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33058,
  serialized_end=33181,
)


_GETTRANSFORMATIONFUNCTIONREQUEST = _descriptor.Descriptor(
  name='GetTransformationFunctionRequest',
  full_name='ai.h2o.featurestore.api.v1.GetTransformationFunctionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_function_name', full_name='ai.h2o.featurestore.api.v1.GetTransformationFunctionRequest.transformation_function_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33183,
  serialized_end=33255,
)


_GETTRANSFORMATIONFUNCTIONRESPONSE = _descriptor.Descriptor(
  name='GetTransformationFunctionResponse',
  full_name='ai.h2o.featurestore.api.v1.GetTransformationFunctionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_function', full_name='ai.h2o.featurestore.api.v1.GetTransformationFunctionResponse.transformation_function', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33257,
  serialized_end=33377,
)


_UPDATEPROJECTREQUEST = _descriptor.Descriptor(
  name='UpdateProjectRequest',
  full_name='ai.h2o.featurestore.api.v1.UpdateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='ai.h2o.featurestore.api.v1.UpdateProjectRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='ai.h2o.featurestore.api.v1.UpdateProjectRequest.locked', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='ai.h2o.featurestore.api.v1.UpdateProjectRequest.secret', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.UpdateProjectRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.UpdateProjectRequest.custom_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields_to_update', full_name='ai.h2o.featurestore.api.v1.UpdateProjectRequest.fields_to_update', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33380,
  serialized_end=33598,
)


_UPDATEFEATURESETREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureSetRequest',
  full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.feature_set_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.tags', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_domains', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.data_source_domains', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.deprecated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.process_interval', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_interval_unit', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.process_interval_unit', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.secret', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live_offline_interval', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.time_to_live_offline_interval', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live_offline_interval_unit', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.time_to_live_offline_interval_unit', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live_online_interval', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.time_to_live_online_interval', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_live_online_interval_unit', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.time_to_live_online_interval_unit', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legal_approved', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.legal_approved', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legal_approved_notes', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.legal_approved_notes', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.state', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.flow', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_name', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.application_name', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.application_id', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.custom_data', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_namespace', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.online_namespace', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_topic', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.online_topic', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_connection_type', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.online_connection_type', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields_to_update', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest.fields_to_update', index=24,
      number=25, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33601,
  serialized_end=34557,
)


_UPDATEFEATUREREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureRequest',
  full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_set_id', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.feature_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_version', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.feature_set_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_id', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.feature_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importance', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.importance', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_data', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.custom_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.special', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anomaly_detection', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.anomaly_detection', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifiers', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.classifiers', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields_to_update', full_name='ai.h2o.featurestore.api.v1.UpdateFeatureRequest.fields_to_update', index=11,
      number=12, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34560,
  serialized_end=34955,
)


_GETOWNERSREQUEST = _descriptor.Descriptor(
  name='GetOwnersRequest',
  full_name='ai.h2o.featurestore.api.v1.GetOwnersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='ai.h2o.featurestore.api.v1.GetOwnersRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34957,
  serialized_end=34996,
)


_GETOWNERSRESPONSE = _descriptor.Descriptor(
  name='GetOwnersResponse',
  full_name='ai.h2o.featurestore.api.v1.GetOwnersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owners', full_name='ai.h2o.featurestore.api.v1.GetOwnersResponse.owners', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34998,
  serialized_end=35076,
)


_BACKFILLOPTIONS_FEATUREMAPPINGENTRY = _descriptor.Descriptor(
  name='FeatureMappingEntry',
  full_name='ai.h2o.featurestore.api.v1.BackfillOptions.FeatureMappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ai.h2o.featurestore.api.v1.BackfillOptions.FeatureMappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.h2o.featurestore.api.v1.BackfillOptions.FeatureMappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35383,
  serialized_end=35436,
)

_BACKFILLOPTIONS = _descriptor.Descriptor(
  name='BackfillOptions',
  full_name='ai.h2o.featurestore.api.v1.BackfillOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_date', full_name='ai.h2o.featurestore.api.v1.BackfillOptions.from_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='ai.h2o.featurestore.api.v1.BackfillOptions.to_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_version', full_name='ai.h2o.featurestore.api.v1.BackfillOptions.from_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_pipeline', full_name='ai.h2o.featurestore.api.v1.BackfillOptions.spark_pipeline', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_mapping', full_name='ai.h2o.featurestore.api.v1.BackfillOptions.feature_mapping', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BACKFILLOPTIONS_FEATUREMAPPINGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35079,
  serialized_end=35436,
)


_BACKFILLRESPONSE = _descriptor.Descriptor(
  name='BackfillResponse',
  full_name='ai.h2o.featurestore.api.v1.BackfillResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingest_response', full_name='ai.h2o.featurestore.api.v1.BackfillResponse.ingest_response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35438,
  serialized_end=35525,
)

_FEATURECUSTOMDATAUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURECUSTOMDATAUPDATEREQUEST.fields_by_name['new_value'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GETWEBCONFIGRESPONSE.fields_by_name['ipd_details'].message_type = _IDENTITYPROVIDERDETAILS
_FEATURESETCUSTOMDATAUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETCUSTOMDATAUPDATEREQUEST.fields_by_name['new_value'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PROJECTCUSTOMDATAUPDATEREQUEST.fields_by_name['new_value'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FEATURESETTYPEUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETTYPEUPDATEREQUEST.fields_by_name['new_value'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETTYPE
_GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURETYPEUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURETYPEUPDATEREQUEST.fields_by_name['new_value'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURETYPE
_FEATUREDOUBLEFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESTRINGFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESTRINGARRAYFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATUREBOOLEANFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST.fields_by_name['new_value'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2._ONLINE_TIMETOLIVEINTERVAL
_FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST.fields_by_name['new_value'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2._OFFLINE_TIMETOLIVEINTERVAL
_FEATURESETINTFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETPROCESSINTERVALUNITUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETPROCESSINTERVALUNITUPDATEREQUEST.fields_by_name['new_value'].enum_type = _PROCESSINTERVALUNIT
_FEATURESETSTRINGARRAYFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETBOOLEANFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETSTRINGFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETUSERFIELDUPDATEREQUEST.fields_by_name['header'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETHEADER
_FEATURESETUSERFIELDUPDATEREQUEST.fields_by_name['new_value'].message_type = _USERBASICINFO
_PROJECTUSERFIELDUPDATEREQUEST.fields_by_name['new_value'].message_type = _USERBASICINFO
_GETINGESTHISTORYREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_STARTREVERTINGESTJOBREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_GETUSERBYMAILRESPONSE.fields_by_name['user'].message_type = _USERBASICINFO
_GENERATETOKENREQUEST.fields_by_name['expiry_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOKENRESPONSE.fields_by_name['token'].message_type = _PERSONALACCESSTOKEN
_LISTTOKENSRESPONSE.fields_by_name['tokens'].message_type = _PERSONALACCESSTOKEN
_LISTJOBSREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_LISTJOBSREQUEST.fields_by_name['job_type'].enum_type = _JOBTYPE
_LISTJOBSRESPONSE.fields_by_name['jobs'].message_type = _JOB
_FEATURESETSCHEMACOMPATIBILITYREQUEST.fields_by_name['original_schema'].message_type = _FEATURESCHEMA
_FEATURESETSCHEMACOMPATIBILITYREQUEST.fields_by_name['new_schema'].message_type = _FEATURESCHEMA
_FEATURESETSCHEMAPATCHREQUEST.fields_by_name['original_schema'].message_type = _FEATURESCHEMA
_FEATURESETSCHEMAPATCHREQUEST.fields_by_name['new_schema'].message_type = _FEATURESCHEMA
_FEATURESETSCHEMAPATCHRESPONSE.fields_by_name['schema'].message_type = _FEATURESCHEMA
_GETRECOMMENDATIONREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_GETRECOMMENDATIONRESPONSE_JOIN.containing_type = _GETRECOMMENDATIONRESPONSE
_GETRECOMMENDATIONRESPONSE_MATCH.fields_by_name['target_feature_set'].message_type = _FEATURESET
_GETRECOMMENDATIONRESPONSE_MATCH.fields_by_name['joins'].message_type = _GETRECOMMENDATIONRESPONSE_JOIN
_GETRECOMMENDATIONRESPONSE_MATCH.containing_type = _GETRECOMMENDATIONRESPONSE
_GETRECOMMENDATIONRESPONSE.fields_by_name['matches'].message_type = _GETRECOMMENDATIONRESPONSE_MATCH
_JOB.fields_by_name['job_type'].enum_type = _JOBTYPE
_JOBPROGRESSOUTPUT_PROGRESS.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBPROGRESSOUTPUT_PROGRESS.containing_type = _JOBPROGRESSOUTPUT
_JOBPROGRESSOUTPUT.fields_by_name['progress'].message_type = _JOBPROGRESSOUTPUT_PROGRESS
_FEATURESETPERMISSIONREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_FEATURESETPERMISSIONREQUEST.fields_by_name['permission'].enum_type = _PERMISSIONTYPE
_PROJECTPERMISSIONREQUEST.fields_by_name['project'].message_type = _PROJECT
_PROJECTPERMISSIONREQUEST.fields_by_name['permission'].enum_type = _PERMISSIONTYPE
_STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['raw_data'].message_type = _RAWDATALOCATION
_STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['derived_from'].message_type = _DERIVEDINFORMATION
_STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['cred'].message_type = _CREDENTIALS
_STARTEXTRACTSCHEMAJOBREQUEST.oneofs_by_name['source'].fields.append(
  _STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['raw_data'])
_STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['raw_data'].containing_oneof = _STARTEXTRACTSCHEMAJOBREQUEST.oneofs_by_name['source']
_STARTEXTRACTSCHEMAJOBREQUEST.oneofs_by_name['source'].fields.append(
  _STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['derived_from'])
_STARTEXTRACTSCHEMAJOBREQUEST.fields_by_name['derived_from'].containing_oneof = _STARTEXTRACTSCHEMAJOBREQUEST.oneofs_by_name['source']
_EXTRACTSCHEMARESPONSE.fields_by_name['schema'].message_type = _FEATURESCHEMA
_EXTRACTSCHEMARESPONSE.fields_by_name['derived_from'].message_type = _DERIVEDINFORMATION
_LISTFEATURESETSVERSIONREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_FEATURESETRESPONSE.fields_by_name['feature_set'].message_type = _FEATURESET
_FEATURESETRESPONSE.fields_by_name['job'].message_type = _JOBID
_UPDATEFEATURESETRESPONSE.fields_by_name['updated_feature_set'].message_type = _FEATURESET
_UPDATEPROJECTRESPONSE.fields_by_name['updated_project'].message_type = _PROJECT
_UPDATEFEATURERESPONSE.fields_by_name['updated_feature_set'].message_type = _FEATURESET
_UPDATEFEATURERESPONSE.fields_by_name['updated_feature'].message_type = _FEATURE
_PROJECTRESPONSE.fields_by_name['project'].message_type = _PROJECT
_LOGINRESPONSE.oneofs_by_name['response'].fields.append(
  _LOGINRESPONSE.fields_by_name['login_url'])
_LOGINRESPONSE.fields_by_name['login_url'].containing_oneof = _LOGINRESPONSE.oneofs_by_name['response']
_LOGINRESPONSE.oneofs_by_name['response'].fields.append(
  _LOGINRESPONSE.fields_by_name['refresh_token'])
_LOGINRESPONSE.fields_by_name['refresh_token'].containing_oneof = _LOGINRESPONSE.oneofs_by_name['response']
_GETACTIVEUSERRESPONSE.fields_by_name['user'].message_type = _USERBASICINFO
_DELETEFEATURESETREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_USER.fields_by_name['user_basic_info'].message_type = _USERBASICINFO
_DELETEPROJECTREQUEST.fields_by_name['project'].message_type = _PROJECT
_UPDATEPROJECTMETADATAREQUEST.fields_by_name['project'].message_type = _PROJECT
_CREATEPROJECTREQUEST.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CREATEPROJECTRESPONSE.fields_by_name['project'].message_type = _PROJECT
_LISTPROJECTSRESPONSE.fields_by_name['projects'].message_type = _PROJECT
_GETINGESTHISTORYRESPONSE.fields_by_name['ingest_history'].message_type = _FEATURESETINGEST
_LISTFEATURESETSACROSSPROJECTSREQUEST.fields_by_name['query'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetSearch__pb2._QUERY
_LISTFEATURESETSPAGEREQUEST.fields_by_name['query'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetSearch__pb2._QUERY
_LISTFEATURESETSPAGERESPONSE.fields_by_name['feature_sets'].message_type = _FEATURESET
_CREDENTIALS.fields_by_name['aws'].message_type = _AWSCREDENTIALS
_CREDENTIALS.fields_by_name['azure'].message_type = _AZURECREDENTIALS
_CREDENTIALS.fields_by_name['snowflake'].message_type = _SNOWFLAKECREDENTIALS
_CREDENTIALS.fields_by_name['jdbc_database'].message_type = _JDBCCREDENTIALS
_LISTFEATURESETSRESPONSE.fields_by_name['feature_sets'].message_type = _FEATURESET
_LISTFEATURESETVERSIONSRESPONSE.fields_by_name['versions'].message_type = _FEATURESETVERSIONDESCRIPTION
_FEATURESETVERSIONDESCRIPTION.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETFEATURESETREQUEST.fields_by_name['project'].message_type = _PROJECT
_STARTINGESTJOBREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_STARTINGESTJOBREQUEST.fields_by_name['cred'].message_type = _CREDENTIALS
_STARTINGESTJOBREQUEST.fields_by_name['data_source'].message_type = _RAWDATALOCATION
_INGESTRESPONSE_INGESTMETA.fields_by_name['ingestion_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INGESTRESPONSE_INGESTMETA.fields_by_name['ingest_scope'].message_type = _SCOPE
_INGESTRESPONSE_INGESTMETA.containing_type = _INGESTRESPONSE
_INGESTRESPONSE.fields_by_name['meta'].message_type = _INGESTRESPONSE_INGESTMETA
_INGESTRESPONSE.fields_by_name['feature_set'].message_type = _FEATURESET
_RETRIEVEREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_RETRIEVEASLINKSRESPONSE.fields_by_name['retrieve_scope'].message_type = _SCOPE
_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY.containing_type = _RETRIEVEASSPARKRESPONSE
_RETRIEVEASSPARKRESPONSE.fields_by_name['options'].message_type = _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY
_RETRIEVEASSPARKRESPONSE.fields_by_name['retrieve_scope'].message_type = _SCOPE
_PREVIEWREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_STARTMATERIALIZATIONONLINEREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_MATERIALIZATIONONLINERESPONSE.fields_by_name['materialization_scope'].message_type = _SCOPE
_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY.containing_type = _INGESTWRITECREDENTIALRESPONSE
_INGESTWRITECREDENTIALRESPONSE.fields_by_name['options'].message_type = _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY
_RAWDATALOCATION.fields_by_name['csv'].message_type = _CSVFILESPEC
_RAWDATALOCATION.fields_by_name['parquet'].message_type = _PARQUETFILESPEC
_RAWDATALOCATION.fields_by_name['snowflake'].message_type = _SNOWFLAKETABLESPEC
_RAWDATALOCATION.fields_by_name['jdbc'].message_type = _JDBCTABLESPEC
_RAWDATALOCATION.fields_by_name['json'].message_type = _JSONFILESPEC
_RAWDATALOCATION.fields_by_name['delta_table'].message_type = _DELTATABLESPEC
_RAWDATALOCATION.fields_by_name['csv_folder'].message_type = _CSVFOLDERSPEC
_RAWDATALOCATION.fields_by_name['parquet_folder'].message_type = _PARQUETFOLDERSPEC
_RAWDATALOCATION.fields_by_name['json_folder'].message_type = _JSONFOLDERSPEC
_RAWDATALOCATION.fields_by_name['temp_parquet'].message_type = _TEMPPARQUETFILESPEC
_RAWDATALOCATION.fields_by_name['online_source'].message_type = _ONLINESOURCESPEC
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['csv'])
_RAWDATALOCATION.fields_by_name['csv'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['parquet'])
_RAWDATALOCATION.fields_by_name['parquet'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['snowflake'])
_RAWDATALOCATION.fields_by_name['snowflake'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['jdbc'])
_RAWDATALOCATION.fields_by_name['jdbc'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['json'])
_RAWDATALOCATION.fields_by_name['json'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['delta_table'])
_RAWDATALOCATION.fields_by_name['delta_table'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['csv_folder'])
_RAWDATALOCATION.fields_by_name['csv_folder'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['parquet_folder'])
_RAWDATALOCATION.fields_by_name['parquet_folder'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['json_folder'])
_RAWDATALOCATION.fields_by_name['json_folder'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['temp_parquet'])
_RAWDATALOCATION.fields_by_name['temp_parquet'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_RAWDATALOCATION.oneofs_by_name['source'].fields.append(
  _RAWDATALOCATION.fields_by_name['online_source'])
_RAWDATALOCATION.fields_by_name['online_source'].containing_oneof = _RAWDATALOCATION.oneofs_by_name['source']
_SNOWFLAKETABLESPEC.fields_by_name['proxy'].message_type = _PROXY
_DELTATABLESPEC.fields_by_name['filter'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetSearch__pb2._FILTER
_TRANSFORMATION.fields_by_name['mojo'].message_type = _MOJOTRANSFORMATION
_TRANSFORMATION.fields_by_name['spark_pipeline'].message_type = _SPARKPIPELINETRANSFORMATION
_TRANSFORMATION.fields_by_name['join'].message_type = _JOINTRANSFORMATION
_TRANSFORMATION.oneofs_by_name['value'].fields.append(
  _TRANSFORMATION.fields_by_name['mojo'])
_TRANSFORMATION.fields_by_name['mojo'].containing_oneof = _TRANSFORMATION.oneofs_by_name['value']
_TRANSFORMATION.oneofs_by_name['value'].fields.append(
  _TRANSFORMATION.fields_by_name['spark_pipeline'])
_TRANSFORMATION.fields_by_name['spark_pipeline'].containing_oneof = _TRANSFORMATION.oneofs_by_name['value']
_TRANSFORMATION.oneofs_by_name['value'].fields.append(
  _TRANSFORMATION.fields_by_name['join'])
_TRANSFORMATION.fields_by_name['join'].containing_oneof = _TRANSFORMATION.oneofs_by_name['value']
_DERIVEDINFORMATION.fields_by_name['feature_set_ids'].message_type = _VERSIONEDID
_DERIVEDINFORMATION.fields_by_name['transformation'].message_type = _TRANSFORMATION
_FILTERCONDITIONUNION.fields_by_name['filter'].message_type = _FEATUREFILTER
_FILTERCONDITIONUNION.fields_by_name['logic'].message_type = _FEATUREFILTERLOGIC
_FILTERCONDITIONUNION.oneofs_by_name['condition'].fields.append(
  _FILTERCONDITIONUNION.fields_by_name['filter'])
_FILTERCONDITIONUNION.fields_by_name['filter'].containing_oneof = _FILTERCONDITIONUNION.oneofs_by_name['condition']
_FILTERCONDITIONUNION.oneofs_by_name['condition'].fields.append(
  _FILTERCONDITIONUNION.fields_by_name['logic'])
_FILTERCONDITIONUNION.fields_by_name['logic'].containing_oneof = _FILTERCONDITIONUNION.oneofs_by_name['condition']
_FEATUREFILTER.fields_by_name['feature'].message_type = _SELECTEDFEATURE
_FEATUREFILTER.fields_by_name['operator'].enum_type = _FEATUREFILTEROPERATOR
_FEATUREFILTERLOGIC.fields_by_name['left'].message_type = _FILTERCONDITIONUNION
_FEATUREFILTERLOGIC.fields_by_name['right'].message_type = _FILTERCONDITIONUNION
_FEATUREFILTERLOGIC.fields_by_name['logic_operator'].enum_type = _FEATUREFILTERLOGICOPERATOR
_FEATUREQUERY_FROM.fields_by_name['feature_set'].message_type = _VERSIONEDID
_FEATUREQUERY_FROM.containing_type = _FEATUREQUERY
_FEATUREQUERY_JOIN_ON.fields_by_name['left'].message_type = _SELECTEDFEATURE
_FEATUREQUERY_JOIN_ON.fields_by_name['right'].message_type = _SELECTEDFEATURE
_FEATUREQUERY_JOIN_ON.containing_type = _FEATUREQUERY_JOIN
_FEATUREQUERY_JOIN.fields_by_name['feature_set'].message_type = _VERSIONEDID
_FEATUREQUERY_JOIN.fields_by_name['on'].message_type = _FEATUREQUERY_JOIN_ON
_FEATUREQUERY_JOIN.containing_type = _FEATUREQUERY
_FEATUREQUERY.fields_by_name['selected_features'].message_type = _SELECTEDFEATURE
_FEATUREQUERY.fields_by_name['from_feature_set'].message_type = _FEATUREQUERY_FROM
_FEATUREQUERY.fields_by_name['join'].message_type = _FEATUREQUERY_JOIN
_FEATUREQUERY.fields_by_name['where'].message_type = _FILTERCONDITIONUNION
_FEATUREVIEW.fields_by_name['query'].message_type = _FEATUREQUERY
_CREATEFEATUREVIEWREQUEST.fields_by_name['query'].message_type = _FEATUREQUERY
_CREATEFEATUREVIEWNEWVERSIONREQUEST.fields_by_name['query'].message_type = _FEATUREQUERY
_FEATUREVIEWRESPONSE.fields_by_name['feature_view'].message_type = _FEATUREVIEW
_LISTFEATUREVIEWSRESPONSE.fields_by_name['feature_views'].message_type = _FEATUREVIEW
_RETRIEVEFEATUREVIEWASSPARKREQUEST.fields_by_name['start_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RETRIEVEFEATUREVIEWASSPARKREQUEST.fields_by_name['end_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY.containing_type = _RETRIEVEFEATUREVIEWASSPARKRESPONSE
_RETRIEVEFEATUREVIEWASSPARKRESPONSE.fields_by_name['options'].message_type = _RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY
_RETRIEVEFEATUREVIEWASASLINKSREQUEST.fields_by_name['start_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RETRIEVEFEATUREVIEWASASLINKSREQUEST.fields_by_name['end_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MLDATASETFEATURE.fields_by_name['feature_type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURETYPE
_MLDATASET.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MLDATASET.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MLDATASET.fields_by_name['features'].message_type = _MLDATASETFEATURE
_MLDATASET.fields_by_name['state'].enum_type = _MLDATASET_MLDATASETSTATE
_MLDATASET_MLDATASETSTATE.containing_type = _MLDATASET
_CREATEMLDATASETREQUEST.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEMLDATASETREQUEST.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEMLDATASETRESPONSE.fields_by_name['ml_dataset'].message_type = _MLDATASET
_CREATEMLDATASETRESPONSE.fields_by_name['job'].message_type = _JOBID
_LISTMLDATASETSRESPONSE.fields_by_name['ml_datasets'].message_type = _MLDATASET
_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY.containing_type = _RETRIEVEMLDATASETASSPARKRESPONSE
_RETRIEVEMLDATASETASSPARKRESPONSE.fields_by_name['options'].message_type = _RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY
_FEATURESET_STATISTICS.containing_type = _FEATURESET
_FEATURESET_SPECIALDATA_LEGAL.fields_by_name['approved_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET_SPECIALDATA_LEGAL.containing_type = _FEATURESET_SPECIALDATA
_FEATURESET_SPECIALDATA.fields_by_name['legal'].message_type = _FEATURESET_SPECIALDATA_LEGAL
_FEATURESET_SPECIALDATA.containing_type = _FEATURESET
_FEATURESET_ONLINE.containing_type = _FEATURESET
_FEATURESET.fields_by_name['feature_set_type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETTYPE
_FEATURESET.fields_by_name['owner'].message_type = _USERBASICINFO
_FEATURESET.fields_by_name['author'].message_type = _USERBASICINFO
_FEATURESET.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET.fields_by_name['last_update_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET.fields_by_name['deprecated_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESET.fields_by_name['process_interval_unit'].enum_type = _PROCESSINTERVALUNIT
_FEATURESET.fields_by_name['time_to_live'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2._TIMETOLIVE
_FEATURESET.fields_by_name['features'].message_type = _FEATURE
_FEATURESET.fields_by_name['statistics'].message_type = _FEATURESET_STATISTICS
_FEATURESET.fields_by_name['special_data'].message_type = _FEATURESET_SPECIALDATA
_FEATURESET.fields_by_name['time_travel_scope'].message_type = _SCOPE
_FEATURESET.fields_by_name['online'].message_type = _FEATURESET_ONLINE
_FEATURESET.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FEATURESET.fields_by_name['online_materialization_scope'].message_type = _SCOPE
_FEATURESET.fields_by_name['derived_from'].message_type = _DERIVEDINFORMATION
_SCOPE.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOPE.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REGISTERFEATURESETREQUEST.fields_by_name['project'].message_type = _PROJECT
_REGISTERFEATURESETREQUEST.fields_by_name['schema'].message_type = _FEATURESCHEMA
_REGISTERFEATURESETREQUEST.fields_by_name['feature_set_type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETTYPE
_REGISTERFEATURESETREQUEST.fields_by_name['online'].message_type = _FEATURESET_ONLINE
_REGISTERFEATURESETREQUEST.fields_by_name['process_interval_unit'].enum_type = _PROCESSINTERVALUNIT
_REGISTERFEATURESETREQUEST.fields_by_name['special_data'].message_type = _FEATURESET_SPECIALDATA
_REGISTERFEATURESETREQUEST.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_REGISTERFEATURESETREQUEST.fields_by_name['time_to_live'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2._TIMETOLIVE
_REGISTERFEATURESETREQUEST.fields_by_name['derived_from'].message_type = _DERIVEDINFORMATION
_CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['feature_set'].message_type = _FEATURESET
_CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['schema'].message_type = _FEATURESCHEMA
_CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['derived_from'].message_type = _DERIVEDINFORMATION
_CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['backfill_options'].message_type = _BACKFILLOPTIONS
_FEATUREPROFILE.fields_by_name['feature_type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURETYPE
_FEATUREPROFILE.fields_by_name['categorical'].message_type = _CATEGORICALFEATURESTATISTICS
_FEATUREPROFILE.fields_by_name['statistics'].message_type = _FEATURESTATISTICS
_FEATURESCHEMA_SPECIALDATA.containing_type = _FEATURESCHEMA
_FEATURESCHEMA.fields_by_name['nested'].message_type = _FEATURESCHEMA
_FEATURESCHEMA.fields_by_name['special_data'].message_type = _FEATURESCHEMA_SPECIALDATA
_FEATURESCHEMA.fields_by_name['feature_type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURETYPE
_FEATURE_MONITORING.containing_type = _FEATURE
_FEATURE_SPECIALDATA.containing_type = _FEATURE
_FEATURE.fields_by_name['profile'].message_type = _FEATUREPROFILE
_FEATURE.fields_by_name['monitoring'].message_type = _FEATURE_MONITORING
_FEATURE.fields_by_name['nested_features'].message_type = _FEATURE
_FEATURE.fields_by_name['special_data'].message_type = _FEATURE_SPECIALDATA
_FEATURE.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CATEGORICALFEATURESTATISTICS_FEATURETOP.containing_type = _CATEGORICALFEATURESTATISTICS
_CATEGORICALFEATURESTATISTICS.fields_by_name['top'].message_type = _CATEGORICALFEATURESTATISTICS_FEATURETOP
_PROJECT.fields_by_name['owner'].message_type = _USERBASICINFO
_PROJECT.fields_by_name['author'].message_type = _USERBASICINFO
_PROJECT.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROJECT.fields_by_name['last_update_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROJECT.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LISTABLEPROJECT.fields_by_name['last_update_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTABLEPROJECT.fields_by_name['permission'].enum_type = _ACTIVEPERMISSION
_LISTABLEPROJECT.fields_by_name['author'].message_type = _USERBASICINFO
_FEATURESETINGEST.fields_by_name['ingest_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESETINGEST.fields_by_name['source'].message_type = _RAWDATALOCATION
_FEATURESETINGEST.fields_by_name['scope'].message_type = _SCOPE
_PERSONALACCESSTOKEN.fields_by_name['last_used'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERSONALACCESSTOKEN.fields_by_name['creation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERSONALACCESSTOKEN.fields_by_name['expiry_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GENERATETRANSFORMATIONUPLOADREQUEST.fields_by_name['transformation_type'].enum_type = _TRANSFORMATIONTYPE
_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY.containing_type = _GENERATETRANSFORMATIONUPLOADRESPONSE
_GENERATETRANSFORMATIONUPLOADRESPONSE.fields_by_name['headers'].message_type = _GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY
_LISTPROJECTSPAGERESPONSE.fields_by_name['projects'].message_type = _PROJECT
_PROJECTSEARCHRESULTS.fields_by_name['listable_project'].message_type = _LISTABLEPROJECT
_LISTABLEFEATURESET.fields_by_name['last_update_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTABLEFEATURESET.fields_by_name['permission'].enum_type = _ACTIVEPERMISSION
_LISTABLEFEATURESET.fields_by_name['feature_set_type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETTYPE
_LISTABLEFEATURESET.fields_by_name['author'].message_type = _USERBASICINFO
_LISTABLEFEATURESET.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTABLEFEATURESET.fields_by_name['deprecated_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTABLEFEATURESET.fields_by_name['time_to_live'].message_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2._TIMETOLIVE
_LISTABLEFEATURESET.fields_by_name['special_data'].message_type = _FEATURESET_SPECIALDATA
_LISTABLEFEATURESET.fields_by_name['time_travel_scope'].message_type = _SCOPE
_LISTABLEFEATURESET.fields_by_name['online_materialization_scope'].message_type = _SCOPE
_LISTABLEFEATURESET.fields_by_name['derived_from'].message_type = _DERIVEDINFORMATION
_FEATURESETSEARCHRESULTS.fields_by_name['listable_feature_set'].message_type = _LISTABLEFEATURESET
_LISTABLEFEATURE.fields_by_name['feature_type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURETYPE
_FEATURESEARCHRESULTS.fields_by_name['listable_feature'].message_type = _LISTABLEFEATURE
_LISTFEATURESPAGERESPONSE.fields_by_name['features'].message_type = _FEATURE
_FEATURERESPONSE.fields_by_name['feature'].message_type = _FEATURE
_LISTFEATURESRESPONSE.fields_by_name['features'].message_type = _FEATURE
_LISTABLEFEATURESETRESPONSE.fields_by_name['listable_feature_set'].message_type = _LISTABLEFEATURESET
_SUBMITPENDINGPERMISSIONREQUEST.fields_by_name['permission'].enum_type = _PERMISSIONTYPE
_LISTPERMISSIONSPAGEREQUEST.fields_by_name['filters'].enum_type = _PERMISSIONSTATE
_LISTPROJECTSPERMISSIONSPAGERESPONSE.fields_by_name['entries'].message_type = _LISTABLEPROJECTTOPERMISSION
_LISTFEATURESETSPERMISSIONSPAGERESPONSE.fields_by_name['entries'].message_type = _LISTABLEFEATURESETTOPERMISSION
_LISTABLEPROJECTTOPERMISSION.fields_by_name['project'].message_type = _LISTABLEPROJECT
_LISTABLEPROJECTTOPERMISSION.fields_by_name['permission'].message_type = _PERMISSION
_LISTABLEFEATURESETTOPERMISSION.fields_by_name['feature_set'].message_type = _LISTABLEFEATURESET
_LISTABLEFEATURESETTOPERMISSION.fields_by_name['permission'].message_type = _PERMISSION
_PERMISSION_PROMOTEDUPDATE.fields_by_name['user'].message_type = _USERBASICINFO
_PERMISSION_PROMOTEDUPDATE.fields_by_name['updated_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERMISSION_PROMOTEDUPDATE.containing_type = _PERMISSION
_PERMISSION_REVOKEDUPDATE.fields_by_name['user'].message_type = _USERBASICINFO
_PERMISSION_REVOKEDUPDATE.fields_by_name['updated_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERMISSION_REVOKEDUPDATE.containing_type = _PERMISSION
_PERMISSION_GRANTEDORREJECTEDUPDATE.fields_by_name['user'].message_type = _USERBASICINFO
_PERMISSION_GRANTEDORREJECTEDUPDATE.fields_by_name['updated_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERMISSION_GRANTEDORREJECTEDUPDATE.containing_type = _PERMISSION
_PERMISSION.fields_by_name['resource_type'].enum_type = _RESOURCETYPE
_PERMISSION.fields_by_name['permission'].enum_type = _PERMISSIONTYPE
_PERMISSION.fields_by_name['user'].message_type = _USERBASICINFO
_PERMISSION.fields_by_name['state'].enum_type = _PERMISSIONSTATE
_PERMISSION.fields_by_name['created_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERMISSION.fields_by_name['last_update_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PERMISSION.fields_by_name['granted_or_rejected'].message_type = _PERMISSION_GRANTEDORREJECTEDUPDATE
_PERMISSION.fields_by_name['revoked'].message_type = _PERMISSION_REVOKEDUPDATE
_PERMISSION.fields_by_name['promoted'].message_type = _PERMISSION_PROMOTEDUPDATE
_GETACTIVEPERMISSIONRESPONSE.fields_by_name['permission'].enum_type = _ACTIVEPERMISSION
_SCHEDULEDTASK.fields_by_name['source'].message_type = _RAWDATALOCATION
_SCHEDULEDTASK.fields_by_name['next_run_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEDTASK.fields_by_name['last_exec'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEDTASK.fields_by_name['owner'].message_type = _USERBASICINFO
_SCHEDULEDTASK.fields_by_name['created_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEDTASK.fields_by_name['last_update_date_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEDTASK.fields_by_name['task_type'].enum_type = _TASKTYPE
_SCHEDULETASKREQUEST.fields_by_name['cred'].message_type = _CREDENTIALS
_SCHEDULETASKREQUEST.fields_by_name['source'].message_type = _RAWDATALOCATION
_LISTSCHEDULEDTASKSRESPONSE.fields_by_name['tasks'].message_type = _SCHEDULEDTASK
_SCHEDULEDTASKRESPONSE.fields_by_name['task'].message_type = _SCHEDULEDTASK
_LAZYINGESTRESPONSE.fields_by_name['job_id'].message_type = _JOBID
_LISTTRANSFORMATIONFUNCTIONSRESPONSE.fields_by_name['transformation_functions'].message_type = _TRANSFORMATIONFUNCTION
_GETTRANSFORMATIONFUNCTIONRESPONSE.fields_by_name['transformation_function'].message_type = _TRANSFORMATIONFUNCTION
_UPDATEPROJECTREQUEST.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATEPROJECTREQUEST.fields_by_name['fields_to_update'].enum_type = _UPDATABLEPROJECTFIELD
_UPDATEFEATURESETREQUEST.fields_by_name['type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURESETTYPE
_UPDATEFEATURESETREQUEST.fields_by_name['process_interval_unit'].enum_type = _PROCESSINTERVALUNIT
_UPDATEFEATURESETREQUEST.fields_by_name['time_to_live_offline_interval_unit'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2._OFFLINE_TIMETOLIVEINTERVAL
_UPDATEFEATURESETREQUEST.fields_by_name['time_to_live_online_interval_unit'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2._ONLINE_TIMETOLIVEINTERVAL
_UPDATEFEATURESETREQUEST.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATEFEATURESETREQUEST.fields_by_name['fields_to_update'].enum_type = _UPDATABLEFEATURESETFIELD
_UPDATEFEATUREREQUEST.fields_by_name['type'].enum_type = ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2._FEATURETYPE
_UPDATEFEATUREREQUEST.fields_by_name['custom_data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATEFEATUREREQUEST.fields_by_name['fields_to_update'].enum_type = _UPDATABLEFEATUREFIELD
_GETOWNERSRESPONSE.fields_by_name['owners'].message_type = _USERBASICINFO
_BACKFILLOPTIONS_FEATUREMAPPINGENTRY.containing_type = _BACKFILLOPTIONS
_BACKFILLOPTIONS.fields_by_name['from_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BACKFILLOPTIONS.fields_by_name['to_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BACKFILLOPTIONS.fields_by_name['spark_pipeline'].message_type = _SPARKPIPELINETRANSFORMATION
_BACKFILLOPTIONS.fields_by_name['feature_mapping'].message_type = _BACKFILLOPTIONS_FEATUREMAPPINGENTRY
_BACKFILLRESPONSE.fields_by_name['ingest_response'].message_type = _INGESTRESPONSE
DESCRIPTOR.message_types_by_name['FeatureCustomDataUpdateRequest'] = _FEATURECUSTOMDATAUPDATEREQUEST
DESCRIPTOR.message_types_by_name['IdentityProviderDetails'] = _IDENTITYPROVIDERDETAILS
DESCRIPTOR.message_types_by_name['GetWebConfigResponse'] = _GETWEBCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['FeatureSetCustomDataUpdateRequest'] = _FEATURESETCUSTOMDATAUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ProjectCustomDataUpdateRequest'] = _PROJECTCUSTOMDATAUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetTypeUpdateRequest'] = _FEATURESETTYPEUPDATEREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureSetsLastMinorForCurrentMajorRequest'] = _GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST
DESCRIPTOR.message_types_by_name['FeatureTypeUpdateRequest'] = _FEATURETYPEUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureDoubleFieldUpdateRequest'] = _FEATUREDOUBLEFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureStringFieldUpdateRequest'] = _FEATURESTRINGFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureStringArrayFieldUpdateRequest'] = _FEATURESTRINGARRAYFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureBooleanFieldUpdateRequest'] = _FEATUREBOOLEANFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest'] = _FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest'] = _FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetIntFieldUpdateRequest'] = _FEATURESETINTFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetProcessIntervalUnitUpdateRequest'] = _FEATURESETPROCESSINTERVALUNITUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetStringArrayFieldUpdateRequest'] = _FEATURESETSTRINGARRAYFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetBooleanFieldUpdateRequest'] = _FEATURESETBOOLEANFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetStringFieldUpdateRequest'] = _FEATURESETSTRINGFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetUserFieldUpdateRequest'] = _FEATURESETUSERFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ProjectBooleanFieldUpdateRequest'] = _PROJECTBOOLEANFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ProjectStringFieldUpdateRequest'] = _PROJECTSTRINGFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ProjectUserFieldUpdateRequest'] = _PROJECTUSERFIELDUPDATEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetExistsRequest'] = _FEATURESETEXISTSREQUEST
DESCRIPTOR.message_types_by_name['GetIngestHistoryRequest'] = _GETINGESTHISTORYREQUEST
DESCRIPTOR.message_types_by_name['ProjectExistsRequest'] = _PROJECTEXISTSREQUEST
DESCRIPTOR.message_types_by_name['ExistsResponse'] = _EXISTSRESPONSE
DESCRIPTOR.message_types_by_name['ProjectsDefaultResponse'] = _PROJECTSDEFAULTRESPONSE
DESCRIPTOR.message_types_by_name['HasPermissionToRetrieveRequest'] = _HASPERMISSIONTORETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['HasPermissionToRetrieveResponse'] = _HASPERMISSIONTORETRIEVERESPONSE
DESCRIPTOR.message_types_by_name['StartRevertIngestJobRequest'] = _STARTREVERTINGESTJOBREQUEST
DESCRIPTOR.message_types_by_name['OnlineRetrieveMeta'] = _ONLINERETRIEVEMETA
DESCRIPTOR.message_types_by_name['RefreshTokenRequest'] = _REFRESHTOKENREQUEST
DESCRIPTOR.message_types_by_name['GetUserByMailRequest'] = _GETUSERBYMAILREQUEST
DESCRIPTOR.message_types_by_name['GetUserByMailResponse'] = _GETUSERBYMAILRESPONSE
DESCRIPTOR.message_types_by_name['TokenRequest'] = _TOKENREQUEST
DESCRIPTOR.message_types_by_name['GenerateTokenRequest'] = _GENERATETOKENREQUEST
DESCRIPTOR.message_types_by_name['TokenResponse'] = _TOKENRESPONSE
DESCRIPTOR.message_types_by_name['ListTokensResponse'] = _LISTTOKENSRESPONSE
DESCRIPTOR.message_types_by_name['RawTokenResponse'] = _RAWTOKENRESPONSE
DESCRIPTOR.message_types_by_name['ListJobsRequest'] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListJobsResponse'] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name['FeatureSetSchemaCompatibilityRequest'] = _FEATURESETSCHEMACOMPATIBILITYREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetSchemaCompatibilityResponse'] = _FEATURESETSCHEMACOMPATIBILITYRESPONSE
DESCRIPTOR.message_types_by_name['FeatureSetSchemaPatchRequest'] = _FEATURESETSCHEMAPATCHREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetSchemaPatchResponse'] = _FEATURESETSCHEMAPATCHRESPONSE
DESCRIPTOR.message_types_by_name['JobId'] = _JOBID
DESCRIPTOR.message_types_by_name['GetRecommendationRequest'] = _GETRECOMMENDATIONREQUEST
DESCRIPTOR.message_types_by_name['GetRecommendationResponse'] = _GETRECOMMENDATIONRESPONSE
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['JobProgressInput'] = _JOBPROGRESSINPUT
DESCRIPTOR.message_types_by_name['JobProgressOutput'] = _JOBPROGRESSOUTPUT
DESCRIPTOR.message_types_by_name['FeatureSetPermissionRequest'] = _FEATURESETPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['ProjectPermissionRequest'] = _PROJECTPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['StartExtractSchemaJobRequest'] = _STARTEXTRACTSCHEMAJOBREQUEST
DESCRIPTOR.message_types_by_name['ExtractSchemaResponse'] = _EXTRACTSCHEMARESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureSetsVersionRequest'] = _LISTFEATURESETSVERSIONREQUEST
DESCRIPTOR.message_types_by_name['FeatureSetResponse'] = _FEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeatureSetResponse'] = _UPDATEFEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['UpdateProjectResponse'] = _UPDATEPROJECTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeatureResponse'] = _UPDATEFEATURERESPONSE
DESCRIPTOR.message_types_by_name['ProjectResponse'] = _PROJECTRESPONSE
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['GetActiveUserResponse'] = _GETACTIVEUSERRESPONSE
DESCRIPTOR.message_types_by_name['GetProjectRequest'] = _GETPROJECTREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeatureSetRequest'] = _DELETEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['LogoutRequest'] = _LOGOUTREQUEST
DESCRIPTOR.message_types_by_name['UserBasicInfo'] = _USERBASICINFO
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['AccessTokenResponse'] = _ACCESSTOKENRESPONSE
DESCRIPTOR.message_types_by_name['DeleteProjectRequest'] = _DELETEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['UpdateProjectMetadataRequest'] = _UPDATEPROJECTMETADATAREQUEST
DESCRIPTOR.message_types_by_name['CreateProjectRequest'] = _CREATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['CreateProjectResponse'] = _CREATEPROJECTRESPONSE
DESCRIPTOR.message_types_by_name['ListProjectsResponse'] = _LISTPROJECTSRESPONSE
DESCRIPTOR.message_types_by_name['GetIngestHistoryResponse'] = _GETINGESTHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureSetsAcrossProjectsRequest'] = _LISTFEATURESETSACROSSPROJECTSREQUEST
DESCRIPTOR.message_types_by_name['ListFeatureSetsPageRequest'] = _LISTFEATURESETSPAGEREQUEST
DESCRIPTOR.message_types_by_name['ListFeatureSetsPageResponse'] = _LISTFEATURESETSPAGERESPONSE
DESCRIPTOR.message_types_by_name['AWSCredentials'] = _AWSCREDENTIALS
DESCRIPTOR.message_types_by_name['AzureCredentials'] = _AZURECREDENTIALS
DESCRIPTOR.message_types_by_name['SnowflakeCredentials'] = _SNOWFLAKECREDENTIALS
DESCRIPTOR.message_types_by_name['JDBCCredentials'] = _JDBCCREDENTIALS
DESCRIPTOR.message_types_by_name['Credentials'] = _CREDENTIALS
DESCRIPTOR.message_types_by_name['ListFeatureSetsResponse'] = _LISTFEATURESETSRESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureSetVersionsResponse'] = _LISTFEATURESETVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['FeatureSetVersionDescription'] = _FEATURESETVERSIONDESCRIPTION
DESCRIPTOR.message_types_by_name['GetFeatureSetRequest'] = _GETFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['StartIngestJobRequest'] = _STARTINGESTJOBREQUEST
DESCRIPTOR.message_types_by_name['IngestResponse'] = _INGESTRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveRequest'] = _RETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['RetrieveAsLinksResponse'] = _RETRIEVEASLINKSRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveAsSparkResponse'] = _RETRIEVEASSPARKRESPONSE
DESCRIPTOR.message_types_by_name['PreviewRequest'] = _PREVIEWREQUEST
DESCRIPTOR.message_types_by_name['StartMaterializationOnlineRequest'] = _STARTMATERIALIZATIONONLINEREQUEST
DESCRIPTOR.message_types_by_name['MaterializationOnlineResponse'] = _MATERIALIZATIONONLINERESPONSE
DESCRIPTOR.message_types_by_name['IngestWriteCredentialRequest'] = _INGESTWRITECREDENTIALREQUEST
DESCRIPTOR.message_types_by_name['IngestWriteCredentialResponse'] = _INGESTWRITECREDENTIALRESPONSE
DESCRIPTOR.message_types_by_name['RawDataLocation'] = _RAWDATALOCATION
DESCRIPTOR.message_types_by_name['OnlineSourceSpec'] = _ONLINESOURCESPEC
DESCRIPTOR.message_types_by_name['CSVFileSpec'] = _CSVFILESPEC
DESCRIPTOR.message_types_by_name['JSONFileSpec'] = _JSONFILESPEC
DESCRIPTOR.message_types_by_name['ParquetFileSpec'] = _PARQUETFILESPEC
DESCRIPTOR.message_types_by_name['TempParquetFileSpec'] = _TEMPPARQUETFILESPEC
DESCRIPTOR.message_types_by_name['Proxy'] = _PROXY
DESCRIPTOR.message_types_by_name['SnowflakeTableSpec'] = _SNOWFLAKETABLESPEC
DESCRIPTOR.message_types_by_name['JDBCTableSpec'] = _JDBCTABLESPEC
DESCRIPTOR.message_types_by_name['DeltaTableSpec'] = _DELTATABLESPEC
DESCRIPTOR.message_types_by_name['CSVFolderSpec'] = _CSVFOLDERSPEC
DESCRIPTOR.message_types_by_name['ParquetFolderSpec'] = _PARQUETFOLDERSPEC
DESCRIPTOR.message_types_by_name['JSONFolderSpec'] = _JSONFOLDERSPEC
DESCRIPTOR.message_types_by_name['MojoTransformation'] = _MOJOTRANSFORMATION
DESCRIPTOR.message_types_by_name['SparkPipelineTransformation'] = _SPARKPIPELINETRANSFORMATION
DESCRIPTOR.message_types_by_name['JoinTransformation'] = _JOINTRANSFORMATION
DESCRIPTOR.message_types_by_name['VersionedId'] = _VERSIONEDID
DESCRIPTOR.message_types_by_name['Transformation'] = _TRANSFORMATION
DESCRIPTOR.message_types_by_name['DerivedInformation'] = _DERIVEDINFORMATION
DESCRIPTOR.message_types_by_name['SelectedFeature'] = _SELECTEDFEATURE
DESCRIPTOR.message_types_by_name['FilterConditionUnion'] = _FILTERCONDITIONUNION
DESCRIPTOR.message_types_by_name['FeatureFilter'] = _FEATUREFILTER
DESCRIPTOR.message_types_by_name['FeatureFilterLogic'] = _FEATUREFILTERLOGIC
DESCRIPTOR.message_types_by_name['FeatureQuery'] = _FEATUREQUERY
DESCRIPTOR.message_types_by_name['FeatureView'] = _FEATUREVIEW
DESCRIPTOR.message_types_by_name['CreateFeatureViewRequest'] = _CREATEFEATUREVIEWREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeatureViewRequest'] = _UPDATEFEATUREVIEWREQUEST
DESCRIPTOR.message_types_by_name['CreateFeatureViewNewVersionRequest'] = _CREATEFEATUREVIEWNEWVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureViewRequest'] = _GETFEATUREVIEWREQUEST
DESCRIPTOR.message_types_by_name['FeatureViewResponse'] = _FEATUREVIEWRESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureViewsRequest'] = _LISTFEATUREVIEWSREQUEST
DESCRIPTOR.message_types_by_name['ListFeatureViewsResponse'] = _LISTFEATUREVIEWSRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveFeatureViewAsSparkRequest'] = _RETRIEVEFEATUREVIEWASSPARKREQUEST
DESCRIPTOR.message_types_by_name['RetrieveFeatureViewAsSparkResponse'] = _RETRIEVEFEATUREVIEWASSPARKRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveFeatureViewAsAsLinksRequest'] = _RETRIEVEFEATUREVIEWASASLINKSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveFeatureViewAsAsLinksResponse'] = _RETRIEVEFEATUREVIEWASASLINKSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteFeatureViewRequest'] = _DELETEFEATUREVIEWREQUEST
DESCRIPTOR.message_types_by_name['MLDatasetFeature'] = _MLDATASETFEATURE
DESCRIPTOR.message_types_by_name['MLDataset'] = _MLDATASET
DESCRIPTOR.message_types_by_name['CreateMLDatasetRequest'] = _CREATEMLDATASETREQUEST
DESCRIPTOR.message_types_by_name['UpdateMLDatasetRequest'] = _UPDATEMLDATASETREQUEST
DESCRIPTOR.message_types_by_name['DeleteMLDatasetRequest'] = _DELETEMLDATASETREQUEST
DESCRIPTOR.message_types_by_name['CreateMLDatasetResponse'] = _CREATEMLDATASETRESPONSE
DESCRIPTOR.message_types_by_name['GetMLDatasetRequest'] = _GETMLDATASETREQUEST
DESCRIPTOR.message_types_by_name['ListMLDatasetsRequest'] = _LISTMLDATASETSREQUEST
DESCRIPTOR.message_types_by_name['ListMLDatasetsResponse'] = _LISTMLDATASETSRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveMLDatasetAsSparkRequest'] = _RETRIEVEMLDATASETASSPARKREQUEST
DESCRIPTOR.message_types_by_name['RetrieveMLDatasetAsSparkResponse'] = _RETRIEVEMLDATASETASSPARKRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveMLDatasetAsAsLinksRequest'] = _RETRIEVEMLDATASETASASLINKSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveMLDatasetAsAsLinksResponse'] = _RETRIEVEMLDATASETASASLINKSRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveMLDatasetOnlineRequest'] = _RETRIEVEMLDATASETONLINEREQUEST
DESCRIPTOR.message_types_by_name['FeatureSet'] = _FEATURESET
DESCRIPTOR.message_types_by_name['GetFeatureSetPreviewRequest'] = _GETFEATURESETPREVIEWREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureSetPreviewResponse'] = _GETFEATURESETPREVIEWRESPONSE
DESCRIPTOR.message_types_by_name['Scope'] = _SCOPE
DESCRIPTOR.message_types_by_name['RegisterFeatureSetRequest'] = _REGISTERFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['CreateNewFeatureSetVersionRequest'] = _CREATENEWFEATURESETVERSIONREQUEST
DESCRIPTOR.message_types_by_name['FeatureProfile'] = _FEATUREPROFILE
DESCRIPTOR.message_types_by_name['FeatureSchema'] = _FEATURESCHEMA
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['FeatureStatistics'] = _FEATURESTATISTICS
DESCRIPTOR.message_types_by_name['CategoricalFeatureStatistics'] = _CATEGORICALFEATURESTATISTICS
DESCRIPTOR.message_types_by_name['GetVersionResponse'] = _GETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['ListableProject'] = _LISTABLEPROJECT
DESCRIPTOR.message_types_by_name['FeatureSetIngest'] = _FEATURESETINGEST
DESCRIPTOR.message_types_by_name['PersonalAccessToken'] = _PERSONALACCESSTOKEN
DESCRIPTOR.message_types_by_name['GenerateTransformationUploadRequest'] = _GENERATETRANSFORMATIONUPLOADREQUEST
DESCRIPTOR.message_types_by_name['GenerateTransformationUploadResponse'] = _GENERATETRANSFORMATIONUPLOADRESPONSE
DESCRIPTOR.message_types_by_name['ListProjectsPageRequest'] = _LISTPROJECTSPAGEREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsPageResponse'] = _LISTPROJECTSPAGERESPONSE
DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['ProjectSearchResults'] = _PROJECTSEARCHRESULTS
DESCRIPTOR.message_types_by_name['ListableFeatureSet'] = _LISTABLEFEATURESET
DESCRIPTOR.message_types_by_name['FeatureSetSearchResults'] = _FEATURESETSEARCHRESULTS
DESCRIPTOR.message_types_by_name['ListableFeature'] = _LISTABLEFEATURE
DESCRIPTOR.message_types_by_name['FeatureSearchResults'] = _FEATURESEARCHRESULTS
DESCRIPTOR.message_types_by_name['FeatureSetRequestId'] = _FEATURESETREQUESTID
DESCRIPTOR.message_types_by_name['GetFeatureRequest'] = _GETFEATUREREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesPageResponse'] = _LISTFEATURESPAGERESPONSE
DESCRIPTOR.message_types_by_name['FeatureResponse'] = _FEATURERESPONSE
DESCRIPTOR.message_types_by_name['ListFeaturesRequest'] = _LISTFEATURESREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesResponse'] = _LISTFEATURESRESPONSE
DESCRIPTOR.message_types_by_name['ListableFeatureSetRequest'] = _LISTABLEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['ListableFeatureSetResponse'] = _LISTABLEFEATURESETRESPONSE
DESCRIPTOR.message_types_by_name['SubmitPendingPermissionRequest'] = _SUBMITPENDINGPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['SubmitPendingPermissionResponse'] = _SUBMITPENDINGPERMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListPermissionsPageRequest'] = _LISTPERMISSIONSPAGEREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsPermissionsPageResponse'] = _LISTPROJECTSPERMISSIONSPAGERESPONSE
DESCRIPTOR.message_types_by_name['ListFeatureSetsPermissionsPageResponse'] = _LISTFEATURESETSPERMISSIONSPAGERESPONSE
DESCRIPTOR.message_types_by_name['ListableProjectToPermission'] = _LISTABLEPROJECTTOPERMISSION
DESCRIPTOR.message_types_by_name['ListableFeatureSetToPermission'] = _LISTABLEFEATURESETTOPERMISSION
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
DESCRIPTOR.message_types_by_name['RevokePermissionRequest'] = _REVOKEPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['ApprovePendingPermissionRequest'] = _APPROVEPENDINGPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['RejectPendingPermissionRequest'] = _REJECTPENDINGPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['GetActivePermissionRequest'] = _GETACTIVEPERMISSIONREQUEST
DESCRIPTOR.message_types_by_name['GetActivePermissionResponse'] = _GETACTIVEPERMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['ScheduledTask'] = _SCHEDULEDTASK
DESCRIPTOR.message_types_by_name['ScheduleTaskRequest'] = _SCHEDULETASKREQUEST
DESCRIPTOR.message_types_by_name['ListScheduledTasksRequest'] = _LISTSCHEDULEDTASKSREQUEST
DESCRIPTOR.message_types_by_name['ListScheduledTasksResponse'] = _LISTSCHEDULEDTASKSRESPONSE
DESCRIPTOR.message_types_by_name['ScheduledTaskId'] = _SCHEDULEDTASKID
DESCRIPTOR.message_types_by_name['ScheduledTaskResponse'] = _SCHEDULEDTASKRESPONSE
DESCRIPTOR.message_types_by_name['ScheduledTaskUpdateRequest'] = _SCHEDULEDTASKUPDATEREQUEST
DESCRIPTOR.message_types_by_name['LazyIngestRequest'] = _LAZYINGESTREQUEST
DESCRIPTOR.message_types_by_name['LazyIngestResponse'] = _LAZYINGESTRESPONSE
DESCRIPTOR.message_types_by_name['GetLazyIngestTaskRequest'] = _GETLAZYINGESTTASKREQUEST
DESCRIPTOR.message_types_by_name['TransformationFunction'] = _TRANSFORMATIONFUNCTION
DESCRIPTOR.message_types_by_name['ListTransformationFunctionsRequest'] = _LISTTRANSFORMATIONFUNCTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListTransformationFunctionsResponse'] = _LISTTRANSFORMATIONFUNCTIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetTransformationFunctionRequest'] = _GETTRANSFORMATIONFUNCTIONREQUEST
DESCRIPTOR.message_types_by_name['GetTransformationFunctionResponse'] = _GETTRANSFORMATIONFUNCTIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateProjectRequest'] = _UPDATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeatureSetRequest'] = _UPDATEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeatureRequest'] = _UPDATEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['GetOwnersRequest'] = _GETOWNERSREQUEST
DESCRIPTOR.message_types_by_name['GetOwnersResponse'] = _GETOWNERSRESPONSE
DESCRIPTOR.message_types_by_name['BackfillOptions'] = _BACKFILLOPTIONS
DESCRIPTOR.message_types_by_name['BackfillResponse'] = _BACKFILLRESPONSE
DESCRIPTOR.enum_types_by_name['JobType'] = _JOBTYPE
DESCRIPTOR.enum_types_by_name['PermissionType'] = _PERMISSIONTYPE
DESCRIPTOR.enum_types_by_name['ActivePermission'] = _ACTIVEPERMISSION
DESCRIPTOR.enum_types_by_name['FeatureFilterOperator'] = _FEATUREFILTEROPERATOR
DESCRIPTOR.enum_types_by_name['FeatureFilterLogicOperator'] = _FEATUREFILTERLOGICOPERATOR
DESCRIPTOR.enum_types_by_name['FeatureDataType'] = _FEATUREDATATYPE
DESCRIPTOR.enum_types_by_name['ProcessIntervalUnit'] = _PROCESSINTERVALUNIT
DESCRIPTOR.enum_types_by_name['TransformationType'] = _TRANSFORMATIONTYPE
DESCRIPTOR.enum_types_by_name['ResourceType'] = _RESOURCETYPE
DESCRIPTOR.enum_types_by_name['PermissionState'] = _PERMISSIONSTATE
DESCRIPTOR.enum_types_by_name['TaskType'] = _TASKTYPE
DESCRIPTOR.enum_types_by_name['UpdatableProjectField'] = _UPDATABLEPROJECTFIELD
DESCRIPTOR.enum_types_by_name['UpdatableFeatureSetField'] = _UPDATABLEFEATURESETFIELD
DESCRIPTOR.enum_types_by_name['UpdatableFeatureField'] = _UPDATABLEFEATUREFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureCustomDataUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureCustomDataUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURECUSTOMDATAUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureCustomDataUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureCustomDataUpdateRequest)

IdentityProviderDetails = _reflection.GeneratedProtocolMessageType('IdentityProviderDetails', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYPROVIDERDETAILS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.IdentityProviderDetails)
  })
_sym_db.RegisterMessage(IdentityProviderDetails)

GetWebConfigResponse = _reflection.GeneratedProtocolMessageType('GetWebConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBCONFIGRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetWebConfigResponse)
  })
_sym_db.RegisterMessage(GetWebConfigResponse)

FeatureSetCustomDataUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetCustomDataUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETCUSTOMDATAUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetCustomDataUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetCustomDataUpdateRequest)

ProjectCustomDataUpdateRequest = _reflection.GeneratedProtocolMessageType('ProjectCustomDataUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCUSTOMDATAUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectCustomDataUpdateRequest)
  })
_sym_db.RegisterMessage(ProjectCustomDataUpdateRequest)

FeatureSetTypeUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetTypeUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETTYPEUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetTypeUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetTypeUpdateRequest)

GetFeatureSetsLastMinorForCurrentMajorRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetsLastMinorForCurrentMajorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetFeatureSetsLastMinorForCurrentMajorRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetsLastMinorForCurrentMajorRequest)

FeatureTypeUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureTypeUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURETYPEUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureTypeUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureTypeUpdateRequest)

FeatureDoubleFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureDoubleFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREDOUBLEFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureDoubleFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureDoubleFieldUpdateRequest)

FeatureStringFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureStringFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTRINGFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureStringFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureStringFieldUpdateRequest)

FeatureStringArrayFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureStringArrayFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTRINGARRAYFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureStringArrayFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureStringArrayFieldUpdateRequest)

FeatureBooleanFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureBooleanFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREBOOLEANFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureBooleanFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureBooleanFieldUpdateRequest)

FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest)

FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest)

FeatureSetIntFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetIntFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETINTFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetIntFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetIntFieldUpdateRequest)

FeatureSetProcessIntervalUnitUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetProcessIntervalUnitUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETPROCESSINTERVALUNITUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetProcessIntervalUnitUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetProcessIntervalUnitUpdateRequest)

FeatureSetStringArrayFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetStringArrayFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSTRINGARRAYFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetStringArrayFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetStringArrayFieldUpdateRequest)

FeatureSetBooleanFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetBooleanFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETBOOLEANFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetBooleanFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetBooleanFieldUpdateRequest)

FeatureSetStringFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetStringFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSTRINGFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetStringFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetStringFieldUpdateRequest)

FeatureSetUserFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('FeatureSetUserFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETUSERFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetUserFieldUpdateRequest)
  })
_sym_db.RegisterMessage(FeatureSetUserFieldUpdateRequest)

ProjectBooleanFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('ProjectBooleanFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTBOOLEANFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectBooleanFieldUpdateRequest)
  })
_sym_db.RegisterMessage(ProjectBooleanFieldUpdateRequest)

ProjectStringFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('ProjectStringFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSTRINGFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectStringFieldUpdateRequest)
  })
_sym_db.RegisterMessage(ProjectStringFieldUpdateRequest)

ProjectUserFieldUpdateRequest = _reflection.GeneratedProtocolMessageType('ProjectUserFieldUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTUSERFIELDUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectUserFieldUpdateRequest)
  })
_sym_db.RegisterMessage(ProjectUserFieldUpdateRequest)

FeatureSetExistsRequest = _reflection.GeneratedProtocolMessageType('FeatureSetExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETEXISTSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetExistsRequest)
  })
_sym_db.RegisterMessage(FeatureSetExistsRequest)

GetIngestHistoryRequest = _reflection.GeneratedProtocolMessageType('GetIngestHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINGESTHISTORYREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetIngestHistoryRequest)
  })
_sym_db.RegisterMessage(GetIngestHistoryRequest)

ProjectExistsRequest = _reflection.GeneratedProtocolMessageType('ProjectExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTEXISTSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectExistsRequest)
  })
_sym_db.RegisterMessage(ProjectExistsRequest)

ExistsResponse = _reflection.GeneratedProtocolMessageType('ExistsResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ExistsResponse)
  })
_sym_db.RegisterMessage(ExistsResponse)

ProjectsDefaultResponse = _reflection.GeneratedProtocolMessageType('ProjectsDefaultResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSDEFAULTRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectsDefaultResponse)
  })
_sym_db.RegisterMessage(ProjectsDefaultResponse)

HasPermissionToRetrieveRequest = _reflection.GeneratedProtocolMessageType('HasPermissionToRetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASPERMISSIONTORETRIEVEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.HasPermissionToRetrieveRequest)
  })
_sym_db.RegisterMessage(HasPermissionToRetrieveRequest)

HasPermissionToRetrieveResponse = _reflection.GeneratedProtocolMessageType('HasPermissionToRetrieveResponse', (_message.Message,), {
  'DESCRIPTOR' : _HASPERMISSIONTORETRIEVERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.HasPermissionToRetrieveResponse)
  })
_sym_db.RegisterMessage(HasPermissionToRetrieveResponse)

StartRevertIngestJobRequest = _reflection.GeneratedProtocolMessageType('StartRevertIngestJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTREVERTINGESTJOBREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.StartRevertIngestJobRequest)
  })
_sym_db.RegisterMessage(StartRevertIngestJobRequest)

OnlineRetrieveMeta = _reflection.GeneratedProtocolMessageType('OnlineRetrieveMeta', (_message.Message,), {
  'DESCRIPTOR' : _ONLINERETRIEVEMETA,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.OnlineRetrieveMeta)
  })
_sym_db.RegisterMessage(OnlineRetrieveMeta)

RefreshTokenRequest = _reflection.GeneratedProtocolMessageType('RefreshTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHTOKENREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RefreshTokenRequest)
  })
_sym_db.RegisterMessage(RefreshTokenRequest)

GetUserByMailRequest = _reflection.GeneratedProtocolMessageType('GetUserByMailRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERBYMAILREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetUserByMailRequest)
  })
_sym_db.RegisterMessage(GetUserByMailRequest)

GetUserByMailResponse = _reflection.GeneratedProtocolMessageType('GetUserByMailResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERBYMAILRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetUserByMailResponse)
  })
_sym_db.RegisterMessage(GetUserByMailResponse)

TokenRequest = _reflection.GeneratedProtocolMessageType('TokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOKENREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.TokenRequest)
  })
_sym_db.RegisterMessage(TokenRequest)

GenerateTokenRequest = _reflection.GeneratedProtocolMessageType('GenerateTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETOKENREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GenerateTokenRequest)
  })
_sym_db.RegisterMessage(GenerateTokenRequest)

TokenResponse = _reflection.GeneratedProtocolMessageType('TokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOKENRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.TokenResponse)
  })
_sym_db.RegisterMessage(TokenResponse)

ListTokensResponse = _reflection.GeneratedProtocolMessageType('ListTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTOKENSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListTokensResponse)
  })
_sym_db.RegisterMessage(ListTokensResponse)

RawTokenResponse = _reflection.GeneratedProtocolMessageType('RawTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _RAWTOKENRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RawTokenResponse)
  })
_sym_db.RegisterMessage(RawTokenResponse)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

FeatureSetSchemaCompatibilityRequest = _reflection.GeneratedProtocolMessageType('FeatureSetSchemaCompatibilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSCHEMACOMPATIBILITYREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest)
  })
_sym_db.RegisterMessage(FeatureSetSchemaCompatibilityRequest)

FeatureSetSchemaCompatibilityResponse = _reflection.GeneratedProtocolMessageType('FeatureSetSchemaCompatibilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSCHEMACOMPATIBILITYRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityResponse)
  })
_sym_db.RegisterMessage(FeatureSetSchemaCompatibilityResponse)

FeatureSetSchemaPatchRequest = _reflection.GeneratedProtocolMessageType('FeatureSetSchemaPatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSCHEMAPATCHREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest)
  })
_sym_db.RegisterMessage(FeatureSetSchemaPatchRequest)

FeatureSetSchemaPatchResponse = _reflection.GeneratedProtocolMessageType('FeatureSetSchemaPatchResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSCHEMAPATCHRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchResponse)
  })
_sym_db.RegisterMessage(FeatureSetSchemaPatchResponse)

JobId = _reflection.GeneratedProtocolMessageType('JobId', (_message.Message,), {
  'DESCRIPTOR' : _JOBID,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JobId)
  })
_sym_db.RegisterMessage(JobId)

GetRecommendationRequest = _reflection.GeneratedProtocolMessageType('GetRecommendationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECOMMENDATIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetRecommendationRequest)
  })
_sym_db.RegisterMessage(GetRecommendationRequest)

GetRecommendationResponse = _reflection.GeneratedProtocolMessageType('GetRecommendationResponse', (_message.Message,), {

  'Join' : _reflection.GeneratedProtocolMessageType('Join', (_message.Message,), {
    'DESCRIPTOR' : _GETRECOMMENDATIONRESPONSE_JOIN,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetRecommendationResponse.Join)
    })
  ,

  'Match' : _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), {
    'DESCRIPTOR' : _GETRECOMMENDATIONRESPONSE_MATCH,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetRecommendationResponse.Match)
    })
  ,
  'DESCRIPTOR' : _GETRECOMMENDATIONRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetRecommendationResponse)
  })
_sym_db.RegisterMessage(GetRecommendationResponse)
_sym_db.RegisterMessage(GetRecommendationResponse.Join)
_sym_db.RegisterMessage(GetRecommendationResponse.Match)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Job)
  })
_sym_db.RegisterMessage(Job)

JobProgressInput = _reflection.GeneratedProtocolMessageType('JobProgressInput', (_message.Message,), {
  'DESCRIPTOR' : _JOBPROGRESSINPUT,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JobProgressInput)
  })
_sym_db.RegisterMessage(JobProgressInput)

JobProgressOutput = _reflection.GeneratedProtocolMessageType('JobProgressOutput', (_message.Message,), {

  'Progress' : _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), {
    'DESCRIPTOR' : _JOBPROGRESSOUTPUT_PROGRESS,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JobProgressOutput.Progress)
    })
  ,
  'DESCRIPTOR' : _JOBPROGRESSOUTPUT,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JobProgressOutput)
  })
_sym_db.RegisterMessage(JobProgressOutput)
_sym_db.RegisterMessage(JobProgressOutput.Progress)

FeatureSetPermissionRequest = _reflection.GeneratedProtocolMessageType('FeatureSetPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETPERMISSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest)
  })
_sym_db.RegisterMessage(FeatureSetPermissionRequest)

ProjectPermissionRequest = _reflection.GeneratedProtocolMessageType('ProjectPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTPERMISSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectPermissionRequest)
  })
_sym_db.RegisterMessage(ProjectPermissionRequest)

StartExtractSchemaJobRequest = _reflection.GeneratedProtocolMessageType('StartExtractSchemaJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTEXTRACTSCHEMAJOBREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest)
  })
_sym_db.RegisterMessage(StartExtractSchemaJobRequest)

ExtractSchemaResponse = _reflection.GeneratedProtocolMessageType('ExtractSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACTSCHEMARESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ExtractSchemaResponse)
  })
_sym_db.RegisterMessage(ExtractSchemaResponse)

ListFeatureSetsVersionRequest = _reflection.GeneratedProtocolMessageType('ListFeatureSetsVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSVERSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureSetsVersionRequest)
  })
_sym_db.RegisterMessage(ListFeatureSetsVersionRequest)

FeatureSetResponse = _reflection.GeneratedProtocolMessageType('FeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetResponse)
  })
_sym_db.RegisterMessage(FeatureSetResponse)

UpdateFeatureSetResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateFeatureSetResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureSetResponse)

UpdateProjectResponse = _reflection.GeneratedProtocolMessageType('UpdateProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateProjectResponse)
  })
_sym_db.RegisterMessage(UpdateProjectResponse)

UpdateFeatureResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateFeatureResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureResponse)

ProjectResponse = _reflection.GeneratedProtocolMessageType('ProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectResponse)
  })
_sym_db.RegisterMessage(ProjectResponse)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.LoginResponse)
  })
_sym_db.RegisterMessage(LoginResponse)

GetActiveUserResponse = _reflection.GeneratedProtocolMessageType('GetActiveUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVEUSERRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetActiveUserResponse)
  })
_sym_db.RegisterMessage(GetActiveUserResponse)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetProjectRequest)
  })
_sym_db.RegisterMessage(GetProjectRequest)

DeleteFeatureSetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.DeleteFeatureSetRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureSetRequest)

LogoutRequest = _reflection.GeneratedProtocolMessageType('LogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.LogoutRequest)
  })
_sym_db.RegisterMessage(LogoutRequest)

UserBasicInfo = _reflection.GeneratedProtocolMessageType('UserBasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERBASICINFO,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UserBasicInfo)
  })
_sym_db.RegisterMessage(UserBasicInfo)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.User)
  })
_sym_db.RegisterMessage(User)

AccessTokenResponse = _reflection.GeneratedProtocolMessageType('AccessTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSTOKENRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.AccessTokenResponse)
  })
_sym_db.RegisterMessage(AccessTokenResponse)

DeleteProjectRequest = _reflection.GeneratedProtocolMessageType('DeleteProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.DeleteProjectRequest)
  })
_sym_db.RegisterMessage(DeleteProjectRequest)

UpdateProjectMetadataRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTMETADATAREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateProjectMetadataRequest)
  })
_sym_db.RegisterMessage(UpdateProjectMetadataRequest)

CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

CreateProjectResponse = _reflection.GeneratedProtocolMessageType('CreateProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CreateProjectResponse)
  })
_sym_db.RegisterMessage(CreateProjectResponse)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

GetIngestHistoryResponse = _reflection.GeneratedProtocolMessageType('GetIngestHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINGESTHISTORYRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetIngestHistoryResponse)
  })
_sym_db.RegisterMessage(GetIngestHistoryResponse)

ListFeatureSetsAcrossProjectsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureSetsAcrossProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSACROSSPROJECTSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureSetsAcrossProjectsRequest)
  })
_sym_db.RegisterMessage(ListFeatureSetsAcrossProjectsRequest)

ListFeatureSetsPageRequest = _reflection.GeneratedProtocolMessageType('ListFeatureSetsPageRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSPAGEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest)
  })
_sym_db.RegisterMessage(ListFeatureSetsPageRequest)

ListFeatureSetsPageResponse = _reflection.GeneratedProtocolMessageType('ListFeatureSetsPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSPAGERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureSetsPageResponse)
  })
_sym_db.RegisterMessage(ListFeatureSetsPageResponse)

AWSCredentials = _reflection.GeneratedProtocolMessageType('AWSCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AWSCREDENTIALS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.AWSCredentials)
  })
_sym_db.RegisterMessage(AWSCredentials)

AzureCredentials = _reflection.GeneratedProtocolMessageType('AzureCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AZURECREDENTIALS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.AzureCredentials)
  })
_sym_db.RegisterMessage(AzureCredentials)

SnowflakeCredentials = _reflection.GeneratedProtocolMessageType('SnowflakeCredentials', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKECREDENTIALS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.SnowflakeCredentials)
  })
_sym_db.RegisterMessage(SnowflakeCredentials)

JDBCCredentials = _reflection.GeneratedProtocolMessageType('JDBCCredentials', (_message.Message,), {
  'DESCRIPTOR' : _JDBCCREDENTIALS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JDBCCredentials)
  })
_sym_db.RegisterMessage(JDBCCredentials)

Credentials = _reflection.GeneratedProtocolMessageType('Credentials', (_message.Message,), {
  'DESCRIPTOR' : _CREDENTIALS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Credentials)
  })
_sym_db.RegisterMessage(Credentials)

ListFeatureSetsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureSetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureSetsResponse)
  })
_sym_db.RegisterMessage(ListFeatureSetsResponse)

ListFeatureSetVersionsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureSetVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETVERSIONSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureSetVersionsResponse)
  })
_sym_db.RegisterMessage(ListFeatureSetVersionsResponse)

FeatureSetVersionDescription = _reflection.GeneratedProtocolMessageType('FeatureSetVersionDescription', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETVERSIONDESCRIPTION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetVersionDescription)
  })
_sym_db.RegisterMessage(FeatureSetVersionDescription)

GetFeatureSetRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetFeatureSetRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetRequest)

StartIngestJobRequest = _reflection.GeneratedProtocolMessageType('StartIngestJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINGESTJOBREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.StartIngestJobRequest)
  })
_sym_db.RegisterMessage(StartIngestJobRequest)

IngestResponse = _reflection.GeneratedProtocolMessageType('IngestResponse', (_message.Message,), {

  'IngestMeta' : _reflection.GeneratedProtocolMessageType('IngestMeta', (_message.Message,), {
    'DESCRIPTOR' : _INGESTRESPONSE_INGESTMETA,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta)
    })
  ,
  'DESCRIPTOR' : _INGESTRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.IngestResponse)
  })
_sym_db.RegisterMessage(IngestResponse)
_sym_db.RegisterMessage(IngestResponse.IngestMeta)

RetrieveRequest = _reflection.GeneratedProtocolMessageType('RetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveRequest)
  })
_sym_db.RegisterMessage(RetrieveRequest)

RetrieveAsLinksResponse = _reflection.GeneratedProtocolMessageType('RetrieveAsLinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEASLINKSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse)
  })
_sym_db.RegisterMessage(RetrieveAsLinksResponse)

RetrieveAsSparkResponse = _reflection.GeneratedProtocolMessageType('RetrieveAsSparkResponse', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _RETRIEVEASSPARKRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse)
  })
_sym_db.RegisterMessage(RetrieveAsSparkResponse)
_sym_db.RegisterMessage(RetrieveAsSparkResponse.OptionsEntry)

PreviewRequest = _reflection.GeneratedProtocolMessageType('PreviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.PreviewRequest)
  })
_sym_db.RegisterMessage(PreviewRequest)

StartMaterializationOnlineRequest = _reflection.GeneratedProtocolMessageType('StartMaterializationOnlineRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTMATERIALIZATIONONLINEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.StartMaterializationOnlineRequest)
  })
_sym_db.RegisterMessage(StartMaterializationOnlineRequest)

MaterializationOnlineResponse = _reflection.GeneratedProtocolMessageType('MaterializationOnlineResponse', (_message.Message,), {
  'DESCRIPTOR' : _MATERIALIZATIONONLINERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.MaterializationOnlineResponse)
  })
_sym_db.RegisterMessage(MaterializationOnlineResponse)

IngestWriteCredentialRequest = _reflection.GeneratedProtocolMessageType('IngestWriteCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _INGESTWRITECREDENTIALREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.IngestWriteCredentialRequest)
  })
_sym_db.RegisterMessage(IngestWriteCredentialRequest)

IngestWriteCredentialResponse = _reflection.GeneratedProtocolMessageType('IngestWriteCredentialResponse', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _INGESTWRITECREDENTIALRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse)
  })
_sym_db.RegisterMessage(IngestWriteCredentialResponse)
_sym_db.RegisterMessage(IngestWriteCredentialResponse.OptionsEntry)

RawDataLocation = _reflection.GeneratedProtocolMessageType('RawDataLocation', (_message.Message,), {
  'DESCRIPTOR' : _RAWDATALOCATION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RawDataLocation)
  })
_sym_db.RegisterMessage(RawDataLocation)

OnlineSourceSpec = _reflection.GeneratedProtocolMessageType('OnlineSourceSpec', (_message.Message,), {
  'DESCRIPTOR' : _ONLINESOURCESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.OnlineSourceSpec)
  })
_sym_db.RegisterMessage(OnlineSourceSpec)

CSVFileSpec = _reflection.GeneratedProtocolMessageType('CSVFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _CSVFILESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CSVFileSpec)
  })
_sym_db.RegisterMessage(CSVFileSpec)

JSONFileSpec = _reflection.GeneratedProtocolMessageType('JSONFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _JSONFILESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JSONFileSpec)
  })
_sym_db.RegisterMessage(JSONFileSpec)

ParquetFileSpec = _reflection.GeneratedProtocolMessageType('ParquetFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETFILESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ParquetFileSpec)
  })
_sym_db.RegisterMessage(ParquetFileSpec)

TempParquetFileSpec = _reflection.GeneratedProtocolMessageType('TempParquetFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _TEMPPARQUETFILESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.TempParquetFileSpec)
  })
_sym_db.RegisterMessage(TempParquetFileSpec)

Proxy = _reflection.GeneratedProtocolMessageType('Proxy', (_message.Message,), {
  'DESCRIPTOR' : _PROXY,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Proxy)
  })
_sym_db.RegisterMessage(Proxy)

SnowflakeTableSpec = _reflection.GeneratedProtocolMessageType('SnowflakeTableSpec', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKETABLESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.SnowflakeTableSpec)
  })
_sym_db.RegisterMessage(SnowflakeTableSpec)

JDBCTableSpec = _reflection.GeneratedProtocolMessageType('JDBCTableSpec', (_message.Message,), {
  'DESCRIPTOR' : _JDBCTABLESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JDBCTableSpec)
  })
_sym_db.RegisterMessage(JDBCTableSpec)

DeltaTableSpec = _reflection.GeneratedProtocolMessageType('DeltaTableSpec', (_message.Message,), {
  'DESCRIPTOR' : _DELTATABLESPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.DeltaTableSpec)
  })
_sym_db.RegisterMessage(DeltaTableSpec)

CSVFolderSpec = _reflection.GeneratedProtocolMessageType('CSVFolderSpec', (_message.Message,), {
  'DESCRIPTOR' : _CSVFOLDERSPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CSVFolderSpec)
  })
_sym_db.RegisterMessage(CSVFolderSpec)

ParquetFolderSpec = _reflection.GeneratedProtocolMessageType('ParquetFolderSpec', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETFOLDERSPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ParquetFolderSpec)
  })
_sym_db.RegisterMessage(ParquetFolderSpec)

JSONFolderSpec = _reflection.GeneratedProtocolMessageType('JSONFolderSpec', (_message.Message,), {
  'DESCRIPTOR' : _JSONFOLDERSPEC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JSONFolderSpec)
  })
_sym_db.RegisterMessage(JSONFolderSpec)

MojoTransformation = _reflection.GeneratedProtocolMessageType('MojoTransformation', (_message.Message,), {
  'DESCRIPTOR' : _MOJOTRANSFORMATION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.MojoTransformation)
  })
_sym_db.RegisterMessage(MojoTransformation)

SparkPipelineTransformation = _reflection.GeneratedProtocolMessageType('SparkPipelineTransformation', (_message.Message,), {
  'DESCRIPTOR' : _SPARKPIPELINETRANSFORMATION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.SparkPipelineTransformation)
  })
_sym_db.RegisterMessage(SparkPipelineTransformation)

JoinTransformation = _reflection.GeneratedProtocolMessageType('JoinTransformation', (_message.Message,), {
  'DESCRIPTOR' : _JOINTRANSFORMATION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.JoinTransformation)
  })
_sym_db.RegisterMessage(JoinTransformation)

VersionedId = _reflection.GeneratedProtocolMessageType('VersionedId', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONEDID,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.VersionedId)
  })
_sym_db.RegisterMessage(VersionedId)

Transformation = _reflection.GeneratedProtocolMessageType('Transformation', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMATION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Transformation)
  })
_sym_db.RegisterMessage(Transformation)

DerivedInformation = _reflection.GeneratedProtocolMessageType('DerivedInformation', (_message.Message,), {
  'DESCRIPTOR' : _DERIVEDINFORMATION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.DerivedInformation)
  })
_sym_db.RegisterMessage(DerivedInformation)

SelectedFeature = _reflection.GeneratedProtocolMessageType('SelectedFeature', (_message.Message,), {
  'DESCRIPTOR' : _SELECTEDFEATURE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.SelectedFeature)
  })
_sym_db.RegisterMessage(SelectedFeature)

FilterConditionUnion = _reflection.GeneratedProtocolMessageType('FilterConditionUnion', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONDITIONUNION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FilterConditionUnion)
  })
_sym_db.RegisterMessage(FilterConditionUnion)

FeatureFilter = _reflection.GeneratedProtocolMessageType('FeatureFilter', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREFILTER,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureFilter)
  })
_sym_db.RegisterMessage(FeatureFilter)

FeatureFilterLogic = _reflection.GeneratedProtocolMessageType('FeatureFilterLogic', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREFILTERLOGIC,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureFilterLogic)
  })
_sym_db.RegisterMessage(FeatureFilterLogic)

FeatureQuery = _reflection.GeneratedProtocolMessageType('FeatureQuery', (_message.Message,), {

  'From' : _reflection.GeneratedProtocolMessageType('From', (_message.Message,), {
    'DESCRIPTOR' : _FEATUREQUERY_FROM,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureQuery.From)
    })
  ,

  'Join' : _reflection.GeneratedProtocolMessageType('Join', (_message.Message,), {

    'On' : _reflection.GeneratedProtocolMessageType('On', (_message.Message,), {
      'DESCRIPTOR' : _FEATUREQUERY_JOIN_ON,
      '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
      # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureQuery.Join.On)
      })
    ,
    'DESCRIPTOR' : _FEATUREQUERY_JOIN,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureQuery.Join)
    })
  ,
  'DESCRIPTOR' : _FEATUREQUERY,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureQuery)
  })
_sym_db.RegisterMessage(FeatureQuery)
_sym_db.RegisterMessage(FeatureQuery.From)
_sym_db.RegisterMessage(FeatureQuery.Join)
_sym_db.RegisterMessage(FeatureQuery.Join.On)

FeatureView = _reflection.GeneratedProtocolMessageType('FeatureView', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEW,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureView)
  })
_sym_db.RegisterMessage(FeatureView)

CreateFeatureViewRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREVIEWREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CreateFeatureViewRequest)
  })
_sym_db.RegisterMessage(CreateFeatureViewRequest)

UpdateFeatureViewRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREVIEWREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureViewRequest)

CreateFeatureViewNewVersionRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureViewNewVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREVIEWNEWVERSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest)
  })
_sym_db.RegisterMessage(CreateFeatureViewNewVersionRequest)

GetFeatureViewRequest = _reflection.GeneratedProtocolMessageType('GetFeatureViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVIEWREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetFeatureViewRequest)
  })
_sym_db.RegisterMessage(GetFeatureViewRequest)

FeatureViewResponse = _reflection.GeneratedProtocolMessageType('FeatureViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureViewResponse)
  })
_sym_db.RegisterMessage(FeatureViewResponse)

ListFeatureViewsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureViewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREVIEWSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureViewsRequest)
  })
_sym_db.RegisterMessage(ListFeatureViewsRequest)

ListFeatureViewsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureViewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREVIEWSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureViewsResponse)
  })
_sym_db.RegisterMessage(ListFeatureViewsResponse)

RetrieveFeatureViewAsSparkRequest = _reflection.GeneratedProtocolMessageType('RetrieveFeatureViewAsSparkRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEFEATUREVIEWASSPARKREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest)
  })
_sym_db.RegisterMessage(RetrieveFeatureViewAsSparkRequest)

RetrieveFeatureViewAsSparkResponse = _reflection.GeneratedProtocolMessageType('RetrieveFeatureViewAsSparkResponse', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _RETRIEVEFEATUREVIEWASSPARKRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse)
  })
_sym_db.RegisterMessage(RetrieveFeatureViewAsSparkResponse)
_sym_db.RegisterMessage(RetrieveFeatureViewAsSparkResponse.OptionsEntry)

RetrieveFeatureViewAsAsLinksRequest = _reflection.GeneratedProtocolMessageType('RetrieveFeatureViewAsAsLinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEFEATUREVIEWASASLINKSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest)
  })
_sym_db.RegisterMessage(RetrieveFeatureViewAsAsLinksRequest)

RetrieveFeatureViewAsAsLinksResponse = _reflection.GeneratedProtocolMessageType('RetrieveFeatureViewAsAsLinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEFEATUREVIEWASASLINKSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksResponse)
  })
_sym_db.RegisterMessage(RetrieveFeatureViewAsAsLinksResponse)

DeleteFeatureViewRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREVIEWREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.DeleteFeatureViewRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureViewRequest)

MLDatasetFeature = _reflection.GeneratedProtocolMessageType('MLDatasetFeature', (_message.Message,), {
  'DESCRIPTOR' : _MLDATASETFEATURE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.MLDatasetFeature)
  })
_sym_db.RegisterMessage(MLDatasetFeature)

MLDataset = _reflection.GeneratedProtocolMessageType('MLDataset', (_message.Message,), {
  'DESCRIPTOR' : _MLDATASET,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.MLDataset)
  })
_sym_db.RegisterMessage(MLDataset)

CreateMLDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateMLDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMLDATASETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CreateMLDatasetRequest)
  })
_sym_db.RegisterMessage(CreateMLDatasetRequest)

UpdateMLDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateMLDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMLDATASETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateMLDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateMLDatasetRequest)

DeleteMLDatasetRequest = _reflection.GeneratedProtocolMessageType('DeleteMLDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMLDATASETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.DeleteMLDatasetRequest)
  })
_sym_db.RegisterMessage(DeleteMLDatasetRequest)

CreateMLDatasetResponse = _reflection.GeneratedProtocolMessageType('CreateMLDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMLDATASETRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CreateMLDatasetResponse)
  })
_sym_db.RegisterMessage(CreateMLDatasetResponse)

GetMLDatasetRequest = _reflection.GeneratedProtocolMessageType('GetMLDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMLDATASETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetMLDatasetRequest)
  })
_sym_db.RegisterMessage(GetMLDatasetRequest)

ListMLDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListMLDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMLDATASETSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListMLDatasetsRequest)
  })
_sym_db.RegisterMessage(ListMLDatasetsRequest)

ListMLDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListMLDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMLDATASETSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListMLDatasetsResponse)
  })
_sym_db.RegisterMessage(ListMLDatasetsResponse)

RetrieveMLDatasetAsSparkRequest = _reflection.GeneratedProtocolMessageType('RetrieveMLDatasetAsSparkRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMLDATASETASSPARKREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkRequest)
  })
_sym_db.RegisterMessage(RetrieveMLDatasetAsSparkRequest)

RetrieveMLDatasetAsSparkResponse = _reflection.GeneratedProtocolMessageType('RetrieveMLDatasetAsSparkResponse', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _RETRIEVEMLDATASETASSPARKRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse)
  })
_sym_db.RegisterMessage(RetrieveMLDatasetAsSparkResponse)
_sym_db.RegisterMessage(RetrieveMLDatasetAsSparkResponse.OptionsEntry)

RetrieveMLDatasetAsAsLinksRequest = _reflection.GeneratedProtocolMessageType('RetrieveMLDatasetAsAsLinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMLDATASETASASLINKSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksRequest)
  })
_sym_db.RegisterMessage(RetrieveMLDatasetAsAsLinksRequest)

RetrieveMLDatasetAsAsLinksResponse = _reflection.GeneratedProtocolMessageType('RetrieveMLDatasetAsAsLinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMLDATASETASASLINKSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksResponse)
  })
_sym_db.RegisterMessage(RetrieveMLDatasetAsAsLinksResponse)

RetrieveMLDatasetOnlineRequest = _reflection.GeneratedProtocolMessageType('RetrieveMLDatasetOnlineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMLDATASETONLINEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RetrieveMLDatasetOnlineRequest)
  })
_sym_db.RegisterMessage(RetrieveMLDatasetOnlineRequest)

FeatureSet = _reflection.GeneratedProtocolMessageType('FeatureSet', (_message.Message,), {

  'Statistics' : _reflection.GeneratedProtocolMessageType('Statistics', (_message.Message,), {
    'DESCRIPTOR' : _FEATURESET_STATISTICS,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSet.Statistics)
    })
  ,

  'SpecialData' : _reflection.GeneratedProtocolMessageType('SpecialData', (_message.Message,), {

    'Legal' : _reflection.GeneratedProtocolMessageType('Legal', (_message.Message,), {
      'DESCRIPTOR' : _FEATURESET_SPECIALDATA_LEGAL,
      '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
      # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal)
      })
    ,
    'DESCRIPTOR' : _FEATURESET_SPECIALDATA,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSet.SpecialData)
    })
  ,

  'Online' : _reflection.GeneratedProtocolMessageType('Online', (_message.Message,), {
    'DESCRIPTOR' : _FEATURESET_ONLINE,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSet.Online)
    })
  ,
  'DESCRIPTOR' : _FEATURESET,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSet)
  })
_sym_db.RegisterMessage(FeatureSet)
_sym_db.RegisterMessage(FeatureSet.Statistics)
_sym_db.RegisterMessage(FeatureSet.SpecialData)
_sym_db.RegisterMessage(FeatureSet.SpecialData.Legal)
_sym_db.RegisterMessage(FeatureSet.Online)

GetFeatureSetPreviewRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetPreviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETPREVIEWREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetFeatureSetPreviewRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetPreviewRequest)

GetFeatureSetPreviewResponse = _reflection.GeneratedProtocolMessageType('GetFeatureSetPreviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETPREVIEWRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetFeatureSetPreviewResponse)
  })
_sym_db.RegisterMessage(GetFeatureSetPreviewResponse)

Scope = _reflection.GeneratedProtocolMessageType('Scope', (_message.Message,), {
  'DESCRIPTOR' : _SCOPE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Scope)
  })
_sym_db.RegisterMessage(Scope)

RegisterFeatureSetRequest = _reflection.GeneratedProtocolMessageType('RegisterFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERFEATURESETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest)
  })
_sym_db.RegisterMessage(RegisterFeatureSetRequest)

CreateNewFeatureSetVersionRequest = _reflection.GeneratedProtocolMessageType('CreateNewFeatureSetVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENEWFEATURESETVERSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest)
  })
_sym_db.RegisterMessage(CreateNewFeatureSetVersionRequest)

FeatureProfile = _reflection.GeneratedProtocolMessageType('FeatureProfile', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPROFILE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureProfile)
  })
_sym_db.RegisterMessage(FeatureProfile)

FeatureSchema = _reflection.GeneratedProtocolMessageType('FeatureSchema', (_message.Message,), {

  'SpecialData' : _reflection.GeneratedProtocolMessageType('SpecialData', (_message.Message,), {
    'DESCRIPTOR' : _FEATURESCHEMA_SPECIALDATA,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData)
    })
  ,
  'DESCRIPTOR' : _FEATURESCHEMA,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSchema)
  })
_sym_db.RegisterMessage(FeatureSchema)
_sym_db.RegisterMessage(FeatureSchema.SpecialData)

Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {

  'Monitoring' : _reflection.GeneratedProtocolMessageType('Monitoring', (_message.Message,), {
    'DESCRIPTOR' : _FEATURE_MONITORING,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Feature.Monitoring)
    })
  ,

  'SpecialData' : _reflection.GeneratedProtocolMessageType('SpecialData', (_message.Message,), {
    'DESCRIPTOR' : _FEATURE_SPECIALDATA,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Feature.SpecialData)
    })
  ,
  'DESCRIPTOR' : _FEATURE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Feature)
  })
_sym_db.RegisterMessage(Feature)
_sym_db.RegisterMessage(Feature.Monitoring)
_sym_db.RegisterMessage(Feature.SpecialData)

FeatureStatistics = _reflection.GeneratedProtocolMessageType('FeatureStatistics', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTATISTICS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureStatistics)
  })
_sym_db.RegisterMessage(FeatureStatistics)

CategoricalFeatureStatistics = _reflection.GeneratedProtocolMessageType('CategoricalFeatureStatistics', (_message.Message,), {

  'FeatureTop' : _reflection.GeneratedProtocolMessageType('FeatureTop', (_message.Message,), {
    'DESCRIPTOR' : _CATEGORICALFEATURESTATISTICS_FEATURETOP,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.FeatureTop)
    })
  ,
  'DESCRIPTOR' : _CATEGORICALFEATURESTATISTICS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics)
  })
_sym_db.RegisterMessage(CategoricalFeatureStatistics)
_sym_db.RegisterMessage(CategoricalFeatureStatistics.FeatureTop)

GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetVersionResponse)
  })
_sym_db.RegisterMessage(GetVersionResponse)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
  'DESCRIPTOR' : _PROJECT,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Project)
  })
_sym_db.RegisterMessage(Project)

ListableProject = _reflection.GeneratedProtocolMessageType('ListableProject', (_message.Message,), {
  'DESCRIPTOR' : _LISTABLEPROJECT,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListableProject)
  })
_sym_db.RegisterMessage(ListableProject)

FeatureSetIngest = _reflection.GeneratedProtocolMessageType('FeatureSetIngest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETINGEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetIngest)
  })
_sym_db.RegisterMessage(FeatureSetIngest)

PersonalAccessToken = _reflection.GeneratedProtocolMessageType('PersonalAccessToken', (_message.Message,), {
  'DESCRIPTOR' : _PERSONALACCESSTOKEN,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.PersonalAccessToken)
  })
_sym_db.RegisterMessage(PersonalAccessToken)

GenerateTransformationUploadRequest = _reflection.GeneratedProtocolMessageType('GenerateTransformationUploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETRANSFORMATIONUPLOADREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GenerateTransformationUploadRequest)
  })
_sym_db.RegisterMessage(GenerateTransformationUploadRequest)

GenerateTransformationUploadResponse = _reflection.GeneratedProtocolMessageType('GenerateTransformationUploadResponse', (_message.Message,), {

  'HeadersEntry' : _reflection.GeneratedProtocolMessageType('HeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.HeadersEntry)
    })
  ,
  'DESCRIPTOR' : _GENERATETRANSFORMATIONUPLOADRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse)
  })
_sym_db.RegisterMessage(GenerateTransformationUploadResponse)
_sym_db.RegisterMessage(GenerateTransformationUploadResponse.HeadersEntry)

ListProjectsPageRequest = _reflection.GeneratedProtocolMessageType('ListProjectsPageRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSPAGEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListProjectsPageRequest)
  })
_sym_db.RegisterMessage(ListProjectsPageRequest)

ListProjectsPageResponse = _reflection.GeneratedProtocolMessageType('ListProjectsPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSPAGERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListProjectsPageResponse)
  })
_sym_db.RegisterMessage(ListProjectsPageResponse)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.SearchRequest)
  })
_sym_db.RegisterMessage(SearchRequest)

ProjectSearchResults = _reflection.GeneratedProtocolMessageType('ProjectSearchResults', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSEARCHRESULTS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ProjectSearchResults)
  })
_sym_db.RegisterMessage(ProjectSearchResults)

ListableFeatureSet = _reflection.GeneratedProtocolMessageType('ListableFeatureSet', (_message.Message,), {
  'DESCRIPTOR' : _LISTABLEFEATURESET,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListableFeatureSet)
  })
_sym_db.RegisterMessage(ListableFeatureSet)

FeatureSetSearchResults = _reflection.GeneratedProtocolMessageType('FeatureSetSearchResults', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETSEARCHRESULTS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetSearchResults)
  })
_sym_db.RegisterMessage(FeatureSetSearchResults)

ListableFeature = _reflection.GeneratedProtocolMessageType('ListableFeature', (_message.Message,), {
  'DESCRIPTOR' : _LISTABLEFEATURE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListableFeature)
  })
_sym_db.RegisterMessage(ListableFeature)

FeatureSearchResults = _reflection.GeneratedProtocolMessageType('FeatureSearchResults', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESEARCHRESULTS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSearchResults)
  })
_sym_db.RegisterMessage(FeatureSearchResults)

FeatureSetRequestId = _reflection.GeneratedProtocolMessageType('FeatureSetRequestId', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETREQUESTID,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureSetRequestId)
  })
_sym_db.RegisterMessage(FeatureSetRequestId)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

ListFeaturesPageResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESPAGERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeaturesPageResponse)
  })
_sym_db.RegisterMessage(ListFeaturesPageResponse)

FeatureResponse = _reflection.GeneratedProtocolMessageType('FeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATURERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.FeatureResponse)
  })
_sym_db.RegisterMessage(FeatureResponse)

ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

ListableFeatureSetRequest = _reflection.GeneratedProtocolMessageType('ListableFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTABLEFEATURESETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListableFeatureSetRequest)
  })
_sym_db.RegisterMessage(ListableFeatureSetRequest)

ListableFeatureSetResponse = _reflection.GeneratedProtocolMessageType('ListableFeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTABLEFEATURESETRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListableFeatureSetResponse)
  })
_sym_db.RegisterMessage(ListableFeatureSetResponse)

SubmitPendingPermissionRequest = _reflection.GeneratedProtocolMessageType('SubmitPendingPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITPENDINGPERMISSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest)
  })
_sym_db.RegisterMessage(SubmitPendingPermissionRequest)

SubmitPendingPermissionResponse = _reflection.GeneratedProtocolMessageType('SubmitPendingPermissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITPENDINGPERMISSIONRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse)
  })
_sym_db.RegisterMessage(SubmitPendingPermissionResponse)

ListPermissionsPageRequest = _reflection.GeneratedProtocolMessageType('ListPermissionsPageRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSPAGEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListPermissionsPageRequest)
  })
_sym_db.RegisterMessage(ListPermissionsPageRequest)

ListProjectsPermissionsPageResponse = _reflection.GeneratedProtocolMessageType('ListProjectsPermissionsPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSPERMISSIONSPAGERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse)
  })
_sym_db.RegisterMessage(ListProjectsPermissionsPageResponse)

ListFeatureSetsPermissionsPageResponse = _reflection.GeneratedProtocolMessageType('ListFeatureSetsPermissionsPageResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSPERMISSIONSPAGERESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse)
  })
_sym_db.RegisterMessage(ListFeatureSetsPermissionsPageResponse)

ListableProjectToPermission = _reflection.GeneratedProtocolMessageType('ListableProjectToPermission', (_message.Message,), {
  'DESCRIPTOR' : _LISTABLEPROJECTTOPERMISSION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListableProjectToPermission)
  })
_sym_db.RegisterMessage(ListableProjectToPermission)

ListableFeatureSetToPermission = _reflection.GeneratedProtocolMessageType('ListableFeatureSetToPermission', (_message.Message,), {
  'DESCRIPTOR' : _LISTABLEFEATURESETTOPERMISSION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListableFeatureSetToPermission)
  })
_sym_db.RegisterMessage(ListableFeatureSetToPermission)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {

  'PromotedUpdate' : _reflection.GeneratedProtocolMessageType('PromotedUpdate', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSION_PROMOTEDUPDATE,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Permission.PromotedUpdate)
    })
  ,

  'RevokedUpdate' : _reflection.GeneratedProtocolMessageType('RevokedUpdate', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSION_REVOKEDUPDATE,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Permission.RevokedUpdate)
    })
  ,

  'GrantedOrRejectedUpdate' : _reflection.GeneratedProtocolMessageType('GrantedOrRejectedUpdate', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSION_GRANTEDORREJECTEDUPDATE,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate)
    })
  ,
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.Permission)
  })
_sym_db.RegisterMessage(Permission)
_sym_db.RegisterMessage(Permission.PromotedUpdate)
_sym_db.RegisterMessage(Permission.RevokedUpdate)
_sym_db.RegisterMessage(Permission.GrantedOrRejectedUpdate)

RevokePermissionRequest = _reflection.GeneratedProtocolMessageType('RevokePermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPERMISSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RevokePermissionRequest)
  })
_sym_db.RegisterMessage(RevokePermissionRequest)

ApprovePendingPermissionRequest = _reflection.GeneratedProtocolMessageType('ApprovePendingPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEPENDINGPERMISSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ApprovePendingPermissionRequest)
  })
_sym_db.RegisterMessage(ApprovePendingPermissionRequest)

RejectPendingPermissionRequest = _reflection.GeneratedProtocolMessageType('RejectPendingPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _REJECTPENDINGPERMISSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.RejectPendingPermissionRequest)
  })
_sym_db.RegisterMessage(RejectPendingPermissionRequest)

GetActivePermissionRequest = _reflection.GeneratedProtocolMessageType('GetActivePermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVEPERMISSIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetActivePermissionRequest)
  })
_sym_db.RegisterMessage(GetActivePermissionRequest)

GetActivePermissionResponse = _reflection.GeneratedProtocolMessageType('GetActivePermissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVEPERMISSIONRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetActivePermissionResponse)
  })
_sym_db.RegisterMessage(GetActivePermissionResponse)

ScheduledTask = _reflection.GeneratedProtocolMessageType('ScheduledTask', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDTASK,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ScheduledTask)
  })
_sym_db.RegisterMessage(ScheduledTask)

ScheduleTaskRequest = _reflection.GeneratedProtocolMessageType('ScheduleTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULETASKREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ScheduleTaskRequest)
  })
_sym_db.RegisterMessage(ScheduleTaskRequest)

ListScheduledTasksRequest = _reflection.GeneratedProtocolMessageType('ListScheduledTasksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCHEDULEDTASKSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListScheduledTasksRequest)
  })
_sym_db.RegisterMessage(ListScheduledTasksRequest)

ListScheduledTasksResponse = _reflection.GeneratedProtocolMessageType('ListScheduledTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCHEDULEDTASKSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListScheduledTasksResponse)
  })
_sym_db.RegisterMessage(ListScheduledTasksResponse)

ScheduledTaskId = _reflection.GeneratedProtocolMessageType('ScheduledTaskId', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDTASKID,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ScheduledTaskId)
  })
_sym_db.RegisterMessage(ScheduledTaskId)

ScheduledTaskResponse = _reflection.GeneratedProtocolMessageType('ScheduledTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDTASKRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ScheduledTaskResponse)
  })
_sym_db.RegisterMessage(ScheduledTaskResponse)

ScheduledTaskUpdateRequest = _reflection.GeneratedProtocolMessageType('ScheduledTaskUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEDTASKUPDATEREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest)
  })
_sym_db.RegisterMessage(ScheduledTaskUpdateRequest)

LazyIngestRequest = _reflection.GeneratedProtocolMessageType('LazyIngestRequest', (_message.Message,), {
  'DESCRIPTOR' : _LAZYINGESTREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.LazyIngestRequest)
  })
_sym_db.RegisterMessage(LazyIngestRequest)

LazyIngestResponse = _reflection.GeneratedProtocolMessageType('LazyIngestResponse', (_message.Message,), {
  'DESCRIPTOR' : _LAZYINGESTRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.LazyIngestResponse)
  })
_sym_db.RegisterMessage(LazyIngestResponse)

GetLazyIngestTaskRequest = _reflection.GeneratedProtocolMessageType('GetLazyIngestTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLAZYINGESTTASKREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetLazyIngestTaskRequest)
  })
_sym_db.RegisterMessage(GetLazyIngestTaskRequest)

TransformationFunction = _reflection.GeneratedProtocolMessageType('TransformationFunction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMATIONFUNCTION,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.TransformationFunction)
  })
_sym_db.RegisterMessage(TransformationFunction)

ListTransformationFunctionsRequest = _reflection.GeneratedProtocolMessageType('ListTransformationFunctionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFORMATIONFUNCTIONSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListTransformationFunctionsRequest)
  })
_sym_db.RegisterMessage(ListTransformationFunctionsRequest)

ListTransformationFunctionsResponse = _reflection.GeneratedProtocolMessageType('ListTransformationFunctionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFORMATIONFUNCTIONSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.ListTransformationFunctionsResponse)
  })
_sym_db.RegisterMessage(ListTransformationFunctionsResponse)

GetTransformationFunctionRequest = _reflection.GeneratedProtocolMessageType('GetTransformationFunctionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFORMATIONFUNCTIONREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetTransformationFunctionRequest)
  })
_sym_db.RegisterMessage(GetTransformationFunctionRequest)

GetTransformationFunctionResponse = _reflection.GeneratedProtocolMessageType('GetTransformationFunctionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFORMATIONFUNCTIONRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetTransformationFunctionResponse)
  })
_sym_db.RegisterMessage(GetTransformationFunctionResponse)

UpdateProjectRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateProjectRequest)
  })
_sym_db.RegisterMessage(UpdateProjectRequest)

UpdateFeatureSetRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureSetRequest)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)

GetOwnersRequest = _reflection.GeneratedProtocolMessageType('GetOwnersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOWNERSREQUEST,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetOwnersRequest)
  })
_sym_db.RegisterMessage(GetOwnersRequest)

GetOwnersResponse = _reflection.GeneratedProtocolMessageType('GetOwnersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOWNERSRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.GetOwnersResponse)
  })
_sym_db.RegisterMessage(GetOwnersResponse)

BackfillOptions = _reflection.GeneratedProtocolMessageType('BackfillOptions', (_message.Message,), {

  'FeatureMappingEntry' : _reflection.GeneratedProtocolMessageType('FeatureMappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _BACKFILLOPTIONS_FEATUREMAPPINGENTRY,
    '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
    # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.BackfillOptions.FeatureMappingEntry)
    })
  ,
  'DESCRIPTOR' : _BACKFILLOPTIONS,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.BackfillOptions)
  })
_sym_db.RegisterMessage(BackfillOptions)
_sym_db.RegisterMessage(BackfillOptions.FeatureMappingEntry)

BackfillResponse = _reflection.GeneratedProtocolMessageType('BackfillResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKFILLRESPONSE,
  '__module__' : 'ai.h2o.featurestore.api.v1.CoreService_pb2'
  # @@protoc_insertion_point(class_scope:ai.h2o.featurestore.api.v1.BackfillResponse)
  })
_sym_db.RegisterMessage(BackfillResponse)


DESCRIPTOR._options = None
_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY._options = None
_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY._options = None
_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY._options = None
_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY._options = None
_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY._options = None
_BACKFILLOPTIONS_FEATUREMAPPINGENTRY._options = None

_CORESERVICE = _descriptor.ServiceDescriptor(
  name='CoreService',
  full_name='ai.h2o.featurestore.api.v1.CoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=38161,
  serialized_end=63422,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListJobs',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListJobs',
    index=0,
    containing_service=None,
    input_type=_LISTJOBSREQUEST,
    output_type=_LISTJOBSRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/api/v1/jobs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetJob',
    index=1,
    containing_service=None,
    input_type=_JOBID,
    output_type=_JOB,
    serialized_options=b'\202\323\344\223\002\027\022\025/api/v1/jobs/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobProgress',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetJobProgress',
    index=2,
    containing_service=None,
    input_type=_JOBPROGRESSINPUT,
    output_type=_JOBPROGRESSOUTPUT,
    serialized_options=b'\202\323\344\223\002 \022\036/api/v1/jobs/{job_id}/progress',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartExtractSchemaJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartExtractSchemaJob',
    index=3,
    containing_service=None,
    input_type=_STARTEXTRACTSCHEMAJOBREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002 \"\033/api/v1/jobs/extract-schema:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtractSchemaJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetExtractSchemaJobOutput',
    index=4,
    containing_service=None,
    input_type=_JOBID,
    output_type=_EXTRACTSCHEMARESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/jobs/extract-schema/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartIngestJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartIngestJob',
    index=5,
    containing_service=None,
    input_type=_STARTINGESTJOBREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002\031\"\024/api/v1/ingest/start:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIngestJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetIngestJobOutput',
    index=6,
    containing_service=None,
    input_type=_JOBID,
    output_type=_INGESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/api/v1/ingests/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRetrieveAsLinksJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartRetrieveAsLinksJob',
    index=7,
    containing_service=None,
    input_type=_RETRIEVEREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002\034\"\027/api/v1/ingest/retrieve:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRetrieveAsLinksJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetRetrieveAsLinksJobOutput',
    index=8,
    containing_service=None,
    input_type=_JOBID,
    output_type=_RETRIEVEASLINKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /api/v1/ingest/retrieve/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveAsSpark',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RetrieveAsSpark',
    index=9,
    containing_service=None,
    input_type=_RETRIEVEREQUEST,
    output_type=_RETRIEVEASSPARKRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\"\035/api/v1/ingest/retrieve/spark:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartPreviewJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartPreviewJob',
    index=10,
    containing_service=None,
    input_type=_PREVIEWREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002\032\"\025/api/v1/preview/start:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIngestWriteCredentials',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetIngestWriteCredentials',
    index=11,
    containing_service=None,
    input_type=_INGESTWRITECREDENTIALREQUEST,
    output_type=_INGESTWRITECREDENTIALRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/api/v1/ingest/credential/{session_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRevertIngestJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartRevertIngestJob',
    index=12,
    containing_service=None,
    input_type=_STARTREVERTINGESTJOBREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002\032\"\025/api/v1/ingest/revert:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRevertIngestJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetRevertIngestJobOutput',
    index=13,
    containing_service=None,
    input_type=_JOBID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002 \022\036/api/v1/ingest/revert/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HasPermissionToRetrieve',
    full_name='ai.h2o.featurestore.api.v1.CoreService.HasPermissionToRetrieve',
    index=14,
    containing_service=None,
    input_type=_HASPERMISSIONTORETRIEVEREQUEST,
    output_type=_HASPERMISSIONTORETRIEVERESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1/ingest/permission',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterFeatureSet',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RegisterFeatureSet',
    index=15,
    containing_service=None,
    input_type=_REGISTERFEATURESETREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\"\035/api/v1/feature-sets/register:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNewFeatureSetVersion',
    full_name='ai.h2o.featurestore.api.v1.CoreService.CreateNewFeatureSetVersion',
    index=16,
    containing_service=None,
    input_type=_CREATENEWFEATURESETVERSIONREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\034/api/v1/feature-sets/version:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnlineRetrieveMeta',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetOnlineRetrieveMeta',
    index=17,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_ONLINERETRIEVEMETA,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1/online-retrieve',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVersion',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetVersion',
    index=18,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETVERSIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/api/v1/version',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureSet',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetFeatureSet',
    index=19,
    containing_service=None,
    input_type=_GETFEATURESETREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\023/api/v1/feature-set:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureSetById',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetFeatureSetById',
    index=20,
    containing_service=None,
    input_type=_FEATURESETREQUESTID,
    output_type=_FEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/feature-set/{feature_set_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureSetsLastMinorForCurrentMajor',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetFeatureSetsLastMinorForCurrentMajor',
    index=21,
    containing_service=None,
    input_type=_GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1/feature-sets-last',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatureSetVersions',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListFeatureSetVersions',
    index=22,
    containing_service=None,
    input_type=_LISTFEATURESETSVERSIONREQUEST,
    output_type=_LISTFEATURESETVERSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/api/v1/feature-sets/version',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeatureSet',
    full_name='ai.h2o.featurestore.api.v1.CoreService.DeleteFeatureSet',
    index=23,
    containing_service=None,
    input_type=_DELETEFEATURESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\031*\024/api/v1/feature-sets:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatureSetsPage',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListFeatureSetsPage',
    index=24,
    containing_service=None,
    input_type=_LISTFEATURESETSPAGEREQUEST,
    output_type=_LISTFEATURESETSPAGERESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/api/v1/feature-sets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureSetExists',
    full_name='ai.h2o.featurestore.api.v1.CoreService.FeatureSetExists',
    index=25,
    containing_service=None,
    input_type=_FEATURESETEXISTSREQUEST,
    output_type=_EXISTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/api/v1/feature-sets/exists',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIngestHistory',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetIngestHistory',
    index=26,
    containing_service=None,
    input_type=_GETINGESTHISTORYREQUEST,
    output_type=_GETINGESTHISTORYRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/api/v1/ingest/history',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetPrimaryKey',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetPrimaryKey',
    index=27,
    containing_service=None,
    input_type=_FEATURESETSTRINGARRAYFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002%\032 /api/v1/feature-sets/primary-key:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetTags',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetTags',
    index=28,
    containing_service=None,
    input_type=_FEATURESETSTRINGARRAYFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002\036\032\031/api/v1/feature-sets/tags:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetDataSourceDomains',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetDataSourceDomains',
    index=29,
    containing_service=None,
    input_type=_FEATURESETSTRINGARRAYFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002-\032(/api/v1/feature-sets/data-source-domains:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetDescription',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetDescription',
    index=30,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002%\032 /api/v1/feature-sets/description:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetType',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetType',
    index=31,
    containing_service=None,
    input_type=_FEATURESETTYPEUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002\036\032\031/api/v1/feature-sets/type:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetOwner',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetOwner',
    index=32,
    containing_service=None,
    input_type=_FEATURESETUSERFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002\037\032\032/api/v1/feature-sets/owner:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetApplicationName',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetApplicationName',
    index=33,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002*\032%/api/v1/feature-sets/application-name:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetApplicationId',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetApplicationId',
    index=34,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002(\032#/api/v1/feature-sets/application-id:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetDeprecated',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetDeprecated',
    index=35,
    containing_service=None,
    input_type=_FEATURESETBOOLEANFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002$\032\037/api/v1/feature-sets/deprecated:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetProcessInterval',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetProcessInterval',
    index=36,
    containing_service=None,
    input_type=_FEATURESETINTFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002*\032%/api/v1/feature-sets/process-interval:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetProcessIntervalUnit',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetProcessIntervalUnit',
    index=37,
    containing_service=None,
    input_type=_FEATURESETPROCESSINTERVALUNITUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002/\032*/api/v1/feature-sets/process-interval-unit:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetFlow',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetFlow',
    index=38,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002\036\032\031/api/v1/feature-sets/flow:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetState',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetState',
    index=39,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002\037\032\032/api/v1/feature-sets/state:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetSecret',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetSecret',
    index=40,
    containing_service=None,
    input_type=_FEATURESETBOOLEANFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002 \032\033/api/v1/feature-sets/secret:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetCustomData',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetCustomData',
    index=41,
    containing_service=None,
    input_type=_FEATURESETCUSTOMDATAUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002%\032 /api/v1/feature-sets/custom-data:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTimeToLiveOfflineInterval',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateTimeToLiveOfflineInterval',
    index=42,
    containing_service=None,
    input_type=_FEATURESETINTFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002.\032)/api/v1/feature-sets/time-to-live-offline:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTimeToLiveOfflineIntervalUnit',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateTimeToLiveOfflineIntervalUnit',
    index=43,
    containing_service=None,
    input_type=_FEATURESETTIMETOLIVEOFFLINEINTERVALUNITUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\0023\032./api/v1/feature-sets/time-to-live-offline-unit:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTimeToLiveOnlineInterval',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateTimeToLiveOnlineInterval',
    index=44,
    containing_service=None,
    input_type=_FEATURESETINTFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002-\032(/api/v1/feature-sets/time-to-live-online:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTimeToLiveOnlineIntervalUnit',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateTimeToLiveOnlineIntervalUnit',
    index=45,
    containing_service=None,
    input_type=_FEATURESETTIMETOLIVEONLINEINTERVALUNITUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\0022\032-/api/v1/feature-sets/time-to-live-online-unit:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetOnlineNamespace',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetOnlineNamespace',
    index=46,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002*\032%/api/v1/feature-sets/online-namespace:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetOnlineTopic',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetOnlineTopic',
    index=47,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002&\032!/api/v1/feature-sets/online-topic:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetOnlineConnectionType',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetOnlineConnectionType',
    index=48,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\0020\032+/api/v1/feature-sets/online-connection-type:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetLegalApproved',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetLegalApproved',
    index=49,
    containing_service=None,
    input_type=_FEATURESETBOOLEANFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002(\032#/api/v1/feature-sets/legal-approved:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSetLegalApprovedNotes',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSetLegalApprovedNotes',
    index=50,
    containing_service=None,
    input_type=_FEATURESETSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002.\032)/api/v1/feature-sets/legal-approved-notes:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureStatus',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureStatus',
    index=51,
    containing_service=None,
    input_type=_FEATURESTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002)\032$/api/v1/feature-sets/features/status:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureType',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureType',
    index=52,
    containing_service=None,
    input_type=_FEATURETYPEUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\'\032\"/api/v1/feature-sets/features/type:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureCustomData',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureCustomData',
    index=53,
    containing_service=None,
    input_type=_FEATURECUSTOMDATAUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002.\032)/api/v1/feature-sets/features/custom-data:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureImportance',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureImportance',
    index=54,
    containing_service=None,
    input_type=_FEATUREDOUBLEFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002-\032(/api/v1/feature-sets/features/importance:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureDescription',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureDescription',
    index=55,
    containing_service=None,
    input_type=_FEATURESTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002.\032)/api/v1/feature-sets/features/description:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSpecial',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSpecial',
    index=56,
    containing_service=None,
    input_type=_FEATURESTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002*\032%/api/v1/feature-sets/features/special:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureAnomalyDetection',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureAnomalyDetection',
    index=57,
    containing_service=None,
    input_type=_FEATUREBOOLEANFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\0024\032//api/v1/feature-sets/features/anomaly-detection:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureClassifiers',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureClassifiers',
    index=58,
    containing_service=None,
    input_type=_FEATURESTRINGARRAYFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002.\032)/api/v1/feature-sets/features/classifiers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsFeatureSetSchemaCompatible',
    full_name='ai.h2o.featurestore.api.v1.CoreService.IsFeatureSetSchemaCompatible',
    index=59,
    containing_service=None,
    input_type=_FEATURESETSCHEMACOMPATIBILITYREQUEST,
    output_type=_FEATURESETSCHEMACOMPATIBILITYRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//api/v1/feature-sets/features/schema-compatible:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureSetSchemaPatch',
    full_name='ai.h2o.featurestore.api.v1.CoreService.FeatureSetSchemaPatch',
    index=60,
    containing_service=None,
    input_type=_FEATURESETSCHEMAPATCHREQUEST,
    output_type=_FEATURESETSCHEMAPATCHRESPONSE,
    serialized_options=b'\202\323\344\223\002&\"!/api/v1/feature-sets/schema-patch:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureSetPreview',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetFeatureSetPreview',
    index=61,
    containing_service=None,
    input_type=_GETFEATURESETPREVIEWREQUEST,
    output_type=_GETFEATURESETPREVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/api/v1/feature-set-previews/{feature_set_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureSet',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureSet',
    index=62,
    containing_service=None,
    input_type=_UPDATEFEATURESETREQUEST,
    output_type=_UPDATEFEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002*\032%/api/v1/feature-sets/{feature_set_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeatureView',
    full_name='ai.h2o.featurestore.api.v1.CoreService.CreateFeatureView',
    index=63,
    containing_service=None,
    input_type=_CREATEFEATUREVIEWREQUEST,
    output_type=_FEATUREVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\"\025/api/v1/feature-views:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureView',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeatureView',
    index=64,
    containing_service=None,
    input_type=_UPDATEFEATUREVIEWREQUEST,
    output_type=_FEATUREVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002C\032>/api/v1/feature-views/{feature_view_id}/{feature_view_version}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureView',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetFeatureView',
    index=65,
    containing_service=None,
    input_type=_GETFEATUREVIEWREQUEST,
    output_type=_FEATUREVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/api/v1/projects/{project_id}/feature-views/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatureViews',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListFeatureViews',
    index=66,
    containing_service=None,
    input_type=_LISTFEATUREVIEWSREQUEST,
    output_type=_LISTFEATUREVIEWSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/api/v1/feature-views',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeatureViewNewVersion',
    full_name='ai.h2o.featurestore.api.v1.CoreService.CreateFeatureViewNewVersion',
    index=67,
    containing_service=None,
    input_type=_CREATEFEATUREVIEWNEWVERSIONREQUEST,
    output_type=_FEATUREVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\"\025/api/v1/feature-views:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRetrieveFeatureViewAsSparkJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartRetrieveFeatureViewAsSparkJob',
    index=68,
    containing_service=None,
    input_type=_RETRIEVEFEATUREVIEWASSPARKREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/spark:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRetrieveFeatureViewAsSparkJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetRetrieveFeatureViewAsSparkJobOutput',
    index=69,
    containing_service=None,
    input_type=_JOBID,
    output_type=_RETRIEVEFEATUREVIEWASSPARKRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/feature-views/spark/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRetrieveFeatureViewAsLinksJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartRetrieveFeatureViewAsLinksJob',
    index=70,
    containing_service=None,
    input_type=_RETRIEVEFEATUREVIEWASASLINKSREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002I\"D/api/v1/feature-views/{feature_view_id}/{feature_view_version}/links:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRetrieveFeatureViewAsLinksJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetRetrieveFeatureViewAsLinksJobOutput',
    index=71,
    containing_service=None,
    input_type=_JOBID,
    output_type=_RETRIEVEFEATUREVIEWASASLINKSRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/feature-views/links/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeatureView',
    full_name='ai.h2o.featurestore.api.v1.CoreService.DeleteFeatureView',
    index=72,
    containing_service=None,
    input_type=_DELETEFEATUREVIEWREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002)*\'/api/v1/feature-views/{feature_view_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateMLDataset',
    full_name='ai.h2o.featurestore.api.v1.CoreService.CreateMLDataset',
    index=73,
    containing_service=None,
    input_type=_CREATEMLDATASETREQUEST,
    output_type=_CREATEMLDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\023/api/v1/ml-datasets:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMLDatasetCreationJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetMLDatasetCreationJobOutput',
    index=74,
    containing_service=None,
    input_type=_JOBID,
    output_type=_MLDATASET,
    serialized_options=b'\202\323\344\223\002\036\022\034/api/v1/ml-datasets/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMLDataset',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateMLDataset',
    index=75,
    containing_service=None,
    input_type=_UPDATEMLDATASETREQUEST,
    output_type=_MLDATASET,
    serialized_options=b'\202\323\344\223\002(\032#/api/v1/ml-datasets/{ml_dataset_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMLDataset',
    full_name='ai.h2o.featurestore.api.v1.CoreService.DeleteMLDataset',
    index=76,
    containing_service=None,
    input_type=_DELETEMLDATASETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002%*#/api/v1/ml-datasets/{ml_dataset_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMLDataset',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetMLDataset',
    index=77,
    containing_service=None,
    input_type=_GETMLDATASETREQUEST,
    output_type=_MLDATASET,
    serialized_options=b'\202\323\344\223\002%\022#/api/v1/ml-datasets/{ml_dataset_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMLDatasets',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListMLDatasets',
    index=78,
    containing_service=None,
    input_type=_LISTMLDATASETSREQUEST,
    output_type=_LISTMLDATASETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/api/v1/ml-datasets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveMLDatasetAsSpark',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RetrieveMLDatasetAsSpark',
    index=79,
    containing_service=None,
    input_type=_RETRIEVEMLDATASETASSPARKREQUEST,
    output_type=_RETRIEVEMLDATASETASSPARKRESPONSE,
    serialized_options=b'\202\323\344\223\002(\"#/api/v1/ml-datasets/{ml_dataset_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveMLDatasetAsLinks',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RetrieveMLDatasetAsLinks',
    index=80,
    containing_service=None,
    input_type=_RETRIEVEMLDATASETASASLINKSREQUEST,
    output_type=_RETRIEVEMLDATASETASASLINKSRESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#/api/v1/ml-datasets/{ml_dataset_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveMLDatasetOnline',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RetrieveMLDatasetOnline',
    index=81,
    containing_service=None,
    input_type=_RETRIEVEMLDATASETONLINEREQUEST,
    output_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2._ONLINERETRIEVERESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/api/v1/ml-datasets/{ml_dataset_id}/online',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListProjectsPage',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListProjectsPage',
    index=82,
    containing_service=None,
    input_type=_LISTPROJECTSPAGEREQUEST,
    output_type=_LISTPROJECTSPAGERESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/api/v1/projects',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateProject',
    full_name='ai.h2o.featurestore.api.v1.CoreService.CreateProject',
    index=83,
    containing_service=None,
    input_type=_CREATEPROJECTREQUEST,
    output_type=_CREATEPROJECTRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\"\020/api/v1/projects:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProject',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetProject',
    index=84,
    containing_service=None,
    input_type=_GETPROJECTREQUEST,
    output_type=_PROJECTRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/api/v1/projects/{project_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProject',
    full_name='ai.h2o.featurestore.api.v1.CoreService.DeleteProject',
    index=85,
    containing_service=None,
    input_type=_DELETEPROJECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\025*\020/api/v1/projects:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProjectsDefault',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetProjectsDefault',
    index=86,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_PROJECTSDEFAULTRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/api/v1/projects/default',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProjectExists',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ProjectExists',
    index=87,
    containing_service=None,
    input_type=_PROJECTEXISTSREQUEST,
    output_type=_EXISTSRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/projects/{project_id}/exists',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectSecret',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateProjectSecret',
    index=88,
    containing_service=None,
    input_type=_PROJECTBOOLEANFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002)\032$/api/v1/projects/{project_id}/secret:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectLocked',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateProjectLocked',
    index=89,
    containing_service=None,
    input_type=_PROJECTBOOLEANFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002)\032$/api/v1/projects/{project_id}/locked:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectOwner',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateProjectOwner',
    index=90,
    containing_service=None,
    input_type=_PROJECTUSERFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002(\032#/api/v1/projects/{project_id}/owner:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectDescription',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateProjectDescription',
    index=91,
    containing_service=None,
    input_type=_PROJECTSTRINGFIELDUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002.\032)/api/v1/projects/{project_id}/description:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProjectCustomData',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateProjectCustomData',
    index=92,
    containing_service=None,
    input_type=_PROJECTCUSTOMDATAUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\210\002\001\202\323\344\223\002.\032)/api/v1/projects/{project_id}/custom-data:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProject',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateProject',
    index=93,
    containing_service=None,
    input_type=_UPDATEPROJECTREQUEST,
    output_type=_UPDATEPROJECTRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\032\035/api/v1/projects/{project_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccessToken',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetAccessToken',
    index=94,
    containing_service=None,
    input_type=_REFRESHTOKENREQUEST,
    output_type=_ACCESSTOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/api/v1/auth/token:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserByMail',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetUserByMail',
    index=95,
    containing_service=None,
    input_type=_GETUSERBYMAILREQUEST,
    output_type=_GETUSERBYMAILRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/api/v1/auth/users/{email}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Logout',
    full_name='ai.h2o.featurestore.api.v1.CoreService.Logout',
    index=96,
    containing_service=None,
    input_type=_LOGOUTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\030\"\023/api/v1/auth/logout:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveUser',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetActiveUser',
    index=97,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETACTIVEUSERRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/api/v1/auth/users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='ai.h2o.featurestore.api.v1.CoreService.Login',
    index=98,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LOGINRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/api/v1/auth/login:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWebConfig',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetWebConfig',
    index=99,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETWEBCONFIGRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\022\016/api/v1/config',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddFeatureSetPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.AddFeatureSetPermission',
    index=100,
    containing_service=None,
    input_type=_FEATURESETPERMISSIONREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002*\"%/api/v1/auth/feature-sets/permissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddProjectPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.AddProjectPermission',
    index=101,
    containing_service=None,
    input_type=_PROJECTPERMISSIONREQUEST,
    output_type=_PROJECTRESPONSE,
    serialized_options=b'\202\323\344\223\002&\"!/api/v1/auth/projects/permissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveFeatureSetPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RemoveFeatureSetPermission',
    index=102,
    containing_service=None,
    input_type=_FEATURESETPERMISSIONREQUEST,
    output_type=_FEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\002**%/api/v1/auth/feature-sets/permissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveProjectPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RemoveProjectPermission',
    index=103,
    containing_service=None,
    input_type=_PROJECTPERMISSIONREQUEST,
    output_type=_PROJECTRESPONSE,
    serialized_options=b'\202\323\344\223\002&*!/api/v1/auth/projects/permissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitPendingProjectPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.SubmitPendingProjectPermission',
    index=104,
    containing_service=None,
    input_type=_SUBMITPENDINGPERMISSIONREQUEST,
    output_type=_SUBMITPENDINGPERMISSIONRESPONSE,
    serialized_options=b'\202\323\344\223\002/\"*/api/v1/permissions/projects/{resource_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitPendingFeatureSetPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.SubmitPendingFeatureSetPermission',
    index=105,
    containing_service=None,
    input_type=_SUBMITPENDINGPERMISSIONREQUEST,
    output_type=_SUBMITPENDINGPERMISSIONRESPONSE,
    serialized_options=b'\202\323\344\223\0023\"./api/v1/permissions/feature-sets/{resource_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListProjectPermissionsPage',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListProjectPermissionsPage',
    index=106,
    containing_service=None,
    input_type=_LISTPERMISSIONSPAGEREQUEST,
    output_type=_LISTPROJECTSPERMISSIONSPAGERESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/api/v1/permissions/projects',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatureSetsPermissionsPage',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListFeatureSetsPermissionsPage',
    index=107,
    containing_service=None,
    input_type=_LISTPERMISSIONSPAGEREQUEST,
    output_type=_LISTFEATURESETSPERMISSIONSPAGERESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /api/v1/permissions/feature-sets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListManageableProjectPermissionsPage',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListManageableProjectPermissionsPage',
    index=108,
    containing_service=None,
    input_type=_LISTPERMISSIONSPAGEREQUEST,
    output_type=_LISTPROJECTSPERMISSIONSPAGERESPONSE,
    serialized_options=b'\202\323\344\223\002)\022\'/api/v1/permissions/manageable-projects',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListManageableFeatureSetsPermissionsPage',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListManageableFeatureSetsPermissionsPage',
    index=109,
    containing_service=None,
    input_type=_LISTPERMISSIONSPAGEREQUEST,
    output_type=_LISTFEATURESETSPERMISSIONSPAGERESPONSE,
    serialized_options=b'\202\323\344\223\002-\022+/api/v1/permissions/manageable-feature-sets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ApprovePendingPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ApprovePendingPermission',
    index=110,
    containing_service=None,
    input_type=_APPROVEPENDINGPERMISSIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002!\"\034/api/v1/permissions/approval:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RejectPendingPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RejectPendingPermission',
    index=111,
    containing_service=None,
    input_type=_REJECTPENDINGPERMISSIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\"\"\035/api/v1/permissions/rejection:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokePermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RevokePermission',
    index=112,
    containing_service=None,
    input_type=_REVOKEPERMISSIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\037\"\032/api/v1/permissions/revoke:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveProjectPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetActiveProjectPermission',
    index=113,
    containing_service=None,
    input_type=_GETACTIVEPERMISSIONREQUEST,
    output_type=_GETACTIVEPERMISSIONRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/api/v1/permissions/projects/{resource_id}/active',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveFeatureSetPermission',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetActiveFeatureSetPermission',
    index=114,
    containing_service=None,
    input_type=_GETACTIVEPERMISSIONREQUEST,
    output_type=_GETACTIVEPERMISSIONRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/api/v1/permissions/feature-sets/{resource_id}/active',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProjectOwners',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetProjectOwners',
    index=115,
    containing_service=None,
    input_type=_GETOWNERSREQUEST,
    output_type=_GETOWNERSRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/api/v1/permissions/project/{resource_id}/owners',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureSetOwners',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetFeatureSetOwners',
    index=116,
    containing_service=None,
    input_type=_GETOWNERSREQUEST,
    output_type=_GETOWNERSRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/api/v1/permissions/feature-sets/{resource_id}/owners',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeToken',
    full_name='ai.h2o.featurestore.api.v1.CoreService.RevokeToken',
    index=117,
    containing_service=None,
    input_type=_TOKENREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\036\"\031/api/v1/auth/token/revoke:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateToken',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GenerateToken',
    index=118,
    containing_service=None,
    input_type=_GENERATETOKENREQUEST,
    output_type=_RAWTOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/api/v1/auth/token:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTokens',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListTokens',
    index=119,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTTOKENSRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/api/v1/auth/tokens',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetToken',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetToken',
    index=120,
    containing_service=None,
    input_type=_TOKENREQUEST,
    output_type=_TOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/api/v1/auth/tokens/{token_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnlineRetrieve',
    full_name='ai.h2o.featurestore.api.v1.CoreService.OnlineRetrieve',
    index=121,
    containing_service=None,
    input_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2._ONLINERETRIEVEREQUEST,
    output_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2._ONLINERETRIEVERESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1/online-retrieve',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnlineIngest',
    full_name='ai.h2o.featurestore.api.v1.CoreService.OnlineIngest',
    index=122,
    containing_service=None,
    input_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2._ONLINEINGESTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\027\022\025/api/v1/online-ingest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartMaterializationOnlineJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartMaterializationOnlineJob',
    index=123,
    containing_service=None,
    input_type=_STARTMATERIALIZATIONONLINEREQUEST,
    output_type=_JOBID,
    serialized_options=b'\202\323\344\223\002\023\"\016/api/v1/online:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaterializationOnlineJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetMaterializationOnlineJobOutput',
    index=124,
    containing_service=None,
    input_type=_JOBID,
    output_type=_MATERIALIZATIONONLINERESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1/online/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetComputeStatisticsJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetComputeStatisticsJobOutput',
    index=125,
    containing_service=None,
    input_type=_JOBID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002%\022#/api/v1/compute-statistics/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetComputeRecommendationClassifiersJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetComputeRecommendationClassifiersJobOutput',
    index=126,
    containing_service=None,
    input_type=_JOBID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002*\022(/api/v1/compute-recommendations/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateTransformationUpload',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GenerateTransformationUpload',
    index=127,
    containing_service=None,
    input_type=_GENERATETRANSFORMATIONUPLOADREQUEST,
    output_type=_GENERATETRANSFORMATIONUPLOADRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/api/v1/transformations:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRecommendationClassifiers',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListRecommendationClassifiers',
    index=128,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2._LISTRECOMMENDATIONCLASSIFIERRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/api/v1/feature-sets/recommendations-classifiers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRecommendationClassifier',
    full_name='ai.h2o.featurestore.api.v1.CoreService.CreateRecommendationClassifier',
    index=129,
    containing_service=None,
    input_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2._CREATERECOMMENDATIONCLASSIFIERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\0025\"0/api/v1/feature-sets/recommendations-classifiers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRecommendationClassifier',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateRecommendationClassifier',
    index=130,
    containing_service=None,
    input_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2._UPDATERECOMMENDATIONCLASSIFIERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002<\0327/api/v1/feature-sets/recommendations-classifiers/{name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRecommendationClassifier',
    full_name='ai.h2o.featurestore.api.v1.CoreService.DeleteRecommendationClassifier',
    index=131,
    containing_service=None,
    input_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2._DELETERECOMMENDATIONCLASSIFIERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002D*B/api/v1/feature-sets/recommendations-classifiers/{classifier_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecommendations',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetRecommendations',
    index=132,
    containing_service=None,
    input_type=_GETRECOMMENDATIONREQUEST,
    output_type=_GETRECOMMENDATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/feature-sets/recommendations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDashboard',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetDashboard',
    index=133,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2._DASHBOARDRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/api/v1/dashboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchProjects',
    full_name='ai.h2o.featurestore.api.v1.CoreService.SearchProjects',
    index=134,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_PROJECTSEARCHRESULTS,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1/search/projects',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchFeatureSets',
    full_name='ai.h2o.featurestore.api.v1.CoreService.SearchFeatureSets',
    index=135,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_FEATURESETSEARCHRESULTS,
    serialized_options=b'\202\323\344\223\002\035\022\033/api/v1/search/feature-sets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchFeatures',
    full_name='ai.h2o.featurestore.api.v1.CoreService.SearchFeatures',
    index=136,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_FEATURESEARCHRESULTS,
    serialized_options=b'\202\323\344\223\002\030\022\026/api/v1/search/feature',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeature',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetFeature',
    index=137,
    containing_service=None,
    input_type=_GETFEATUREREQUEST,
    output_type=_FEATURERESPONSE,
    serialized_options=b'\202\323\344\223\002=\022;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeature',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListFeature',
    index=138,
    containing_service=None,
    input_type=_LISTFEATURESREQUEST,
    output_type=_LISTFEATURESRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./api/v1/feature-sets/{feature_set_id}/features',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeature',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateFeature',
    index=139,
    containing_service=None,
    input_type=_UPDATEFEATUREREQUEST,
    output_type=_UPDATEFEATURERESPONSE,
    serialized_options=b'\202\323\344\223\002@\032;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetListableFeatureSet',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetListableFeatureSet',
    index=140,
    containing_service=None,
    input_type=_LISTABLEFEATURESETREQUEST,
    output_type=_LISTABLEFEATURESETRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./api/v1/listable-feature-sets/{feature_set_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ScheduleIngestJob',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ScheduleIngestJob',
    index=141,
    containing_service=None,
    input_type=_SCHEDULETASKREQUEST,
    output_type=_SCHEDULEDTASKRESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\033/api/v1/schedules/ingestion:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScheduledTasks',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListScheduledTasks',
    index=142,
    containing_service=None,
    input_type=_LISTSCHEDULEDTASKSREQUEST,
    output_type=_LISTSCHEDULEDTASKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/api/v1/schedules',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetScheduledTask',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetScheduledTask',
    index=143,
    containing_service=None,
    input_type=_SCHEDULEDTASKID,
    output_type=_SCHEDULEDTASKRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/api/v1/schedules/{scheduled_task_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteScheduledTask',
    full_name='ai.h2o.featurestore.api.v1.CoreService.DeleteScheduledTask',
    index=144,
    containing_service=None,
    input_type=_SCHEDULEDTASKID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\'*%/api/v1/schedules/{scheduled_task_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateScheduledTask',
    full_name='ai.h2o.featurestore.api.v1.CoreService.UpdateScheduledTask',
    index=145,
    containing_service=None,
    input_type=_SCHEDULEDTASKUPDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002*\032%/api/v1/schedules/{scheduled_task_id}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ScheduleLazyIngestTask',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ScheduleLazyIngestTask',
    index=146,
    containing_service=None,
    input_type=_SCHEDULETASKREQUEST,
    output_type=_SCHEDULEDTASKRESPONSE,
    serialized_options=b'\202\323\344\223\002%\" /api/v1/schedules/lazy/ingestion:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartLazyIngestTask',
    full_name='ai.h2o.featurestore.api.v1.CoreService.StartLazyIngestTask',
    index=147,
    containing_service=None,
    input_type=_LAZYINGESTREQUEST,
    output_type=_LAZYINGESTRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/api/v1/schedules/lazy/ingestion/start',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLazyIngestTask',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetLazyIngestTask',
    index=148,
    containing_service=None,
    input_type=_GETLAZYINGESTTASKREQUEST,
    output_type=_SCHEDULEDTASKRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/api/v1/schedules/lazy/ingestion/{feature_set_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTransformationFunctions',
    full_name='ai.h2o.featurestore.api.v1.CoreService.ListTransformationFunctions',
    index=149,
    containing_service=None,
    input_type=_LISTTRANSFORMATIONFUNCTIONSREQUEST,
    output_type=_LISTTRANSFORMATIONFUNCTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /api/v1/transformation_functions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransformationFunction',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetTransformationFunction',
    index=150,
    containing_service=None,
    input_type=_GETTRANSFORMATIONFUNCTIONREQUEST,
    output_type=_GETTRANSFORMATIONFUNCTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002A\022?/api/v1/transformation_functions/{transformation_function_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBackfillJobOutput',
    full_name='ai.h2o.featurestore.api.v1.CoreService.GetBackfillJobOutput',
    index=151,
    containing_service=None,
    input_type=_JOBID,
    output_type=_BACKFILLRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/api/v1/backfill/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CORESERVICE)

DESCRIPTOR.services_by_name['CoreService'] = _CORESERVICE

# @@protoc_insertion_point(module_scope)
